searchData={"items":[{"type":"module","title":"PrimerLive","doc":"An implementation of GitHub's  Primer Design System  for Phoenix LiveView.\n \n\n \nPrimer Design provides a strong base for creating data driven applications such as rich CRUD applications with interactive forms.\n \n\n \nAll PrimerLive components accept the  class  attribute for customisations (and often the  classes  struct to address inner elements).  Primer's utility classes  allow a wide range of customisations without having to write custom styles.\n \n\n \nPrimerLive components can be used in  Phoenix LiveView pages  and regular (non-LiveView) views in Phoenix applications.","ref":"PrimerLive.html"},{"type":"module","title":"Documentation - PrimerLive","doc":"- [Component documentation](`PrimerLive.Component`)\n- [Installation](doc-extra/installation.md)\n- [Usage](doc-extra/usage.md)","ref":"PrimerLive.html#module-documentation"},{"type":"module","title":"Resources - PrimerLive","doc":"- [PrimerLive Storybook and Demo](https://primer-live.org)\n- [Source code](https://github.com/ArthurClemens/primer_live)","ref":"PrimerLive.html#module-resources"},{"type":"module","title":"PrimerLive.Component","doc":"PrimerLive component documentation.","ref":"PrimerLive.Component.html"},{"type":"function","title":"PrimerLive.Component.action_list/1","doc":"Action list is a vertical list of interactive actions or options. It's composed of items presented in a consistent. single-column format, with room for icons, descriptions, side information, and other rich visuals.\n\nAction list is composed of one or more child components:\n- `action_list_section_divider/1` - a divider with optional title\n- `action_list_item/1` - versatile list item\n\nSee the [Primer Action list interface guidelines](https://primer.style/design/components/action-list) for more examples.","ref":"PrimerLive.Component.html#action_list/1"},{"type":"function","title":"Examples - PrimerLive.Component.action_list/1","doc":"","ref":"PrimerLive.Component.html#action_list/1-examples"},{"type":"function","title":"action_list - PrimerLive.Component.action_list/1","doc":"```\n<.action_list>\n  <.action_list_item>Item</.action_list_item>\n  <.action_list_item>Item</.action_list_item>\n</.action_list>\n```\n\nCreate separator lines between the items:\n\n```\n<.action_list is_divided>\n  ...\n</.action_list>\n```\n\nRemove default padding:\n\n```\n<.action_list is_full_bleed>\n  ...\n</.action_list>\n```","ref":"PrimerLive.Component.html#action_list/1-action_list"},{"type":"function","title":"action_list_section_divider - PrimerLive.Component.action_list/1","doc":"Add a divider to separate a group of content:\n\n```\n<.action_list>\n  <.action_list_section_divider />\n  ...\n</.action_list>\n```\n\nAdd a title to the divider, and optionally a description:\n\n```\n<.action_list>\n  <.action_list_section_divider>\n    <:title>Section title</:title>\n    <:description>A descriptive text</:description>\n  </.action_list_section_divider>\n  ...\n</.action_list>\n```\n\nUse the title slot to set the id for `aria-labelledby`:\n\n```\n<.action_list aria-labelledby=\"title-01\">\n  <.action_list_section_divider>\n    <:title id=\"title-01\">Section title</:title>\n  </.action_list_section_divider>\n  ...\n</.action_list>\n```","ref":"PrimerLive.Component.html#action_list/1-action_list_section_divider"},{"type":"function","title":"action_list_item - PrimerLive.Component.action_list/1","doc":"Common list item attributes:\n\n```\n<.action_list_item is_selected>\n  This is the selected item\n</.action_list_item>\n\n<.action_list_item is_danger>\n  Descructive item\n</.action_list_item>\n\n<.action_list_item is_disabled>\n  Disabled item\n</.action_list_item>\n\n<.action_list_item is_button phx-click=\"remove\">\n  Button\n</.action_list_item>\n\n<.action_list_item is_height_medium>\n  A higher item\n</.action_list_item>\n\n<.action_list_item is_height_large>\n  An even higher item\n</.action_list_item>\n\n<.action_list_item is_truncated>\n  A very long text that should stay on one line, abbreviated by ellipsis\n</.action_list_item>\n```\n\nUse slot `description` to add a descriptive text. The description is displayed on a new line by default.\n\n```\n<.action_list_item>\n  Short label\n  <:description>\n    A more descriptive text\n  </:description>\n</.action_list_item>\n```\n\nPlace the description on the same line:\n\n```\n<.action_list_item is_inline_description>\n  Short label\n  <:description>\n    A more descriptive text after the title\n  </:description>\n</.action_list_item>\n```\n\nAdd a leading visual. This is usually an `octicon/1`, but can be any small image:\n\n```\n<.action_list_item>\n  Item\n  <:leading_visual>\n    <.octicon name=\"bell-16\" />\n  </:leading_visual>\n</.action_list_item>\n```\n\nLikewise, add a trailing visual:\n\n```\n<.action_list_item>\n  Item\n  <:leading_visual>\n    <.counter>12</.counter>\n  </:leading_visual>\n</.action_list_item>\n```\n\nItems are by default rendered as span elements. To create link elements, place the label text inside slot `link` and pass attribute `href`, `navigate` or `patch`.\nWhen a link attribute is supplied to the link slot, links are created with `Phoenix.Component.link/1`, passing all other slot attributes to the link. Link examples:\n\n```\n<.action_list_item>\n  <:link href=\"/url\" target=\"_blank\">\n    href link\n  </:link>\n</.action_list_item>\n<.action_list_item>\n  <:link navigate={Routes.page_path(@socket, :index)}>\n    navigate link\n  </:link>\n</.action_list_item>\n<.action_list_item>\n  <:link patch={Routes.page_path(@socket, :index)}>\n    patch link\n  </:link>\n</.action_list_item>\n```\n\n\nAction list items can be selected. Single selections are represented with a check `ui_icon/1`, while multiple selections are represented with a checkbox `ui_icon/1`.\n\nCreate a single select list:\n\n```\n<.action_list>\n  <.action_list_item is_single_select is_selected>\n    Option\n  </.action_list_item>\n  <.action_list_item is_single_select>\n    Option\n  </.action_list_item>\n  <.action_list_item is_single_select>\n    Option\n  </.action_list_item>\n</.action_list>\n```\n\nCreate a multiple select list. Add `is_multiple_select` to both `action_list` (for the proper ARIA attributes) and `action_list_item` (for leading visuals):\n\n```\n<.action_list is_multiple_select>\n  <.action_list_item is_multiple_select is_selected>\n    Option\n  </.action_list_item>\n  <.action_list_item is_multiple_select is_selected>\n    Option\n  </.action_list_item>\n  <.action_list_item is_multiple_select>\n    Option\n  </.action_list_item>\n</.action_list>\n```\n\nDeviating from the Primer implementation, selected items don't show a highlight border at the left. To give these items a navigation like appearance, use `is_selected_link_marker`:\n\n```\n<.action_list>\n  <.action_list_item is_single_select is_selected_link_marker is_selected>\n    Option\n  </.action_list_item>\n  <.action_list_item is_single_select is_selected_link_marker>\n    Option\n  </.action_list_item>\n  <.action_list_item is_single_select is_selected_link_marker>\n    Option\n  </.action_list_item>\n</.action_list>\n```\n\nNested sub lists (\"sub groups\") can be used to initially hide additional options. A sub group is an action list placed inside a list item, which is automatically created by slot `sub_group`.\n\n```\n<.action_list>\n  <.action_list_section_divider>\n    <:title>Section title</:title>\n  </.action_list_section_divider>\n  <.action_list_item leading_visual_width=\"16\" is_collapsible is_expanded>\n    Collapsible and expanded item\n    <:leading_visual>\n      <.octicon name=\"comment-discussion-16\" />\n    </:leading_visual>\n    <:sub_group>\n      <.action_list_item is_sub_item>\n        Sub item\n      </.action_list_item>\n      <.action_list_item is_sub_item>\n        Sub item\n      </.action_list_item>\n    </:sub_group>\n  </.action_list_item>\n</.action_list>\n```\n\n- slot `sub_group` accepts `action_list/1` attributes\n- `is_collapsible` indicates that the sub group is conditionally hidden. The item is rendered as button.\n- `is_expanded` reveals hidden items.\n- `leading_visual_width` can be used to align the content with the visual.\n- action list attribute `is_sub_item` renders the item smaller.\n\nWhen using a sub group, use the divider's title slot to set the id for `aria-labelledby` on the sub group:\n\n```\n<.action_list_section_divider>\n  <:title id=\"title-01\">Section title</:title>\n</.action_list_section_divider>\n<.action_list_item>\n  Item\n  <:sub_group aria-labelledby=\"title-01\">\n    ...\n  </:sub_group>\n</.action_list_item>\n```\n\nExample of using a form and event handler to submit a \"single select\" selection:\n\n```\n# Component logic\n\nvalues = assigns.changeset.changes |> Map.get(:roles) || []\ncurrent_role = List.first(values) || \"\"\noptions = Repo.role_options()\nlabel_lookup = options |> Enum.map(fn {label, value} -> {value, label} end) |> Enum.into(%{})\nselected_labels = values |> Enum.map(&Map.get(label_lookup, &1))\n\nselected_text =\n  if Enum.count(selected_labels) > 0,\n    do: selected_labels |> Enum.join(\", \"),\n    else: \"-\"\n\nassigns =\n  assigns\n  |> assign(:options, options)\n  |> assign(:values, values)\n  |> assign(:current_role, current_role)\n  |> assign(:selected_text, selected_text)\n\n# Component heex\n\n \n  Selected: <%= @selected_text %>\n \n \n  <.form :let={f} for={@changeset} phx-change=\"validate\" phx-submit=\"save\" phx-value-role={@current_role}>\n    <.action_list>\n      <%= for {label, value} <- @options do %>\n        <.action_list_item\n          form={f}\n          field={:roles}\n          checked_value={value}\n          is_single_select\n          is_selected={value in @values}\n        >\n          <%= label %>\n        </.action_list_item>\n      <% end %>\n    </.action_list>\n  </.form>\n \n\n# Live view\n\ndef handle_event(\n      \"validate\",\n      %{\"role\" => role, \"job_description\" => params},\n      socket\n    ) do\n  valid_roles = params |> Map.get(\"roles\") |> Enum.reject(&(&1 === role))\n  new_params = params |> Map.put(\"roles\", valid_roles)\n\n  changeset =\n    Repo.empty_job_description()\n    |> Repo.change_job_description(new_params)\n    |> Map.put(:action, :validate)\n\n  socket =\n    socket\n    |> assign(:changeset, changeset)\n\n  {:noreply, socket}\nend\n```","ref":"PrimerLive.Component.html#action_list/1-action_list_item"},{"type":"function","title":"Attributes - PrimerLive.Component.action_list/1","doc":"* `aria_label` (`:string`) - Adds attribute `aria-label` to the outer element. Defaults to `nil`.\n* `role` (`:string`) - Adds attribute `role` to the outer element. Defaults to `\"listbox\"`.\n* `is_divided` (`:boolean`) - Show dividers between items. Defaults to `false`.\n* `is_full_bleed` (`:boolean`) - Removes the default padding. Defaults to `false`.\n* `is_multiple_select` (`:boolean`) - Sets ARIA attribute and classes for multi select checkmarks. Defaults to `false`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#action_list/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.action_list/1","doc":"* `inner_block` (required) - Action list components.","ref":"PrimerLive.Component.html#action_list/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.action_list/1","doc":"[Primer Action list](https://primer.style/design/components/action-list)\n[Primer Nav list](https://primer.style/design/components/nav-list)","ref":"PrimerLive.Component.html#action_list/1-reference"},{"type":"function","title":"PrimerLive.Component.action_list_item/1","doc":"Action list item. See `action_list/1`.","ref":"PrimerLive.Component.html#action_list_item/1"},{"type":"function","title":"Attributes - PrimerLive.Component.action_list_item/1","doc":"* `form` (`:any`) - Either a [Phoenix.HTML.Form](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html) or an atom. Defaults to `nil`.\n* `field` (`:any`) - Field name (atom or string). Defaults to `nil`.\n* `checked_value` (`:string`) - Checkbox `checked_value`, see `checkbox/1`. Defaults to `nil`.\n* `input_id` (`:string`) - When using form/field. Custom input ID to be used in case the generated IDs cause \"Multiple IDs detected\" errors. Defaults to `nil`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for section item elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    action_list_item: \"\",          # Action list item element (li)\n    content: \"\",                   # Content wrapper (span, a or button)\n    label: \"\",                     # Label container (span)\n    description: \"\",               # Description container (span)\n    description_container: \"\",     # Container around label and description (span)\n    leading_visual: \"\",            # Leading visual container (span)\n    trailing_visual: \"\",           # Trailing visual container (span)\n    sub_group: \"\",                 # Nested action_list\n  }\n  ```\n\n  Defaults to `%{label: nil, description: nil, content: nil, section_divider: nil, description_container: nil, leading_visual: nil, trailing_visual: nil, sub_group: nil}`.\n* `is_selected` (`:boolean`) - Shows the selected state.\n  - Link items show an active border at the left and a gray highlighted background\n  - Single select items show a check icon\n  - Multiple select items show a selected checkbox icon\n\n  Defaults to `false`.\n* `is_selected_link_marker` (`:boolean`) - When using `is_single_select` or `is_multiple_select`: creates a selected state similar for selected link items (border and background). Defaults to `false`.\n* `is_inline_description` (`:boolean`) - Renders the description inline, on the same line as the label. Defaults to `false`.\n* `is_height_medium` (`:boolean`) - Sets the row height to at least 40px. The default row height is 32px (on touch devices this is 48px). Defaults to `false`.\n* `is_height_large` (`:boolean`) - Sets the row height to at least 48px. The default row height is 32px (on touch devices this is 48px as well). Defaults to `false`.\n* `is_single_select` (`:boolean`) - Creates a checkbox group, visualized as checkmark icons, and sets ARIA attributes. The icons can be replaced with the `leading_visual` slot.\n  Uses `checkbox/1` without attr `is_multiple` set, so the form will contain a single string for the selected value.\n\n  Defaults to `false`.\n* `is_multiple_select` (`:boolean`) - Creates a checkbox group, using smaller sized checkboxes, and sets ARIA attributes. The icons can be replaced with the `leading_visual` slot.\n  Uses `checkbox/1` with attr `is_multiple: true` and `hidden_input: false`, so the form will contain an array of strings for the selected values.\n\n  Defaults to `false`.\n* `is_checkmark_icon` (`:boolean`) - Overrides the default `leading_visual` when using `is_multiple_select`. Visualizes the checkboxes as checkmark icons. Defaults to `false`.\n* `is_button` (`:boolean`) - Renders the content element with a `button` tag. Defaults to `false`.\n* `is_collapsible` (`:boolean`) - Inserts a collapse icon as trailing visual (override the visual by using `trailing_visual` slot). Use with `is_expanded` and sets ARIA attributes. Uses a `button` element instead of `span`.\n\n  When using slot `sub_group`, a false value of `is_expanded` will hide the sub group items.\n\n  Defaults to `false`.\n* `is_expanded` (`:boolean`) - Use with `is_collapsible`. Sets the state of the collapsible by setting ARIA attributes.\n\n  When using slot `sub_group`, a false value of `is_expanded` will hide the sub group items; a true value will show the items and make the current item bold.\n\n  Defaults to `false`.\n* `is_danger` (`:boolean`) - Adds a \"danger\" style to show that the item is descrucive. Defaults to `false`.\n* `is_disabled` (`:boolean`) - Shows the item is disabled. Defaults to `false`.\n* `is_truncated` (`:boolean`) - Shortens the item label with ellipsis. Defaults to `false`.\n* `is_sub_item` (`:boolean`) - For items within a `sub_group`. Renders the item smaller. Defaults to `false`.\n* `leading_visual_width` (`:any`) - Use with the item that contains slots `sub_group` and `leading_visual`. Indents the items within the sub group to match the leading visual.\n\n  Supported sizes: 16, 20, 24.\n\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#action_list_item/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.action_list_item/1","doc":"* `inner_block` (required) - Label.\n* `link` - Creates a link. Pass attribute `href`, `navigate` or `patch`. Accepts attributes:\n\n  * `href` (`:any`) - Link attribute. The link is created with `Phoenix.Component.link/1`, passing all other slot attributes to the link.\n  * `patch` (`:string`) - Link attribute - see `href`.\n  * `navigate` (`:string`) - Link attribute - see `href`.\n  * `target` (`:string`) - Link target.\n  * `onclick` (`:string`) - Onclick event.\n  * `phx-*` (`:string`) - phx attributes.\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `description` - Description.\n* `leading_visual` - Container for a leading visual. Commonly a `octicon/1` component is used.\n\n  The container's width is determined by the content. Use the same size icons and graphics for consistency. A common icon size is 16px.\n\n* `trailing_visual` - Container for a trailing visual. Commonly a `octicon/1` component is used, but a textual \"visual\" is also possible.\n* `sub_group` - Creates a nested `action_list/1`. Pass `action_list_items` as children.\n\n  Use `is_sub_item` for child items to render them smaller.\n\n  Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)","ref":"PrimerLive.Component.html#action_list_item/1-slots"},{"type":"function","title":"PrimerLive.Component.action_list_section_divider/1","doc":"Action list section divider for separating groups of content. See `action_list/1`.","ref":"PrimerLive.Component.html#action_list_section_divider/1"},{"type":"function","title":"Attributes - PrimerLive.Component.action_list_section_divider/1","doc":"* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for section divider elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    section_divider: \"\", # Section divider element (li)\n    title: \"\",           # Title container (h3)\n    description: \"\",     # Description container (span)\n  }\n  ```\n\n  Defaults to `%{description: nil, title: nil, section_divider: nil}`.\n* `is_filled` (`:boolean`) - Creates a higher horizontal line. When used with the `title` slot, the title is placed inside the line. Defaults to `false`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#action_list_section_divider/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.action_list_section_divider/1","doc":"* `title` - Title separator. The input text is wrapped in a ` ` element. Omit to create a horizontal line only. Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `description` - Optional extra text. Requires `title` slot. Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)","ref":"PrimerLive.Component.html#action_list_section_divider/1-slots"},{"type":"function","title":"PrimerLive.Component.action_menu/1","doc":"Action menu is composed of action list and overlay patterns used for quick actions and selections.\n\nThe action menu functions similarly to a `select_menu/1`, but with an `action_list/1` as content.\n\n```\n<.action_menu>\n  <:toggle>Menu</:toggle>\n  <.action_list>\n    ...\n  </.action_list>\n</.action_menu>\n```","ref":"PrimerLive.Component.html#action_menu/1"},{"type":"function","title":"Examples - PrimerLive.Component.action_menu/1","doc":"Create a multiple select menu:\n\n```\n<.action_menu is_dropdown_caret>\n  <:toggle>Select <.counter>2</.counter></:toggle>\n  <.action_list>\n    <.action_list_item is_multiple_select is_selected>\n      Option\n    </.action_list_item>\n    <.action_list_item is_multiple_select is_selected>\n      Option\n    </.action_list_item>\n    <.action_list_item is_multiple_select>\n      Option\n    </.action_list_item>\n  </.action_list>\n</.action_menu>\n```\n\nSee for more examples:\n- [Action list examples](#action_list/1-examples)\n- [Select menu examples](#select_menu/1-examples)","ref":"PrimerLive.Component.html#action_menu/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.action_menu/1","doc":"* `id` (`:string`) - Menu element id. Use to toggle from the outside, and to get consistent IDs in tests.\n  If not set, an id is generated, either based on `form` and `field`, or otherwise randomly.\n\n* `form` (`:any`) - To maintain the open state when using the menu element inside a form, pass the form surrounding the menu element.\n  Either a [Phoenix.HTML.Form](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html) or an atom.\n\n* `field` (`:any`) - Field name (atom or string). Use an atom when used with a form.\n  To maintain the open state when using the menu inside a form, see: [Menus and dialogs](doc-extra/menus-and-dialogs.md).\n\n* `is_dropdown_caret` (`:boolean`) - Adds a dropdown caret to the prompt button. Defaults to `false`.\n* `is_backdrop` (`:boolean`) - Generates a backdrop background (default with medium darkness). Defaults to `false`.\n* `is_dark_backdrop` (`:boolean`) - Generates a darker backdrop background color. Defaults to `false`.\n* `is_medium_backdrop` (`:boolean`) - Generates a medium backdrop background color. Defaults to `false`.\n* `is_light_backdrop` (`:boolean`) - Generates a lighter backdrop background color. Default for menus. Defaults to `false`.\n* `is_fast` (`:boolean`) - Generates fast fade transitions for backdrop and content. Defaults to `true`.\n* `prompt_options` (`:string`) - JavaScript state callback functions as string. For example:\n\n  ```\n  \"{\n    willShow: function(elements) { console.log('willShow', elements) },\n    didShow: function(elements) { console.log('didShow', elements) },\n    willHide: function(elements) { console.log('willHide', elements) },\n    didHide: function(elements) { console.log('didHide', elements) }\n  }\"\n  ```\n\n* `phx_click_touch` (`:any`) - `phx-click` event binding to assign an event callback on clicking the touch layer.\n  Ignored if `is_modal` is true.\n\n* `is_aligned_end` (`:boolean`) - Aligns the menu to the end (at the right in left-to-right languages). Defaults to `false`.\n* `is_right_aligned` (`:boolean`) - Deprecated: use `is_aligned_end`. Since 0.5.1.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for action menu elements.\n\n  Any provided value will be appended to the default classname, except for `toggle` that will override the default class \"btn\".\n\n  Default map:\n  ```\n  %{\n    action_menu: \"\",         # Action menu container (details element).\n    caret: \"\",               # Dropdown caret element.\n    menu_container: \"\",      # Menu container (called \"modal\" at PrimerCSS).\n    menu_list: \"\",           # Menu list container.\n    menu: \"\",                # Menu element\n    toggle: \"\",              # Toggle element. Any value will override the\n                             # default class \"btn\".\n  }\n  ```\n\n  Defaults to `%{menu: nil, caret: nil, toggle: nil, menu_container: nil, menu_list: nil, action_menu: nil}`.\n* `menu_theme` (`:map`) - Sets the theme of the menu, including the dropdown shadow, but excluding the toggle button. This is useful when the button resides in a part with a different theme, such as a dark header.\n\n  Pass a map with all theme state keys. See `theme/1`.\n\n  Example:\n  ```\n  <.header>\n    <.action_menu menu_theme={@theme_state}>\n      <:toggle>\n        <.octicon name=\"sun-16\" />\n      </:toggle>\n      <.theme_menu_options\n        default_theme_state={@default_theme_state}\n        theme_state={@theme_state}\n      />\n    </.action_menu>\n  <./header>\n  ```\n\n  Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#action_menu/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.action_menu/1","doc":"* `toggle` (required) - Generates a toggle element (default with button appearance) using the slot content as label.\n\n  Any custom class will override the default class \"btn\".\n\n  Accepts attributes:\n\n  * `options` (`:string`) - Deprecated: pass the attrs to the menu component as `prompt_options`.\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`) - Additional HTML attributes added to the item element.\n* `inner_block` - Slot to place the `action_list/1` component.","ref":"PrimerLive.Component.html#action_menu/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.action_menu/1","doc":"- [Primer Action menu](https://primer.style/design/components/action-menu)\n- [Primer Action list](https://primer.style/design/components/action-list)","ref":"PrimerLive.Component.html#action_menu/1-reference"},{"type":"function","title":"PrimerLive.Component.alert/1","doc":"Flash alert informs users of successful or pending actions.\n\n```\n<.alert>\n  Flash message goes here.\n</.alert>\n```","ref":"PrimerLive.Component.html#alert/1"},{"type":"function","title":"Examples - PrimerLive.Component.alert/1","doc":"Add color to the alert by using attribute `state`. Possible states:\n\n- \"default\" - light blue\n- \"info\" - same as default\n- \"success\" - light green\n- \"warning\" - light yellow\n- \"error\" - pink\n\nAdd a success color to the alert:\n\n```\n<.alert state=\"success\">\n  You're done!\n</.alert>\n```\n\nMultiline message:\n\n```\n<.alert state=\"success\">\n   You're done! \n   You may close this message \n</.alert>\n```\n\nTo add an extra bottom margin to a stack of alerts, wrap the alerts in `alert_messages/1`.","ref":"PrimerLive.Component.html#alert/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.alert/1","doc":"* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for the alert element and alert states.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    alert: \"\",         # Outer container\n    state_default: \"\", # Alert color modifier\n    state_info: \"\",    # Alert color modifier\n    state_success: \"\", # Alert color modifier\n    state_warning: \"\", # Alert color modifier\n    state_error: \"\",   # Alert color modifier\n  }\n  ```\n\n  Defaults to `%{alert: nil, state_default: nil, state_info: nil, state_success: nil, state_warning: nil, state_error: nil}`.\n* `state` (`:string`) - Color mapping:\n\n  - \"default\" - light blue\n  - \"info\" - same as default\n  - \"success\" - light green\n  - \"warning\" - light yellow\n  - \"error\" - pink\nMust be one of `\"default\"`, `\"info\"`, `\"success\"`, `\"warning\"`, or `\"error\"`.\n* `is_full_width` (`:boolean`) - Renders the alert full width, with border and border radius removed. Defaults to `false`.\n* `is_full` (`:boolean`) - Deprecated: use `is_full_width`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#alert/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.alert/1","doc":"* `inner_block` (required) - Alert content.","ref":"PrimerLive.Component.html#alert/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.alert/1","doc":"[Primer Flash](https://primer.style/design/components/flash)","ref":"PrimerLive.Component.html#alert/1-reference"},{"type":"function","title":"PrimerLive.Component.alert_messages/1","doc":"Wrapper to render a vertical stack of `alert/1` messages with spacing in between.\n\n```\n<.alert_messages>\n  <.alert is_success>\n    Message 1\n  </.alert>\n  <.alert class=\"mt-4\">\n    Message 2\n  </.alert>\n</.alert_messages>\nRest of content\n```","ref":"PrimerLive.Component.html#alert_messages/1"},{"type":"function","title":"Attributes - PrimerLive.Component.alert_messages/1","doc":"* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#alert_messages/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.alert_messages/1","doc":"* `inner_block` (required) - Alert messages content.","ref":"PrimerLive.Component.html#alert_messages/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.alert_messages/1","doc":"[Primer Alert](https://primer.style/design/components/alert)","ref":"PrimerLive.Component.html#alert_messages/1-reference"},{"type":"function","title":"PrimerLive.Component.animated_ellipsis/1","doc":"Adds animated ellipsis to indicate progress.\n\n```\n<.animated_ellipsis />\n```","ref":"PrimerLive.Component.html#animated_ellipsis/1"},{"type":"function","title":"Examples - PrimerLive.Component.animated_ellipsis/1","doc":"Inside a header:\n\n```\n Loading<.animated_ellipsis /> \n```\n\nInside a label:\n\n```\n<.label>Loading<.animated_ellipsis /></.label>\n```\n\nInside a button:\n\n```\n<.button is_disabled>Loading<.animated_ellipsis /></.label>\n```","ref":"PrimerLive.Component.html#animated_ellipsis/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.animated_ellipsis/1","doc":"* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#animated_ellipsis/1-attributes"},{"type":"function","title":"Reference - PrimerLive.Component.animated_ellipsis/1","doc":"No longer mentioned on https://primer.style/design/components","ref":"PrimerLive.Component.html#animated_ellipsis/1-reference"},{"type":"function","title":"PrimerLive.Component.as_link/1","doc":"Generates a consistent link-like appearance of actual links and spans inside links.\n\nThe component name deviates from the PrimerCSS name `Link` to prevent a naming conflict with `Phoenix.Component.link/1`.\n\n```\nSome text with a <.as_link>link</.as_link>\n```","ref":"PrimerLive.Component.html#as_link/1"},{"type":"function","title":"Examples - PrimerLive.Component.as_link/1","doc":"links are created with `Phoenix.Component.link/1`. Link examples:\n\n```\n<.as_link href=\"/home\">label</.as_link>\n<.as_link navigate=\"/home\">label</.as_link>\n<.as_link patch=\"/home\">label</.as_link>\n```\n\nTurn a link blue only on hover:\n\n```\n<.as_link href=\"/home\" is_primary>link</.as_link>\n```\n\nGive it a muted gray color:\n\n```\n<.as_link href=\"/home\" is_secondary>link</.as_link>\n```\n\nTurn a link blue only on hover:\n\n```\n<.as_link href=\"/home\" is_primary>link</.as_link>\n```\n\nRmove the underline:\n\n```\n<.as_link href=\"/home\" is_no_underline>link</.as_link>\n```\n\nUse `is_on_hover` to make any text color used with links to turn blue on hover.\nThis is useful when you want only part of a link to turn blue on hover.\nWe are using a nested `as_link` for this:\n\n```\n \n  <.as_link href=\"#url\" is_muted is_no_underline>\n    A link with a partial <.as_link is_on_hover>hover link</.as_link>\n  </.as_link>\n \n```\n\nCombine with color utility classes\n\n```\n \n  <.as_link href=\"#url\" is_primary class=\"text-bold\">\n    <.octicon name=\"flame-16\" width=\"12\" class=\"color-fg-danger\" />\n    Hot  potato \n  </.as_link>\n \n```","ref":"PrimerLive.Component.html#as_link/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.as_link/1","doc":"* `is_primary` (`:boolean`) - Turns the link color to blue only on hover. Defaults to `false`.\n* `is_secondary` (`:boolean`) - Turns the link color to blue only on hover, using a darker color. Defaults to `false`.\n* `is_muted` (`:boolean`) - Turns the link to muted gray, also on hover. Defaults to `false`.\n* `is_no_underline` (`:boolean`) - Removes the underline on hover. Defaults to `false`.\n* `is_on_hover` (`:boolean`) - Makes any text color used with links to turn blue on hover. This is useful when you want only part of a link to turn blue on hover. Defaults to `false`.\n* `href` (`:any`) - Link attribute. The link is created with `Phoenix.Component.link/1`, passing all other attributes to the link.\n* `patch` (`:string`) - Link attribute - see `href`.\n* `navigate` (`:string`) - Link attribute - see `href`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#as_link/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.as_link/1","doc":"* `inner_block` (required) - Link content.","ref":"PrimerLive.Component.html#as_link/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.as_link/1","doc":"[Primer Link](https://primer.style/design/components/link)","ref":"PrimerLive.Component.html#as_link/1-reference"},{"type":"function","title":"PrimerLive.Component.avatar/1","doc":"User profile image.\n\nA simple wrapper function that returns an `img` element, styled square and rounded. For correct rendering, the input image must be square.\n\n```\n<.avatar src=\"user.jpg\" />\n```","ref":"PrimerLive.Component.html#avatar/1"},{"type":"function","title":"Examples - PrimerLive.Component.avatar/1","doc":"Set the size (possible values: 1 - 8):\n\n```\n<.avatar size=\"1\" src=\"user.jpg\" />\n```\n\nOr set the size using regular `img` tags:\n\n```\n<.avatar src=\"user.jpg\" width=\"20\" height=\"20\" />\n```","ref":"PrimerLive.Component.html#avatar/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.avatar/1","doc":"* `src` (`:string`) - Image source attribute. Defaults to `nil`.\n* `width` (`:string`) - Image width attribute. Defaults to `nil`.\n* `height` (`:string`) - Image height attribute. Defaults to `nil`.\n* `alt` (`:string`) - Image alt attribute. Defaults to `nil`.\n* `is_round` (`:boolean`) - Creates a round avatar. Defaults to `false`.\n* `size` (`:any`) - Avatar size (number or number as string).\n\n  Values translate to sizes:\n  - 1: `16px`\n  - 2: `20px`\n  - 3: `24px` (default)\n  - 4: `28px`\n  - 5: `32px`\n  - 6: `40px`\n  - 7: `48px`\n  - 8: `64px`\n\n  Defaults to `3`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#avatar/1-attributes"},{"type":"function","title":"Reference - PrimerLive.Component.avatar/1","doc":"[Primer Avatar](https://primer.style/design/components/avatar)","ref":"PrimerLive.Component.html#avatar/1-reference"},{"type":"function","title":"PrimerLive.Component.avatar_pair/1","doc":"Generates a larger \"parent\" avatar with a smaller \"child\" overlaid on top.","ref":"PrimerLive.Component.html#avatar_pair/1"},{"type":"function","title":"Examples - PrimerLive.Component.avatar_pair/1","doc":"Use slots `parent` and `child` to create the avatars using `avatar/1` attributes:\n\n```\n<.avatar_pair>\n  <:parent src=\"emma.jpg\" size=\"7\" />\n  <:child src=\"kim.jpg\" size=\"2\" />\n</.avatar_pair>\n```","ref":"PrimerLive.Component.html#avatar_pair/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.avatar_pair/1","doc":"* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#avatar_pair/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.avatar_pair/1","doc":"* `parent` - Generates a parent avatar. Accepts attributes:\n\n  * `size` (`:any`) - Avatar image size - see `avatar/1`.\n  * `src` (`:any`) - Avatar image source - see `avatar/1`.\n  * `is_round` (`:any`) - Rounded avatar - see `avatar/1`.\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `child` - Generates a child avatar. Accepts attributes:\n\n  * `size` (`:any`) - Avatar size - see `avatar/1`.\n  * `src` (`:any`) - Avatar image source - see `avatar/1`.\n  * `is_round` (`:any`) - Rounded avatar - see `avatar/1`.\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)","ref":"PrimerLive.Component.html#avatar_pair/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.avatar_pair/1","doc":"[Primer Avatar](https://primer.style/design/components/avatars)\n[Primer Avatar pair](https://primer.style/design/components/avatar-pair)","ref":"PrimerLive.Component.html#avatar_pair/1-reference"},{"type":"function","title":"PrimerLive.Component.blankslate/1","doc":"Blankslate is used as placeholder to tell users why content is missing.\n\n```\n<.blankslate>\n  <:heading>\n    This is a blank slate\n  </:heading>\n   Use it to provide information when no dynamic content exists. \n</.blankslate>\n```\n\nBlankslate is created with slots that are applied in this order:\n1. `octicon` or `img`\n1. `heading`\n1. `inner_block`\n1. `action` (multiple)","ref":"PrimerLive.Component.html#blankslate/1"},{"type":"function","title":"Examples - PrimerLive.Component.blankslate/1","doc":"With an `octicon/1`:\n\n```\n<.blankslate>\n  <:octicon name=\"rocket-24\" />\n  ...\n</.blankslate>\n```\n\nWith an image:\n\n```\n<.blankslate>\n  <:img src=\"https://ghicons.github.com/assets/images/blue/png/Pull%20request.png\" alt=\"\" />\n  ...\n</.blankslate>\n```\n\nWith an action:\n\n```\n<.blankslate>\n  <:action>\n    <.button is_primary>New project</.button>\n  </:action>\n  ...\n</.blankslate>\n```\n\nNarrow layout:\n\n```\n<.blankslate is_narrow>\n  ...\n</.blankslate>\n```\n\nLarge text:\n\n```\n<.blankslate is_large>\n  ...\n</.blankslate>\n```\n\nCombined slots, in a `box/1`:\n\n```\n<.box>\n  <.blankslate>\n    <:heading>\n      This is a blank slate\n    </:heading>\n    <:img\n      src=\"https://ghicons.github.com/assets/images/blue/png/Pull%20request.png\"\n      alt=\"\"\n    />\n    <:action>\n      <.button is_primary>New project</.button>\n    </:action>\n    <:action>\n      <.button is_link>Learn more</.button>\n    </:action>\n     Use it to provide information when no dynamic content exists. \n  </.blankslate>\n</.box>\n```","ref":"PrimerLive.Component.html#blankslate/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.blankslate/1","doc":"* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for blankslate elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    blankslate: \"\", # Blankslate wrapper\n    octicon: \"\"     # Icon element\n    img: \"\",        # Image element\n    heading: \"\",    # Heading element\n    action: \"\",     # Action element\n  }\n  ```\n\n  Defaults to `%{action: nil, blankslate: nil, img: nil, heading: nil, octicon: nil}`.\n* `is_narrow` (`:boolean`) - Narrows the blankslate container to not occupy the entire available width. Defaults to `false`.\n* `is_large` (`:boolean`) - Increases the size of the text in the blankslate. Defaults to `false`.\n* `is_spacious` (`:boolean`) - Significantly increases the vertical padding. Defaults to `false`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#blankslate/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.blankslate/1","doc":"* `heading` - Heading. Accepts attributes:\n\n  * `tag` (`:string`) - HTML tag used for the heading.\n\n    Default: \"h3\".\n\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `octicon` - Adds a top icon with `octicon/1`. Accepts attributes:\n\n  * `name` (`:string`) - Octicon name.\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `img` - Adds a top image with an `img` tag. Accepts attributes:\n\n  * `src` (`:string`) - Image source attribute.\n  * `alt` (`:string`) - Image alt attribute.\n  * `width` (`:string`) - Image width attribute.\n  * `height` (`:string`) - Image height attribute.\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `action` - Adds a wrapper for a button or link. Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `inner_block` - Regular content.","ref":"PrimerLive.Component.html#blankslate/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.blankslate/1","doc":"[Primer Blankslate](https://primer.style/design/components/blankslate)","ref":"PrimerLive.Component.html#blankslate/1-reference"},{"type":"function","title":"PrimerLive.Component.box/1","doc":"Box is a basic wrapper component for most layout related needs.\n\nA `box` is a container with rounded corners, a white background, and a light gray border.\nBy default, there are no other styles, such as padding; however, these can be introduced\nwith utility classes as needed.\n\n```\n<.box>\n  Content\n</.box>\n```\n\nSlots allow for the creation of alternative styles and layouts.\n\n```\n<.box>\n  <:header>Header</:header>\n  <:body>Body</:body>\n  <:row>Row</:row>\n  <:footer>Footer</:footer>\n</.box>\n```","ref":"PrimerLive.Component.html#box/1"},{"type":"function","title":"Examples - PrimerLive.Component.box/1","doc":"Row themes:\n\n```\n<.box>\n  <:row is_gray>Row</:row>\n  <:row is_hover_gray>Row</:row>\n  <:row is_yellow>Row</:row>\n  <:row is_hover_blue>Row</:row>\n  <:row is_blue>Row</:row>\n</.box>\n```\n\nBox theme - \"danger box\":\n\n```\n<.box is_danger>\n  <:row>Row</:row>\n  <:row>Row</:row>\n</.box>\n```\n\nHeader theme - blue header:\n\n```\n<.box>\n  <:header is_blue>Blue header</:header>\n</.box>\n```\n\nRender a row for each search result:\n\n```\n<.box>\n  <:row :for={result <- @results}>\n    <%= result %>\n  </:row>\n</.box>\n```\n\nConditionally show an alert:\n\n```\n <.box>\n  <.alert :if={@show_alert}>Alert message</.alert>\n  <:body>\n    Body\n  </:body>\n</.box>\n```\n\nHeader title. Slot `header` can be omitted:\n\n```\n<.box>\n  <:header_title>\n    Title\n  </:header_title>\n  Content\n</.box>\n```\n\nHeader with a button, using both `header` and `header_title` slots. The title will be inserted as first header element:\n\n```\n<.box>\n  <:header class=\"d-flex flex-items-center\">\n    <.button is_primary is_smmall>\n      Button\n    </.button>\n  </:header>\n  <:header_title class=\"flex-auto\">\n    Title\n  </:header_title>\n  <:body>\n    Rest\n  </:body>\n</.box>\n```\n\nHeader with icon button:\n\n```\n<.box>\n  <:header class=\"d-flex flex-justify-between flex-items-start\">\n    <.button is_close_button aria-label=\"Close\" class=\"flex-shrink-0 pl-4\">\n      <.octicon name=\"x-16\" />\n    </.button>\n  </:header>\n  <:header_title>\n    A very long title that wraps onto multiple lines without overlapping\n    or wrapping underneath the icon to it's right\n  </:header_title>\n  <:body>Content</:body>\n</.box>\n```\n\nLinks can be placed inside rows. Use `:let` to get access to the `classes.link` class. With `Phoenix.Component.link/1`:\n\n```\n<.box>\n  <:row :let={classes}>\n    <.link href=\"/\" class={classes.link}>Home</.link>\n  </:row>\n</.box>\n```\n\nTo make the entire row a link, pass attribute `href`, `navigate` or `patch`. Tweak the link behaviour with row attrs `is_hover_gray`, `is_hover_blue` and/or Primer CSS modifier class \"no-underline\". Link examples:\n\n```\n<:row href=\"#url\">href link</:row>\n<:row navigate={Routes.page_path(@socket, :index)}>navigate link</:row>\n<:row patch={Routes.page_path(@socket, :index)}>patch link</:row>\n<:row href=\"#url\" class=\"no-underline\" is_hover_gray>Link, no underline, hover gray</:row>\n```\n\nBox can be used inside dialogs. To make the box content scrollable within the confined space of the dialog, use `is_scrollable`. This will make all inner content (`inner_block`, `body` and `rows`) scrollable between header and footer.\n\nTo limit the height of the box, either:\n- Use class \"Box--scrollable\" to limit the height to `324px`\n- Add style \"max-height\"\n\n```\n<.box is_scrollable class=\"Box--scrollable\">\n  <:header>Fixed header</:header>\n  <:body>Scrollable body</:body>\n  <:row>Scrollable row</:row>\n  <:row>Scrollable row</:row>\n  ...\n  <:footer>Fixed footer</:footer>\n</.box>\n```\n\n```\n<.box is_scrollable style=\"max-height: 80vh\">\n  <:header>Fixed header</:header>\n  <:body>Scrollable body</:body>\n  <:row>Scrollable row</:row>\n  <:row>Scrollable row</:row>\n  ...\n  <:footer>Fixed footer</:footer>\n</.box>\n```","ref":"PrimerLive.Component.html#box/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.box/1","doc":"* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for layout elements.\n\n    Any provided value will be appended to the default classname.\n\n    Default map:\n    ```\n    %{\n      box: \"\",          # Box element\n      header: \"\",       # Box header row element\n      row: \"\",          # Box content row element\n      body: \"\",         # Content element\n      footer: \"\",       # Footer row element\n      header_title: \"\", # Title element within a header row\n      link: \"\",         # Class for links\n    }\n    ```\n\n  Defaults to `%{link: nil, header: nil, body: nil, box: nil, row: nil, footer: nil, header_title: nil}`.\n* `is_blue` (`:boolean`) - Generates a blue box theme. Defaults to `false`.\n* `is_danger` (`:boolean`) - Generates a danger color box theme. Only works with slots `row` and `body`. Use class \"color-border-danger\" for a lighter danger color. Defaults to `false`.\n* `is_border_dashed` (`:boolean`) - Applies a dashed border to the box. Defaults to `false`.\n* `is_condensed` (`:boolean`) - Condenses line-height and reduces the padding on the Y axis. Defaults to `false`.\n* `is_spacious` (`:boolean`) - Increases padding and increases the title font size. Defaults to `false`.\n* `is_scrollable` (`:boolean`) - Makes inner content (consistent of `inner_block`, `body` and `rows`) scrollable in a box with maximum height. Defaults to `false`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#box/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.box/1","doc":"* `header` - Generates a header row element. Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n  * `is_blue` (`:boolean`) - Change the header border and background to blue.\n* `header_title` - Generates a title within the header. If no header slot is passed, the header title will be wrapped inside a header element. Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n* `row` - Generates a content row element. To create a link element, pass attribute `href`, `navigate` or `patch`. Accepts attributes:\n\n  * `is_blue` (`:boolean`) - Blue row theme.\n  * `is_gray` (`:boolean`) - Gray row theme.\n  * `is_yellow` (`:boolean`) - Yellow row theme.\n  * `is_hover_blue` (`:boolean`) - Changes to blue row theme on hover.\n  * `is_hover_gray` (`:boolean`) - Changes to gray row theme on hover.\n  * `is_focus_blue` (`:boolean`) - Changes to blue row theme on focus.\n  * `is_focus_gray` (`:boolean`) - Changes to gray row theme on focus.\n  * `is_navigation_focus` (`:boolean`) - Combine with a theme color to highlight the row when using keyboard commands.\n  * `is_unread` (`:boolean`) - Apply a blue vertical line highlight for indicating a row contains unread items.\n  * `href` (`:any`) - Link attribute. The link is created with `Phoenix.Component.link/1`, passing all other slot attributes to the link.\n  * `patch` (`:string`) - Link attribute - see `href`.\n  * `navigate` (`:string`) - Link attribute - see `href`.\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `body` - Generates a body element. Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n* `footer` - Generates a footer row element. Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n* `inner_block` (required) - Unstructured content.","ref":"PrimerLive.Component.html#box/1-slots"},{"type":"function","title":"Lets - PrimerLive.Component.box/1","doc":"```\n<:item :let={classes} />\n```\n\nYields a `classes` map, containing the merged values of default classnames, plus any value supplied to the `classes` component attribute.\n\n```\n<.box classes={%{ link: \"link-x\" }}>\n  <:row :let={classes}>\n    <.link href=\"/\" class={[\"my-link\", classes.link]}>Home</.link>\n  </:row>\n</.box>\n```\n\nResults in:\n\n```\n \n   \n     Home \n   \n \n```","ref":"PrimerLive.Component.html#box/1-lets"},{"type":"function","title":"Reference - PrimerLive.Component.box/1","doc":"[Primer Box](https://primer.style/design/components/box)\n[Primer Border box](https://primer.style/design/components/border-box)","ref":"PrimerLive.Component.html#box/1-reference"},{"type":"function","title":"PrimerLive.Component.branch_name/1","doc":"Branch name is a label-type component rendered as a link that displays the name of a branch.\n\n```\n<.branch_name>development</.branch_name>\n```","ref":"PrimerLive.Component.html#branch_name/1"},{"type":"function","title":"Examples - PrimerLive.Component.branch_name/1","doc":"A branch name may be a link. Links are created with `Phoenix.Component.link/1`, passing all other attributes to the link. Link examples:\n\n```\n<.branch_name href=\"#url\">some-name</.branch_name>\n<.branch_name navigate={Routes.page_path(@socket, :index)}>some-name</.branch_name>\n<.branch_name patch={Routes.page_path(@socket, :index, :details)}>some-name</.branch_name>\n```\n\nAdd an icon before the branch name:\n\n```\n<.branch_name>\n  <.octicon name=\"git-branch-16\" />\n  some-name\n</.branch_name>\n```","ref":"PrimerLive.Component.html#branch_name/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.branch_name/1","doc":"* `href` (`:any`) - Link attribute. The link is created with `Phoenix.Component.link/1`, passing all other attributes to the link.\n* `patch` (`:string`) - Link attribute - see `href`.\n* `navigate` (`:string`) - Link attribute - see `href`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#branch_name/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.branch_name/1","doc":"* `inner_block` (required) - The branch name text and optionally an icon.","ref":"PrimerLive.Component.html#branch_name/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.branch_name/1","doc":"[Primer Branch name](https://primer.style/design/components/branch-name)","ref":"PrimerLive.Component.html#branch_name/1-reference"},{"type":"function","title":"PrimerLive.Component.breadcrumb/1","doc":"Breadcrumb navigation to navigate a hierarchy of pages.\n\nAll items are rendered as links. The last link will show a selected state.\n\n```\n<.breadcrumb>\n  <:item href=\"/home\">Home</:item>\n  <:item href=\"/account\">Account</:item>\n  <:item href=\"/account/history\">History</:item>\n</.breadcrumb>\n```","ref":"PrimerLive.Component.html#breadcrumb/1"},{"type":"function","title":"Examples - PrimerLive.Component.breadcrumb/1","doc":"Links are created with `Phoenix.Component.link/1`, passing all other slot attributes to the link. Link examples:\n\n```\n<:item href=\"#url\">href link</:item>\n<:item navigate={Routes.page_path(@socket, :index)}>navigate link</:item>\n<:item patch={Routes.page_path(@socket, :index)}>patch link</:item>\n```","ref":"PrimerLive.Component.html#breadcrumb/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.breadcrumb/1","doc":"* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for breadcrumb elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    breadcrumb: \"\",    # Breadcrumb container\n    item: \"\",          # Breadcrumb item (li element)\n    selected_item: \"\", # Selected breadcrumb item (li element)\n    link: \"\",          # Link\n  }\n  ```\n\n  Defaults to `%{link: nil, item: nil, breadcrumb: nil, selected_item: nil}`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#breadcrumb/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.breadcrumb/1","doc":"* `item` (required) - Breadcrumb item content. To create a link element, pass attribute `href`, `navigate` or `patch`. Accepts attributes:\n\n  * `href` (`:any`) - Link attribute. The link is created with `Phoenix.Component.link/1`, passing all other slot attributes to the link.\n  * `patch` (`:string`) - Link attribute - see `href`.\n  * `navigate` (`:string`) - Link attribute - see `href`.\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)","ref":"PrimerLive.Component.html#breadcrumb/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.breadcrumb/1","doc":"[Primer Breadcrumbs](https://primer.style/design/components/breadcrumbs)","ref":"PrimerLive.Component.html#breadcrumb/1-reference"},{"type":"function","title":"PrimerLive.Component.button/1","doc":"Generates a button.\n\n```\n<.button>Click me</.button>\n```","ref":"PrimerLive.Component.html#button/1"},{"type":"function","title":"Examples - PrimerLive.Component.button/1","doc":"Optionally create an anchor link rendered as a button. Anchor links are created with `Phoenix.Component.link/1`, passing all other slot attributes to the link. Link examples:\n\n```\n<.button href=\"#url\">href link</.button>\n<.button navigate={Routes.page_path(@socket, :index)}>navigate link</.button>\n<.button patch={Routes.page_path(@socket, :index)}>patch link</.button>\n```\n\nPrimary button:\n\n```\n<.button is_primary>Sign in</.button>\n```\n\nSmall button:\n\n```\n<.button is_small>Edit</.button>\n```\n\nSelected button:\n\n```\n<.button is_selected>Unread</.button>\n```\n\nWith a dropdown caret:\n\n```\n<.button is_dropdown_caret>Menu</.button>\n```\n\nWith a leading icon:\n\n```\n<.button is_primary>\n  <.octicon name=\"download-16\" />\n   Clone \n</.button>\n```\n\nWith a trailing icon:\n\n```\n<.button is_primary>\n   Clone \n  <.octicon name=\"download-16\" />\n</.button>\n```\n\nIcon button (a button with an icon, similar to Primer React's IconButton):\n\n```\n<.button is_icon_button aria-label=\"Desktop\">\n  <.octicon name=\"device-desktop-16\" />\n</.button>\n```\n\nIcon as button (reduced padding):\n\n```\n<.button is_icon_only aria-label=\"Desktop\">\n  <.octicon name=\"device-desktop-16\" />\n</.button>\n```\n\nUse `button_group/1` to create a group of buttons:\n\n```\n<.button_group>\n  <.button>Button 1</.button>\n  <.button>Button 2</.button>\n  <.button>Button 3</.button>\n</.button_group>\n```","ref":"PrimerLive.Component.html#button/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.button/1","doc":"* `is_full_width` (`:boolean`) - Generates a full-width button. Defaults to `false`.\n* `is_close_button` (`:boolean`) - Use when enclosing icon \"x-16\". This setting removes the default padding. Defaults to `false`.\n* `is_dropdown_caret` (`:boolean`) - Adds a dropdown caret icon. Defaults to `false`.\n* `is_danger` (`:boolean`) - Generates a danger button (red label, turns the button red on hover). Defaults to `false`.\n* `is_disabled` (`:boolean`) - Generates a disabled button. Defaults to `false`.\n* `is_icon_button` (`:boolean`) - Generates an icon button without a label (similar to Primer React's IconButton). Add `is_danger` to create a danger icon (turns the icon red on hover). Defaults to `false`.\n* `is_icon_only` (`:boolean`) - Generates an icon that functions as a button. Add `is_danger` to create a danger icon (turns the icon red on hover). Defaults to `false`.\n* `is_invisible` (`:boolean`) - Create a button that looks like a link, maintaining the paddings of a regular button. Defaults to `false`.\n* `is_aligned_start` (`:boolean`) - Aligns contents to the start (at the left in left-to-right languages), while the dropdown caret (if any)\n  is placed at the far end.\n  Use this when the button is used for selecting items from a list.\n\n  By default contents is center aligned.\n\n  Defaults to `false`.\n* `is_large` (`:boolean`) - Generates a large button. Defaults to `false`.\n* `is_link` (`:boolean`) - Create a button that looks like a link. Defaults to `false`.\n* `is_outline` (`:boolean`) - Generates an outline button. Defaults to `false`.\n* `is_primary` (`:boolean`) - Generates a primary colored button. Defaults to `false`.\n* `is_selected` (`:boolean`) - Generates a selected button. Defaults to `false`.\n* `is_small` (`:boolean`) - Generates a small button. Defaults to `false`.\n* `is_submit` (`:boolean`) - Generates a button with type=\"submit\". Defaults to `false`.\n* `href` (`:any`) - Link attribute. The link is created with `Phoenix.Component.link/1`, passing all other attributes to the link.\n* `patch` (`:string`) - Link attribute - see `href`.\n* `navigate` (`:string`) - Link attribute - see `href`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for button elements. Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    button: \"\",  # Button element\n    content: \"\", # Content (icons and label)\n    caret: \"\",   # Dropdown icon\n  }\n  ```\n\n  Defaults to `%{content: nil, button: nil, caret: nil}`.\n* Global attributes are accepted. Supports all globals plus: `[\"name\", \"type\", \"disabled\"]`.","ref":"PrimerLive.Component.html#button/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.button/1","doc":"* `inner_block` - Button content.","ref":"PrimerLive.Component.html#button/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.button/1","doc":"[Primer Button](https://primer.style/design/components/button)\n[Primer Button group](https://primer.style/design/components/button-group)\n[Primer Icon button](https://primer.style/design/components/icon-button)","ref":"PrimerLive.Component.html#button/1-reference"},{"type":"function","title":"PrimerLive.Component.button_group/1","doc":"Generates a group of buttons.\n\n```\n<.button_group>\n  <.button>Button 1</.button>\n  <.button>Button 2</.button>\n  <.button>Button 3</.button>\n</.button_group>\n```","ref":"PrimerLive.Component.html#button_group/1"},{"type":"function","title":"Examples - PrimerLive.Component.button_group/1","doc":"Use `button/1` children to create the button row:\n\n```\n<.button_group>\n  <.button>Button 1</.button>\n  <.button is_selected>Button 2</.button>\n  <.button is_danger>Button 3</.button>\n  <.button class=\"my-button\">Button 4</.button>\n</.button_group>\n```","ref":"PrimerLive.Component.html#button_group/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.button_group/1","doc":"* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#button_group/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.button_group/1","doc":"* `button` - Deprecated: use `button/1` as children. Since 0.5.0.\n\n  Deprecation support: use `button/1` attributes to configure the button appearance and behaviour.\n\n  Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n  * `href` (`:any`) - Link attribute. The link is created with `Phoenix.Component.link/1`, passing all other slot attributes to the link.\n  * `navigate` (`:string`) - Link attribute - see `href`.\n  * `patch` (`:string`) - Link attribute - see `href`.\n  * `is_close_button` (`:boolean`) - See `button/1`.\n  * `is_danger` (`:boolean`) - See `button/1`.\n  * `is_disabled` (`:boolean`) - See `button/1`.\n  * `is_dropdown_caret` (`:boolean`) - See `button/1`.\n  * `is_full_width` (`:boolean`) - See `button/1`.\n  * `is_icon_button` (`:boolean`) - See `button/1`.\n  * `is_icon_only` (`:boolean`) - See `button/1`.\n  * `is_invisible` (`:boolean`) - See `button/1`.\n  * `is_large` (`:boolean`) - See `button/1`.\n  * `is_link` (`:boolean`) - See `button/1`.\n  * `is_outline` (`:boolean`) - See `button/1`.\n  * `is_primary` (`:boolean`) - See `button/1`.\n  * `is_selected` (`:boolean`) - See `button/1`.\n  * `is_small` (`:boolean`) - See `button/1`.\n  * `is_submit` (`:boolean`) - See `button/1`.\n* `inner_block` - Buttons as children of group button.","ref":"PrimerLive.Component.html#button_group/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.button_group/1","doc":"[Primer Button group](https://primer.style/design/components/button-group)\n[Primer Button](https://primer.style/design/components/button)","ref":"PrimerLive.Component.html#button_group/1-reference"},{"type":"function","title":"PrimerLive.Component.checkbox/1","doc":"Generates a checkbox.\n\nWrapper around `PhoenixHTMLHelpers.Form.checkbox/3`.\n\n```\n<.checkbox name=\"available_for_hire\" />\n```\n\nTo create a group of checkboxes, see `checkbox_group/1`.","ref":"PrimerLive.Component.html#checkbox/1"},{"type":"function","title":"Examples - PrimerLive.Component.checkbox/1","doc":"Set the checked state:\n\n```\n<.checkbox name=\"available_for_hire\" checked />\n```\n\nUsing the checkbox with form data. This will automatically create the checkbox label:\n\n```\n<.form let={f} for={@changeset} phx-change=\"validate\" phx-submit=\"save\">\n  <.checkbox form={f} field={:available_for_hire} />\n</.form>\n```\n\nPass a custom checkbox label with the `label` slot:\n\n```\n<.checkbox form={:user} field={:available_for_hire}>\n  <:label>Some label</:label>\n</.checkbox>\n```\n\nAdd emphasis to the label:\n\n```\n<.checkbox name=\"available_for_hire\" is_emphasised_label />\n```\n\nAdd a hint below the label:\n\n```\n<.checkbox name=\"available_for_hire\">\n  <:label>Some label</:label>\n  <:hint>\n    Add your  resume  below\n  </:hint>\n</.checkbox>\n```\n\nReveal extra details when the checkbox is checked:\n\n```\n<.checkbox name=\"available_for_hire\">\n  <:label>Some label</:label>\n  <:disclosure>\n     Available hours per week \n    <.text_input is_contrast size=\"3\" />\n     hours per week \n  </:disclosure>\n</.checkbox>\n```","ref":"PrimerLive.Component.html#checkbox/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.checkbox/1","doc":"* `form` (`:any`) - Either a [Phoenix.HTML.Form](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html) or an atom. Defaults to `nil`.\n* `field` (`:any`) - Field name (atom or string). Defaults to `nil`.\n* `name` (`:string`) - Input name attribute (when not using `form` and `field`).\n* `input_id` (`:string`) - When using form/field. Custom input ID to be used in case the generated IDs cause \"Multiple IDs detected\" errors. Defaults to `nil`.\n* `checked` (`:boolean`) - The state of the checkbox (when not using `form` and `field`).\n* `checked_value` (`:string`) - The value to be sent when the checkbox is checked. If `checked_value` equals `value`, the checkbox is marked checked. Defaults to \"true\". Defaults to `nil`.\n* `hidden_input` (`:string`) - Controls if the component will generate a hidden input to submit the unchecked checkbox value or not. Defaults to \"true\". Defaults to `\"true\"`.\n* `value` (`:string`) - Checkbox value attribute (overrides field value when using `form` and `field`).\n* `is_multiple` (`:boolean`) - When creating a list of checkboxes. Appends `[]` to the input name so that a list of values is passed to the form events.\n\n  Alternatively, use `checkbox_in_group/1` to set this automatically.\n\n  Defaults to `false`.\n* `is_emphasised_label` (`:boolean`) - Adds emphasis to the label. Defaults to `false`.\n* `is_omit_label` (`:boolean`) - Omits the label. Defaults to `false`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for checkbox elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    container: \"\",       # Checkbox container\n    label_container: \"\", # Input label container\n    label: \"\",           # Input label\n    input: \"\",           # Checkbox input element\n    caption: \"\",         # Hint message element\n    hint: \"\",            # Deprecation support: identical to \"caption\"\n    disclosure: \"\"       # Disclosure container (inline)\n  }\n  ```\n\n  Defaults to `%{input: nil, label: nil, hint: nil, caption: nil, container: nil, label_container: nil, disclosure: nil}`.\n* Global attributes are accepted. Supports all globals plus: `[\"disabled\"]`.","ref":"PrimerLive.Component.html#checkbox/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.checkbox/1","doc":"* `label` - Custom checkbox label. Overides the derived label when using a `form` and `field`. Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `caption` - Adds text below checkbox label. Enabled when a label is displayed. Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `hint` - Deprecated: use `caption`. As of 0.5.0. Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `disclosure` - Extra label content to be revealed when checkbox is checked. Enabled when a label is displayed.\n\n  Note that the label element can only contain inline child elements.\n\n  Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)","ref":"PrimerLive.Component.html#checkbox/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.checkbox/1","doc":"- [Primer Checkbox](https://primer.style/design/components/checkbox)\n- [Primer Checkbox group](https://primer.style/design/components/checkbox-group)\n- [Primer Form control](https://primer.style/design/components/form-control)","ref":"PrimerLive.Component.html#checkbox/1-reference"},{"type":"function","title":"PrimerLive.Component.checkbox_group/1","doc":"Checkbox group renders a set of [`checkboxes`](`checkbox/1`).\n\n```\n<.checkbox_group>\n  <.checkbox name=\"roles[]\" checked_value=\"admin\" />\n  <.checkbox name=\"roles[]\" checked_value=\"editor\" />\n</.checkbox_group>\n```\n\nThis is equivalent to:\n\n```\n<.form_control is_input_group>\n  <.checkbox name=\"roles[]\" checked_value=\"admin\" />\n  <.checkbox name=\"roles[]\" checked_value=\"editor\" />\n</.form_control>\n```\n\n`is_input_group` (and hence `checkbox_group`) adds specific styling: a larger label font size, and layout for inputs, captions and validation.","ref":"PrimerLive.Component.html#checkbox_group/1"},{"type":"function","title":"Examples - PrimerLive.Component.checkbox_group/1","doc":"Another convenience component - checkbox variant `checkbox_in_group/1` - sets attr `is_multiple` to true,\nso that the server receives an array of strings for the checked values.\n\n```\n<.form :let={f} for={@changeset} phx-change=\"validate\" phx-submit=\"save\">\n  <.checkbox_group\n    form={f}\n    field={@field}\n    caption=\"Select one\"\n  >\n    <.checkbox_in_group\n      :for={{label, value} <- @options}\n      form={f}\n      field={@field}\n      checked_value={value}\n      checked={value in @values}\n    >\n      <:label>\n        <%= label %>\n      </:label>\n    </.checkbox_in_group>\n  </.checkbox_group>\n</.form>\n```","ref":"PrimerLive.Component.html#checkbox_group/1-examples"},{"type":"function","title":"Reference - PrimerLive.Component.checkbox_group/1","doc":"[Primer Checkbox group](https://primer.style/design/components/checkbox-group)","ref":"PrimerLive.Component.html#checkbox_group/1-reference"},{"type":"function","title":"Attributes - PrimerLive.Component.checkbox_group/1","doc":"* `form` (`:any`) - Either a [Phoenix.HTML.Form](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html) or an atom. Defaults to `nil`.\n* `field` (`:any`) - Field name (atom or string). Defaults to `nil`.\n* `validation_message` (`:any`) - Function to write a custom validation message (in case of error or success).\n\n  The function receives a `PrimerLive.FieldState` struct and returns a validation message or nil.\n\n  A validation message is shown:\n  - If form is a `Phoenix.HTML.Form`, containing a `changeset`\n  - The `validation_message` function does not return nil\n\n  Function signatures:\n  - `fun () -> string | nil`\n  - `fun (field_state) -> string | nil`\n\n  Conditional error message:\n  ```\n  fn field_state ->\n    if !field_state.valid?, do: \"Please enter your first name\"\n  end\n  ```\n\n  Conditional success message, only shown when `changeset.action` is `:validate`:\n  ```\n  fn field_state ->\n    if field_state.valid? && field_state.changeset.action == :validate, do: \"Is available\"\n  end\n  ```\n\n  Defaults to `nil`.\n* `caption` (`:any`) - Hint message below the checkbox group label.\n\n  Pass a string, or a function that returns a string.\n\n  The function receives a `PrimerLive.FieldState` struct and returns a message or nil (which omits the caption element).\n\n  Function signatures:\n  - `fun () -> string | nil`\n  - `fun (field_state) -> string | nil`\n\n  To conditionally show a caption, use `field_state`. To show the caption when field state is valid:\n  ```\n  fn field_state ->\n    if !field_state.valid?, do: nil, else: \"Caption\"\n  end\n  ```\n\n  For additional markup, use the `H` sigil:\n  ```\n  fn ->\n    ~H'''\n    Caption with  link \n    '''\n  end\n  ```\n\n  Defaults to `nil`.\n* `label` (`:string`) - Custom label. Note that a label is automatically generated when using `field`. Defaults to `nil`.\n* `is_hide_label` (`:boolean`) - Omits the automatically generated label (when using `field`). Defaults to `false`.\n* `is_disabled` (`:boolean`) - Adjusts the styling to indicate disabled state. Defaults to `false`.\n* `required_marker` (`:string`) - Required field marking. This will be shown for all required fields (when using `Phoenix.HTML.Form`). Pass an empty string to remove the indicator. Defaults to `\"*\"`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for checkbox group elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    control: \"\",               # Checkbox group wrapper\n    group: \"\",                 # Deprecation support: identical to \"control\"\n    header: \"\",                # Header element containing the group label\n    label: \"\",                 # Checkbox group label\n    input_group_container: \"\", # Input group container (for checkbox_group and radio_group)\n    caption: \"\",               # Checkbox group caption\n  }\n  ```\n\n  Defaults to `%{control: nil, label: nil, header: nil, group: nil, caption: nil, input_group_container: nil}`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#checkbox_group/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.checkbox_group/1","doc":"* `inner_block` (required) - The checkbox group content.","ref":"PrimerLive.Component.html#checkbox_group/1-slots"},{"type":"function","title":"PrimerLive.Component.checkbox_in_group/1","doc":"Convenience checkbox component for use inside `checkbox_group/1`.\n\nSets attr `is_multiple` to true, so that the server receives an array of strings for the checked values.\n\n```\n<.checkbox_in_group form={@form} field={@field} />\n```\n\nInside a form and checkbox group:\n\n```\n<.form :let={f} for={@changeset} phx-change=\"validate\" phx-submit=\"save\">\n  <.checkbox_group\n    form={f}\n    field={@field}\n  >\n    <.checkbox_in_group\n      :for={{label, value} <- @options}\n      form={f}\n      field={@field}\n      checked_value={value}\n      checked={value in @values}\n    />\n  </.checkbox_group>\n</.form>\n```","ref":"PrimerLive.Component.html#checkbox_in_group/1"},{"type":"function","title":"Attributes - PrimerLive.Component.checkbox_in_group/1","doc":"Use `checkbox/1` attributes.","ref":"PrimerLive.Component.html#checkbox_in_group/1-attributes"},{"type":"function","title":"PrimerLive.Component.circle_badge/1","doc":"Generates a badge-like icon or logo.\n\n```\n<.circle_badge>\n  <:octicon name=\"alert-16\" />\n</.circle_badge>\n```","ref":"PrimerLive.Component.html#circle_badge/1"},{"type":"function","title":"Examples - PrimerLive.Component.circle_badge/1","doc":"Use slot `octicon` to create an `octicon/1` icon\n\n```\n<.circle_badge>\n  <:octicon name=\"alert-16\" />\n</.circle_badge>\n```\n\nUse slot `img` to create an image icon\n\n```\n<.circle_badge>\n  <:img src=\"https://github.com/travis-ci.png\" />\n</.circle_badge>\n```\n\nCreate a large badge (size \"medium\" or \"large\"):\n\n```\n<.circle_badge size=\"medium\">\n  <:octicon name=\"alert-24\" />\n</.circle_badge>\n```\n\nBadges are by default rendered as div elements. To create link elements, pass attribute `href`, `navigate` or `patch`. Link examples:\n\n```\n<.circle_badge href=\"#url\">...</.circle_badge>\n<.circle_badge navigate={Routes.page_path(@socket, :index)}>...</.circle_badge>\n<.circle_badge patch={Routes.page_path(@socket, :index, :details)}>...</.circle_badge>\n```","ref":"PrimerLive.Component.html#circle_badge/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.circle_badge/1","doc":"* `size` (`:string`) - Badge size: \"small\", \"medium\" or \"large\".\n\n  Sizes:\n  - small: `56px` (default)\n  - medium: `96px`\n  - large: `128px`\n\n  Defaults to `\"small\"`.\n* `href` (`:any`) - Link attribute. The link is created with `Phoenix.Component.link/1`, passing all other attributes to the link.\n* `patch` (`:string`) - Link attribute - see `href`.\n* `navigate` (`:string`) - Link attribute - see `href`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#circle_badge/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.circle_badge/1","doc":"* `octicon` - Generates a badge icon with `octicon/1`. Accepts attributes:\n\n  * `name` (`:string`) - Octicon name.\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `img` - Generates a badge icon with an `img` tag. Accepts attributes:\n\n  * `src` (`:any`) - Image source attribute.\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)","ref":"PrimerLive.Component.html#circle_badge/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.circle_badge/1","doc":"[Primer Circle badge](https://primer.style/design/components/circle-badge)","ref":"PrimerLive.Component.html#circle_badge/1-reference"},{"type":"function","title":"PrimerLive.Component.counter/1","doc":"Adds a count label to navigational elements and buttons.\n\n```\n<.counter>12</.counter>\n```","ref":"PrimerLive.Component.html#counter/1"},{"type":"function","title":"Examples - PrimerLive.Component.counter/1","doc":"Apply primary state:\n\n```\n<.counter is_primary>12</.counter>\n```\n\nWith an icon:\n\n```\n<.counter><.octicon name=\"comment-16\" /> 1.5K</.counter>\n```\n\nAdd an emoji:\n\n```\n<.counter>👍 2</.counter>\n```","ref":"PrimerLive.Component.html#counter/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.counter/1","doc":"* `is_primary` (`:boolean`) - Primary color. Defaults to `false`.\n* `is_secondary` (`:boolean`) - Secondary color. Defaults to `false`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#counter/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.counter/1","doc":"* `inner_block` (required) - Label content.","ref":"PrimerLive.Component.html#counter/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.counter/1","doc":"[Primer Counter label](https://primer.style/design/components/counter-label)","ref":"PrimerLive.Component.html#counter/1-reference"},{"type":"function","title":"PrimerLive.Component.dialog/1","doc":"Dialog is a floating surface used to display transient content such as confirmation actions, selection options, and more.\n\nA dialog is created with `box/1` slots.\n\n```\n<.dialog>\n  <:header_title>Title</:header_title>\n  <:body>\n    Message in a dialog\n  </:body>\n</.dialog>\n```\n\nShowing and hiding is done with JS function `Prompt`, included in PrimerLive.\nFunction `Prompt.show` requires a selector. When placed inside the dialog component, the selector can be replaced with `this`:\n\n```\n<.dialog id=\"my-dialog\">\n  <:body>\n    Message in a dialog\n    <.button onclick=\"Prompt.hide(this)\">Close</.button>\n  </:body>\n</.dialog>\n\n<.button onclick=\"Prompt.show('#my-dialog')\">Open dialog</.button>\n```","ref":"PrimerLive.Component.html#dialog/1"},{"type":"function","title":"Examples - PrimerLive.Component.dialog/1","doc":"Add a backdrop. Optionally add `is_light_backdrop` or `is_dark_backdrop`:\n\n```\n<.dialog is_backdrop is_dark_backdrop>\n  ...\n</.dialog>\n```\n\nCreate a modal dialog; clicking the backdrop (if used) or outside of the dialog will not close the dialog:\n\n```\n<.dialog is_modal>\n  ...\n</.dialog>\n```\n\nClose the dialog with the Escape key:\n\n```\n<.dialog is_escapable>\n  ...\n</.dialog>\n```\n\nCreate faster fade in and out:\n\n```\n<.dialog is_fast>\n  ...\n</.dialog>\n```\n\nA narrow dialog:\n\n```\n<.dialog is_narrow>\n  ...\n</.dialog>\n```\n\nA wide dialog:\n\n```\n<.dialog is_wide>\n  ...\n</.dialog>\n```\n\nFocus the first element after opening the dialog. Pass a selector to match the element.\n\n```\n<.dialog focus_first=\"#login_first_name\">\n  ...\n</.dialog>\n```\n\nor\n\n```\n<.dialog focus_first=\"[name=login\\[first_name\\]]\">\n  ...\n</.dialog>\n```\n\nLong content will automatically show a scrollbar. To change the maxium height of the dialog, use a CSS value. Use unit `vh` or `%`.\n\n```\n<.dialog max_height=\"50vh\">\n  ...\n</.dialog>\n```\n\nAdd a header title and a footer.\n\n`box` slot `header` slot is automatically added when `header_title` is used.\n\n```\n<.dialog>\n  <:header_title>Title</:header_title>\n  ...\n  <:footer>Footer</:footer>\n</.dialog>\n```\n\nA dialog with rows:\n\n```\n <.dialog>\n  <:header_title>Title</:header_title>\n  <:row>Row 1</:row>\n  <:row>Row 2</:row>\n  <:row>Row 3</:row>\n  <:row>Row 4</:row>\n  <:footer>Footer</:footer>\n</.dialog>\n```\n\nDialog content is wrapped inside a `Phoenix.Component.focus_wrap/1` so that navigating with Tab won't leave the dialog.\n\n```\n<.dialog is_backdrop is_modal>\n  <:header_title>Title</:header_title>\n  <:body>\n  <.text_input form={:user} field={:first_name} is_form_control />\n  <.text_input form={:user} field={:last_name} is_form_control />\n  </:body>\n</.dialog>\n```","ref":"PrimerLive.Component.html#dialog/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.dialog/1","doc":"* `id` (`:string`) (required) - Dialog element id. Use to toggle from the outside. Required in order to derive a consistent focus wrap ID.\n* `form` (`:any`) - To maintain the open state when using the dialog element inside a form, pass the form surrounding the dialog element.\n  Either a [Phoenix.HTML.Form](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html) or an atom.\n\n* `field` (`:any`) - Field name (atom or string). Use an atom when used with a form.\n  To maintain the open state when using the dialog inside a form, see: [Menus and dialogs](doc-extra/menus-and-dialogs.md).\n\n* `is_dropdown_caret` (`:boolean`) - Adds a dropdown caret to the prompt button. Defaults to `false`.\n* `is_backdrop` (`:boolean`) - Generates a backdrop background (default with medium darkness). Defaults to `false`.\n* `is_dark_backdrop` (`:boolean`) - Generates a darker backdrop background color. Defaults to `false`.\n* `is_medium_backdrop` (`:boolean`) - Generates a medium backdrop background color. Defaults to `false`.\n* `is_light_backdrop` (`:boolean`) - Generates a lighter backdrop background color. Default for menus. Defaults to `false`.\n* `is_fast` (`:boolean`) - Generates fast fade transitions for backdrop and content. Defaults to `false`.\n* `prompt_options` (`:string`) - JavaScript state callback functions as string. For example:\n\n  ```\n  \"{\n    willShow: function(elements) { console.log('willShow', elements) },\n    didShow: function(elements) { console.log('didShow', elements) },\n    willHide: function(elements) { console.log('willHide', elements) },\n    didHide: function(elements) { console.log('didHide', elements) }\n  }\"\n  ```\n\n* `phx_click_touch` (`:any`) - `phx-click` event binding to assign an event callback on clicking the touch layer.\n  Ignored if `is_modal` is true.\n\n* `is_modal` (`:boolean`) - Generates a modal the dialog; clicking the backdrop (if used) or outside of the dialog will not close the dialog. Defaults to `false`.\n* `is_escapable` (`:boolean`) - Closes the content when pressing the Escape key. Defaults to `false`.\n* `focus_first` (`:string`) - Focus the first element after opening the dialog. Pass a selector to match the element.\n* `is_show_on_mount` (`:boolean`) - Displays the dialog on mount. Control conditional display by using the regular `:if={}` attribute. Defaults to `false`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for dialog elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    # Dialog classes\n    dialog_wrapper: \"\",  # The outer element\n    dialog: \"\",          # Dialog element\n    # Box classes - see box component:\n    box: \"\",\n    header: \"\",\n    row: \"\",\n    body: \"\",\n    footer: \"\",\n    header_title: \"\",\n    link: \"\",\n  }\n  ```\n\n  Defaults to `%{link: nil, header: nil, body: nil, box: nil, dialog: nil, row: nil, footer: nil, header_title: nil, dialog_wrapper: nil}`.\n* `is_narrow` (`:boolean`) - Generates a smaller dialog, width: `320px` (default: `440px`). Defaults to `false`.\n* `is_wide` (`:boolean`) - Generates a wider dialog, width: `640px` (default: `440px`). Defaults to `false`.\n* `max_height` (`:string`) - Maximum height of the dialog as CSS value. Use unit `vh` or `%`. Defaults to `\"80vh\"`.\n* `max_width` (`:string`) - Maximum width of the dialog as CSS value. Use unit `vh` or `%`. Defaults to `\"90vw\"`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#dialog/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.dialog/1","doc":"* `header_title` - Dialog header title. Uses `box/1` `header_title` slot.\n\n  Note that slot `header` is automatically created to ensure the correct close button.\n\n  Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `body` - Dialog body. Uses `box/1` `body` slot. Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `row` - Dialog row. Uses `box/1` `row` slot. Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `footer` - Dialog footer. Uses `box/1` `footer` slot. Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `inner_block` - Unstructured dialog content. Uses `box/1` `inner_block` slot.","ref":"PrimerLive.Component.html#dialog/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.dialog/1","doc":"[Primer Dialog](https://primer.style/design/components/dialog)","ref":"PrimerLive.Component.html#dialog/1-reference"},{"type":"function","title":"PrimerLive.Component.drawer/1","doc":"Generates a drawer with configuration options for backdrop, position and behavior.\n\n```\n<.drawer>\n  <:body>\n    Content\n  </:body>\n</.drawer>\n```\n\nShowing and hiding is done with JS function `Prompt`, included in PrimerLive.\nFunction `Prompt.show` requires a selector. When placed inside the drawer component, the selector can be replaced with `this`:\n\n```\n<.drawer id=\"my-drawer\">\n  <:body>\n    <.button onclick=\"Prompt.hide(this)\">Close</.button>\n    Content\n  </:body>\n</.drawer>\n\n<.button onclick=\"Prompt.show('#my-drawer')\">Open drawer</.button>\n```","ref":"PrimerLive.Component.html#drawer/1"},{"type":"function","title":"Examples - PrimerLive.Component.drawer/1","doc":"By default the drawer width is defined by its content. To set an explicit width of the drawer content:\n\n```\n<.drawer>\n  <:body width=\"300px\">\n    ...\n  </:body>\n</.drawer>\n```\n\nAdd a backdrop. Optionally add `is_light_backdrop` or `is_dark_backdrop`:\n\n```\n<.drawer is_backdrop is_dark_backdrop>\n  ...\n</.drawer>\n```\n\nCreate a modal drawer; clicking the backdrop (if used) or outside of the drawer will not close the drawer:\n\n```\n<.drawer is_modal>\n  ...\n</.drawer>\n```\n\nClose the drawer with the Escape key:\n\n```\n<.drawer is_escapable>\n  ...\n</.drawer>\n```\n\nCreate faster slide in and out:\n\n```\n<.drawer is_fast>\n  ...\n</.drawer>\n```\n\nFocus the first element after opening the drawer. Pass a selector to match the element.\n\n```\n<.drawer focus_first=\"#login_first_name\">\n  ...\n</.drawer>\n```\n\nor\n\n```\n<.drawer focus_first=\"[name=login\\[first_name\\]]\">\n  ...\n</.drawer>\n```\n\nCreate a local drawer (inside a container) with `is_local`:\n\n```\n \n  Page content\n  <.drawer is_local>\n    <:body>\n      Content\n    </:body>\n  </.drawer>\n \n```\n\nCreate a push drawer - where the drawer content pushes the adjacent content aside when it opens - with attr `is_push` and the content to be pushed inside `<.drawer>`:\n\n```\n \n  <.drawer is_push>\n    Page content\n    <:body>\n      Content\n    </:body>\n  </.drawer>\n \n```","ref":"PrimerLive.Component.html#drawer/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.drawer/1","doc":"* `id` (`:string`) (required) - Drawer element id. Use to toggle from the outside. Required in order to derive a consistent focus wrap ID.\n* `form` (`:any`) - To maintain the open state when using the drawer element inside a form, pass the form surrounding the drawer element.\n  Either a [Phoenix.HTML.Form](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html) or an atom.\n\n* `field` (`:any`) - Field name (atom or string). Use an atom when used with a form.\n  To maintain the open state when using the drawer inside a form, see: [Menus and dialogs](doc-extra/menus-and-dialogs.md).\n\n* `is_dropdown_caret` (`:boolean`) - Adds a dropdown caret to the prompt button. Defaults to `false`.\n* `is_backdrop` (`:boolean`) - Generates a backdrop background (default with medium darkness). Defaults to `false`.\n* `is_dark_backdrop` (`:boolean`) - Generates a darker backdrop background color. Defaults to `false`.\n* `is_medium_backdrop` (`:boolean`) - Generates a medium backdrop background color. Defaults to `false`.\n* `is_light_backdrop` (`:boolean`) - Generates a lighter backdrop background color. Default for menus. Defaults to `false`.\n* `is_fast` (`:boolean`) - Generates fast fade transitions for backdrop and content. Defaults to `false`.\n* `prompt_options` (`:string`) - JavaScript state callback functions as string. For example:\n\n  ```\n  \"{\n    willShow: function(elements) { console.log('willShow', elements) },\n    didShow: function(elements) { console.log('didShow', elements) },\n    willHide: function(elements) { console.log('willHide', elements) },\n    didHide: function(elements) { console.log('didHide', elements) }\n  }\"\n  ```\n\n* `phx_click_touch` (`:any`) - `phx-click` event binding to assign an event callback on clicking the touch layer.\n  Ignored if `is_modal` is true.\n\n* `is_modal` (`:boolean`) - Generates a modal the drawer; clicking the backdrop (if used) or outside of the drawer will not close the drawer. Defaults to `false`.\n* `is_escapable` (`:boolean`) - Closes the content when pressing the Escape key. Defaults to `false`.\n* `focus_first` (`:string`) - Focus the first element after opening the drawer. Pass a selector to match the element.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for drawer elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    drawer_wrapper: \"\",  # The outer element\n    drawer: \"\",          # Drawer element\n    body: \"\",            # Drawer content element\n  }\n  ```\n\n  Defaults to `%{body: nil, drawer: nil, drawer_wrapper: nil}`.\n* `is_far_side` (`:boolean`) - Opens the drawer at the far end of the reading direction. Defaults to `false`.\n* `is_local` (`:boolean`) - Adds styles for a drawer inside a a container. Defaults to `false`.\n* `is_push` (`:boolean`) - Adds styles for a push drawer inside a a container. Defaults to `false`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#drawer/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.drawer/1","doc":"* `body` - Drawer body. Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n  * `width` (`:string`) - Sets the width of the drawer as CSS value. Add unit `px` or `rem` or other size unit.\n\n    By default the drawer width is defined by its content.\n\n  * `style` (`:string`)\n  * `rest` (`:any`)\n* `inner_block` - Drawer content and any adjacent elements. Use slot `body` for the content to be displayed inside the drawer.","ref":"PrimerLive.Component.html#drawer/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.drawer/1","doc":"Neither Primer CSS nor Primer React provide a drawer component. However, a drawer is used on their documentation site (mobile view).","ref":"PrimerLive.Component.html#drawer/1-reference"},{"type":"function","title":"PrimerLive.Component.drawer_content/1","doc":"Drawer content (DEPRECATED).\n\nUse `:body` slot with `drawer/1`.","ref":"PrimerLive.Component.html#drawer_content/1"},{"type":"function","title":"Attributes - PrimerLive.Component.drawer_content/1","doc":"* `width` (`:string`) - Sets the width of the drawer as CSS value. Add unit `px` or `rem` or other size unit.\n\n  By default the drawer width is defined by its content.\n\n  Defaults to `nil`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#drawer_content/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.drawer_content/1","doc":"* `inner_block` - Drawer content.","ref":"PrimerLive.Component.html#drawer_content/1-slots"},{"type":"function","title":"PrimerLive.Component.dropdown/1","doc":"Generates a dropdown menu - a small context menu that can be used for navigation and actions. It is a simple alternative to [`select menus`](`select_menu/1`).\n\nMenu items are rendered as link element.\n\n```\n<.dropdown>\n  <:toggle>Menu</:toggle>\n  <:item href=\"#url\">Item 1</:item>\n  <:item href=\"#url\">Item 2</:item>\n</.dropdown>\n```","ref":"PrimerLive.Component.html#dropdown/1"},{"type":"function","title":"Examples - PrimerLive.Component.dropdown/1","doc":"Menu links are created with `Phoenix.Component.link/1`, passing all other slot attributes to the link. Link examples:\n\n```\n<:item href=\"#url\">href link</:item>\n<:item navigate={Routes.page_path(@socket, :index)}>navigate link</:item>\n<:item patch={Routes.page_path(@socket, :index)}>patch link</:item>\n```\n\nAdd a menu title by passing `title` to the `menu` slot:\n\n```\n<.dropdown>\n  <:toggle>Menu</:toggle>\n  <:menu title=\"Menu title\" />\n  ...\n</.dropdown>\n```\n\nChange the position of the menu relative to the dropdown toggle:\n\n```\n<:menu position=\"e\" />\n```\n\nCreate dividers with `item` slot attribute `is_divider`. A divider cannot have contents.\n\n```\n<.dropdown>\n  <:toggle>Menu</:toggle>\n  ...\n  <:item is_divider />\n  ...\n</.dropdown>\n```","ref":"PrimerLive.Component.html#dropdown/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.dropdown/1","doc":"* `id` (`:string`) - Dropdown element id. Use to toggle from the outside, and to get consistent IDs in tests.\n  If not set, an id is generated, either based on `form` and `field`, or otherwise randomly.\n\n* `form` (`:any`) - To maintain the open state when using the dropdown element inside a form, pass the form surrounding the dropdown element.\n  Either a [Phoenix.HTML.Form](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html) or an atom.\n\n* `field` (`:any`) - Field name (atom or string). Use an atom when used with a form.\n  To maintain the open state when using the dropdown inside a form, see: [Menus and dialogs](doc-extra/menus-and-dialogs.md).\n\n* `is_dropdown_caret` (`:boolean`) - Adds a dropdown caret to the prompt button. Defaults to `true`.\n* `is_backdrop` (`:boolean`) - Generates a backdrop background (default with medium darkness). Defaults to `false`.\n* `is_dark_backdrop` (`:boolean`) - Generates a darker backdrop background color. Defaults to `false`.\n* `is_medium_backdrop` (`:boolean`) - Generates a medium backdrop background color. Defaults to `false`.\n* `is_light_backdrop` (`:boolean`) - Generates a lighter backdrop background color. Default for menus. Defaults to `false`.\n* `is_fast` (`:boolean`) - Generates fast fade transitions for backdrop and content. Defaults to `true`.\n* `prompt_options` (`:string`) - JavaScript state callback functions as string. For example:\n\n  ```\n  \"{\n    willShow: function(elements) { console.log('willShow', elements) },\n    didShow: function(elements) { console.log('didShow', elements) },\n    willHide: function(elements) { console.log('willHide', elements) },\n    didHide: function(elements) { console.log('didHide', elements) }\n  }\"\n  ```\n\n* `phx_click_touch` (`:any`) - `phx-click` event binding to assign an event callback on clicking the touch layer.\n  Ignored if `is_modal` is true.\n\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for dropdown elements.\n\n  Any provided value will be appended to the default classname, except for `toggle` that will override the default class \"btn\".\n\n  Default map:\n  ```\n  %{\n    caret: \"\",    # Arrow in toggle button\n    divider: \"\",  # List divider item (li element)\n    dropdown: \"\", # Dropdown wrapper\n    header: \"\",   # Menu header\n    item: \"\",     # Link item, placed inside li element\n    menu: \"\",     # List container (ul element)\n    toggle: \"\"    # Toggle (open) button\n  }\n  ```\n\n  Defaults to `%{header: nil, item: nil, menu: nil, divider: nil, caret: nil, dropdown: nil, toggle: nil}`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#dropdown/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.dropdown/1","doc":"* `toggle` (required) - Generates a toggle element (default with button appearance) using the slot content as label.\n\n  Any custom class will override the default class \"btn\".\n\n  Accepts attributes:\n\n  * `options` (`:string`) - Deprecated: pass the attrs to the dropdown component as `prompt_options`.\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`) - Additional HTML attributes added to the item element.\n* `menu` - Generates a menu element. Accepts attributes:\n\n  * `title` (`:string`) - Generates a menu header with specified title.\n  * `position` (`:string`) - Position of the menu relative to the dropdown toggle.\n\n    Default: \"se\".\nMust be one of `\"se\"`, `\"ne\"`, `\"e\"`, `\"sw\"`, `\"s\"`, or `\"w\"`.\n* `item` (required) - Menu item content. To create a link element, pass attribute `href`, `navigate` or `patch`. Accepts attributes:\n\n  * `is_divider` (`:boolean`) - Generates a divider element.\n  * `href` (`:any`) - Link attribute. The link is created with `Phoenix.Component.link/1`, passing all other slot attributes to the link.\n  * `patch` (`:string`) - Link attribute - see `href`.\n  * `navigate` (`:string`) - Link attribute - see `href`.\n  * `phx_click` (`:string`) - See https://hexdocs.pm/phoenix_live_view/bindings.html.\n  * `name` (`:string`)\n  * `type` (`:string`)\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)","ref":"PrimerLive.Component.html#dropdown/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.dropdown/1","doc":"[Primer Dropdown](https://primer.style/design/components/dropdown)","ref":"PrimerLive.Component.html#dropdown/1-reference"},{"type":"function","title":"PrimerLive.Component.filter_list/1","doc":"Generates a vertical list of filters.\n\nFilter list items are rendered as link element.\n\n```\n<.filter_list aria_label=\"Menu\">\n  <:item href=\"#url\" is_selected>\n    One\n  </:item>\n  <:item href=\"#url\">\n    Two\n  </:item>\n  <:item href=\"#url\">\n    Three\n  </:item>\n</.filter_list>\n```","ref":"PrimerLive.Component.html#filter_list/1"},{"type":"function","title":"Examples - PrimerLive.Component.filter_list/1","doc":"Filter links are created with `Phoenix.Component.link/1`, passing all other slot attributes to the link. Link examples:\n\n```\n<:item href=\"#url\">href link</:item>\n<:item navigate={Routes.page_path(@socket, :index)}>navigate link</:item>\n<:item patch={Routes.page_path(@socket, :index)}>patch link</:item>\n```\n\nAdd counts to the links:\n\n```\n<.filter_list aria_label=\"Menu\">\n  <:item href=\"#url\" is_selected count=\"99\">\n    First filter\n  </:item>\n  <:item href=\"#url\" count={3}>\n    Second filter\n  </:item>\n  <:item href=\"#url\">\n    Third filter\n  </:item>\n</.filter_list>\n```","ref":"PrimerLive.Component.html#filter_list/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.filter_list/1","doc":"* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for filter list elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    filter_list: \"\", # Outer container (ul element)\n    item: \"\",        # Filter list item element (a element)\n    count: \"\",       # Filter list item count element (span element)\n  }\n  ```\n\n  Defaults to `%{count: nil, item: nil, filter_list: nil}`.\n* `aria_label` (`:string`) - Adds attribute `aria-label` to the outer element. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#filter_list/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.filter_list/1","doc":"* `item` (required) - Filter list item content. To create a link element, pass attribute `href`, `navigate` or `patch`. Accepts attributes:\n\n  * `is_selected` (`:boolean`) - Shows the selected state.\n  * `count` (`:any`) - Integer or string. Displays a number at the far end of the filter link.\n  * `href` (`:any`) - Link attribute. The link is created with `Phoenix.Component.link/1`, passing all other slot attributes to the link.\n  * `patch` (`:string`) - Link attribute - see `href`.\n  * `navigate` (`:string`) - Link attribute - see `href`.\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)","ref":"PrimerLive.Component.html#filter_list/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.filter_list/1","doc":"No longer mentioned on https://primer.style/design/components","ref":"PrimerLive.Component.html#filter_list/1-reference"},{"type":"function","title":"PrimerLive.Component.form_control/1","doc":"Helper component that generates a form control: a wrapper around a form input that maintains consistent layout and a field label. Form control is used by other components, and you probably won't need to use it standalone.\n\nUsed with `text_input/1`, `textarea/1` and `select/1`.\n\nAutomatically adds a label based on supplied form and field (with the option to set a custom label) and a required mark if the field is required.\n\nUnlike Primer Style, the form control component does not provide validation messages and captions - these can also be added to the input element without a form control.\n\nUsing `form_control` standalone:\n```\n<.form_control field=\"first_name\">\n  <.text_input field=\"first_name\" />\n</.form_control>\n```\n\nThis is equivalent to:\n```\n<.text_input field=\"first_name\" is_form_control />\n```","ref":"PrimerLive.Component.html#form_control/1"},{"type":"function","title":"Examples - PrimerLive.Component.form_control/1","doc":"With a `PhoenixHTMLHelpers.Form`:\n\n```\n<.form let={f} for={@changeset} phx-change=\"validate\" phx-submit=\"save\">\n  <.form_control form={f} field={:first_name}>\n    <.text_input\n      form={f}\n      field={:first_name}\n      phx_debounce=\"blur\"\n    />\n  </.form_control>\n</.form>\n```\n\nCustom label:\n\n```\n<.form_control form={f} field={:first_name} label=\"Enter your first name\">\n...\n</.form_control>\n```\n\nHide the label:\n\n```\n<.form_control form={f} field={:first_name} is_hide_label>\n...\n</.form_control>\n```","ref":"PrimerLive.Component.html#form_control/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.form_control/1","doc":"* `form` (`:any`) - Either a [Phoenix.HTML.Form](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html) or an atom. Defaults to `nil`.\n* `field` (`:any`) - Field name (atom or string). Defaults to `nil`.\n* `is_input_group` (`:boolean`) - Creates styling for `checkbox_group/1` and `radio_group/1`: a larger label font size, and layout for inputs, captions and validation. Defaults to `false`.\n* `caption` (`:any`) - Hint message below the form control label.\n\n  Pass a string, or a function that returns a string.\n\n  The function receives a `PrimerLive.FieldState` struct and returns a message or nil (which omits the caption element).\n\n  Function signatures:\n  - `fun () -> string | nil`\n  - `fun (field_state) -> string | nil`\n\n  To conditionally show a caption, use `field_state`. To show the caption when field state is valid:\n  ```\n  fn field_state ->\n    if !field_state.valid?, do: nil, else: \"Caption\"\n  end\n  ```\n\n  For additional markup, use the `H` sigil:\n  ```\n  fn ->\n    ~H'''\n    Caption with  link \n    '''\n  end\n  ```\n\n  Defaults to `nil`.\n* `label` (`:string`) - Custom label. Note that a label is automatically generated when using `field`. Defaults to `nil`.\n* `is_hide_label` (`:boolean`) - Omits the automatically generated label (when using `field`). Defaults to `false`.\n* `is_disabled` (`:boolean`) - Adjusts the styling to indicate disabled state. Defaults to `false`.\n* `required_marker` (`:string`) - Required field marking. This will be shown for all required fields (when using `Phoenix.HTML.Form`). Pass an empty string to remove the indicator. Defaults to `\"*\"`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for form control elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    control: \"\",               # Form control wrapper\n    group: \"\",                 # Deprecation support: identical to \"control\"\n    header: \"\",                # Header element containing the group label\n    label: \"\",                 # Form control label\n    input_group_container: \"\", # Input group container (for checkbox_group and radio_group)\n    caption: \"\",               # Form control caption\n  }\n  ```\n\n  Defaults to `%{control: nil, label: nil, header: nil, group: nil, caption: nil, input_group_container: nil}`.\n* `deprecated_has_form_group` (`:boolean`) - Internal use: detects if deprecated `form_group` or `is_form_group` is used. Used to maintain consistent styling. Defaults to `false`.\n* `for` (`:string`) - Internally used by `text_input/1` and `textarea/1` when using `is_form_control` or `form_control`. Label attribute to associate the label with the input. `for` should be the same as the input's `id`. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#form_control/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.form_control/1","doc":"* `inner_block` (required) - The form control content.","ref":"PrimerLive.Component.html#form_control/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.form_control/1","doc":"[Primer Form control](https://primer.style/design/components/form-control)","ref":"PrimerLive.Component.html#form_control/1-reference"},{"type":"function","title":"PrimerLive.Component.form_group/1","doc":"","ref":"PrimerLive.Component.html#form_group/1"},{"type":"function","title":"Attributes - PrimerLive.Component.form_group/1","doc":"* `form` (`:any`) - Either a [Phoenix.HTML.Form](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html) or an atom. Defaults to `nil`.\n* `field` (`:any`) - Field name (atom or string). Defaults to `nil`.\n* `is_input_group` (`:boolean`) - Creates styling for `checkbox_group/1` and `radio_group/1`: a larger label font size, and layout for inputs, captions and validation. Defaults to `false`.\n* `caption` (`:any`) - Hint message below the form group label.\n\n  Pass a string, or a function that returns a string.\n\n  The function receives a `PrimerLive.FieldState` struct and returns a message or nil (which omits the caption element).\n\n  Function signatures:\n  - `fun () -> string | nil`\n  - `fun (field_state) -> string | nil`\n\n  To conditionally show a caption, use `field_state`. To show the caption when field state is valid:\n  ```\n  fn field_state ->\n    if !field_state.valid?, do: nil, else: \"Caption\"\n  end\n  ```\n\n  For additional markup, use the `H` sigil:\n  ```\n  fn ->\n    ~H'''\n    Caption with  link \n    '''\n  end\n  ```\n\n  Defaults to `nil`.\n* `label` (`:string`) - Custom label. Note that a label is automatically generated when using `field`. Defaults to `nil`.\n* `is_hide_label` (`:boolean`) - Omits the automatically generated label (when using `field`). Defaults to `false`.\n* `is_disabled` (`:boolean`) - Adjusts the styling to indicate disabled state. Defaults to `false`.\n* `required_marker` (`:string`) - Required field marking. This will be shown for all required fields (when using `Phoenix.HTML.Form`). Pass an empty string to remove the indicator. Defaults to `\"*\"`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for form group elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    control: \"\",               # Form group wrapper\n    group: \"\",                 # Deprecation support: identical to \"control\"\n    header: \"\",                # Header element containing the group label\n    label: \"\",                 # Form group label\n    input_group_container: \"\", # Input group container (for checkbox_group and radio_group)\n    caption: \"\",               # Form group caption\n  }\n  ```\n\n  Defaults to `%{control: nil, label: nil, header: nil, group: nil, caption: nil, input_group_container: nil}`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#form_group/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.form_group/1","doc":"* `inner_block` (required) - The form group content.","ref":"PrimerLive.Component.html#form_group/1-slots"},{"type":"function","title":"PrimerLive.Component.header/1","doc":"Generates a navigational header, to be placed at the top of the page.\n\n```\n<.header>\n  <:item>Item 1</:item>\n  <:item>Item 2</:item>\n  <:item>Item 3</:item>\n</.header>\n```","ref":"PrimerLive.Component.html#header/1"},{"type":"function","title":"Examples - PrimerLive.Component.header/1","doc":"Stretch an item with attribute `is_full_width`:\n\n```\n <:item is_full_width>Stretched item</:item>\n```\n\nA space can also be generated with an \"empty\" item:\n\n```\n<:item is_full_width />\n```\n\nLinks can be placed inside items. Use `:let` to get access to the `classes.link` class. With `Phoenix.Component.link/1`:\n\n```\n<:item :let={classes}>\n  <.link href=\"/\" class={classes.link}>Regular anchor link</.link>\n</:item>\n<:item :let={classes}>\n  <.link navigate={Routes.page_path(@socket, :index)} class={[classes.link, \"underline\"]}>Home</.link>\n</:item>\n```\n\nInputs can be placed in the same way, using `:let` to get access to the `classes.input` class:\n\n```\n<:item :let={classes}>\n  <.text_input form={:user} field={:first_name} type=\"search\" class={classes.input} />\n</:item>\n```","ref":"PrimerLive.Component.html#header/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.header/1","doc":"* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for header elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    header: \"\", # The wrapping element\n    item: \"\",   # Header item element\n    link: \"\",   # Link inside an item\n    input: \"\",  # Input element inside an item\n  }\n  ```\n\n  Defaults to `%{link: nil, header: nil, item: nil}`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#header/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.header/1","doc":"* `item` - Header item. Accepts attributes:\n\n  * `is_full_width` (`:boolean`) - Stretches the item to maximum.\n  * `is_full` (`:boolean`) - Deprecated: use is_full_width.\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)","ref":"PrimerLive.Component.html#header/1-slots"},{"type":"function","title":"Lets - PrimerLive.Component.header/1","doc":"```\n<:item :let={classes} />\n```\n\nYields a `classes` map, containing the merged values of default classnames, plus any value supplied to the `classes` component attribute.\n\n```\n<.header classes={%{ link: \"link-x\" }}>\n  <:item :let={classes}>\n    <.link href=\"/\" class={[\"my-link\", classes.link]}>Home</.link>\n  </:item>\n</.header>\n```\n\nResults in:\n\n```\n \n   \n     Home \n   \n \n```","ref":"PrimerLive.Component.html#header/1-lets"},{"type":"function","title":"Reference - PrimerLive.Component.header/1","doc":"[Primer Header](https://primer.style/design/components/header)","ref":"PrimerLive.Component.html#header/1-reference"},{"type":"function","title":"PrimerLive.Component.input_validation_message/1","doc":"Generates a validation message for a form input. It can be used as standalone component for inputs where the position of the validation feedback is not so obvious.\n\nThis component is incorporated in \"singular inputs\" `text_input/1`, `textarea/1` and `select/1`.\n\nA validation error message is automatically added when using a changeset with an error state. The message text is taken from the changeset errors.\n\n\nTo show the default validation message:\n\n```\n<.form let={f} for={@changeset} phx-change=\"validate\" phx-submit=\"save\">\n  <!-- INPUTS -->\n  <.input_validation_message form={@form} field={:availability} />\n</.form>\n```\n\nTo show a custom error message:\n\n```\n<.form let={f} for={@changeset} phx-change=\"validate\" phx-submit=\"save\">\n  <!-- INPUTS -->\n  <.input_validation_message\n    form={@form}\n    field={:availability}\n    validation_message={\n      fn field_state ->\n        if !field_state.valid?, do: \"Please select your availability\"\n      end\n    }\n  />\n</.form>\n```\n\nSimilarly, to show a custom validation success message:\n\n```\n<.form let={f} for={@changeset} phx-change=\"validate\" phx-submit=\"save\">\n  <!-- INPUTS -->\n  <.input_validation_message\n    form={@form}\n    field={:availability}\n    validation_message={\n      fn field_state ->\n        if field_state.valid?, do: \"Great!\"\n      end\n    }\n  />\n</.form>\n```","ref":"PrimerLive.Component.html#input_validation_message/1"},{"type":"function","title":"Reference - PrimerLive.Component.input_validation_message/1","doc":"[Primer Form control](https://primer.style/design/components/form-control)","ref":"PrimerLive.Component.html#input_validation_message/1-reference"},{"type":"function","title":"Attributes - PrimerLive.Component.input_validation_message/1","doc":"* `form` (`:any`) - Either a [Phoenix.HTML.Form](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html) or an atom. Defaults to `nil`.\n* `field` (`:any`) - Field name (atom or string). Defaults to `nil`.\n* `input_id` (`:string`) - When using form/field. Custom input ID to be used in case the generated IDs cause \"Multiple IDs detected\" errors. Defaults to `nil`.\n* `validation_message` (`:any`) - Function to write a custom validation message (in case of error or success).\n\n  The function receives a `PrimerLive.FieldState` struct and returns a validation message or nil.\n\n  A validation message is shown:\n  - If form is a `Phoenix.HTML.Form`, containing a `changeset`\n  - The `validation_message` function does not return nil\n\n  Function signatures:\n  - `fun () -> string | nil`\n  - `fun (field_state) -> string | nil`\n\n  Conditional error message:\n  ```\n  fn field_state ->\n    if !field_state.valid?, do: \"Please enter your first name\"\n  end\n  ```\n\n  Conditional success message, only shown when `changeset.action` is `:validate`:\n  ```\n  fn field_state ->\n    if field_state.valid? && field_state.changeset.action == :validate, do: \"Is available\"\n  end\n  ```\n\n  Defaults to `nil`.\n* `validation_message_id` (`:any`) - Message ID that is usually passed from the form element component to `input_validation_message`. If not used, the ID will be generated.\n* `is_multiple` (`:boolean`) - Set to true when the validation message refers to a \"multiple\" field, to that the generated ID will include suffix `[]`. Defaults to `false`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#input_validation_message/1-attributes"},{"type":"function","title":"PrimerLive.Component.issue_label/1","doc":"Issue labels are used for adding labels to issues and pull requests. They also come with emoji support.\n\nAnd issue label is basically labels without a border. It expects background and foreground colors.\n\n```\n<.issue_label>Label</.issue_label>\n```","ref":"PrimerLive.Component.html#issue_label/1"},{"type":"function","title":"Examples - PrimerLive.Component.issue_label/1","doc":"Add colors:\n\n```\n<.issue_label color-bg-accent-emphasis color-fg-on-emphasis>Label</.issue_label>\n```\n\nLarger label:\n\n```\n<.issue_label is_big>Label</.issue_label>\n```","ref":"PrimerLive.Component.html#issue_label/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.issue_label/1","doc":"* `is_big` (`:boolean`) - Larger issue label. Defaults to `false`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#issue_label/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.issue_label/1","doc":"* `inner_block` (required) - Label content.","ref":"PrimerLive.Component.html#issue_label/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.issue_label/1","doc":"[Primer Labels](https://primer.style/design/components/labels)","ref":"PrimerLive.Component.html#issue_label/1-reference"},{"type":"function","title":"PrimerLive.Component.label/1","doc":"Generates a label element to add metadata or indicate status of items and navigational elements.\n\n```\n<.label>Label</.label>\n```\n\nWhen using `label` alongside `PhoenixHTMLHelpers.Form.label/2`, use a prefix, for example:\n\n```\nuse PrimerLive\nalias PrimerLive.Component, as: Primer\n...\n Label \n```","ref":"PrimerLive.Component.html#label/1"},{"type":"function","title":"Examples - PrimerLive.Component.label/1","doc":"Create a colored label:\n\n```\n<.label is_success>Label</.label>\n```\n\nCreate a larger label:\n\n```\n<.label is_large>Label</.label>\n```\n\nCreate an inline label:\n\n```\n Lorem Ipsum is simply <.label is_inline>dummy text</.label> of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text. \n```","ref":"PrimerLive.Component.html#label/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.label/1","doc":"* `is_primary` (`:boolean`) - Generates a label with a stronger border. Defaults to `false`.\n* `is_secondary` (`:boolean`) - Generates a label with a subtler text color. Defaults to `false`.\n* `is_accent` (`:boolean`) - Accent color. Defaults to `false`.\n* `is_success` (`:boolean`) - Success color. Defaults to `false`.\n* `is_attention` (`:boolean`) - Attention color. Defaults to `false`.\n* `is_severe` (`:boolean`) - Severe color. Defaults to `false`.\n* `is_danger` (`:boolean`) - Danger color. Defaults to `false`.\n* `is_open` (`:boolean`) - Open color. Defaults to `false`.\n* `is_closed` (`:boolean`) - Closed color. Defaults to `false`.\n* `is_done` (`:boolean`) - Done color. Defaults to `false`.\n* `is_sponsors` (`:boolean`) - Sponsors color. Defaults to `false`.\n* `is_large` (`:boolean`) - Larger label. Defaults to `false`.\n* `is_inline` (`:boolean`) - For use in running text. Adapts line height and font size to text. Defaults to `false`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#label/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.label/1","doc":"* `inner_block` (required) - Label content.","ref":"PrimerLive.Component.html#label/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.label/1","doc":"[Primer Label](https://primer.style/design/components/label)","ref":"PrimerLive.Component.html#label/1-reference"},{"type":"function","title":"PrimerLive.Component.layout/1","doc":"Layout provides foundational patterns for responsive pages.\n\n```\n<.layout>\n  <:main>\n    Main content\n  </:main>\n  <:sidebar>\n    Sidebar content\n  </:sidebar>\n</.layout>\n```","ref":"PrimerLive.Component.html#layout/1"},{"type":"function","title":"Examples - PrimerLive.Component.layout/1","doc":"The position of the sidebar (left or right on desktop) is set by CSS (and can be changed with attribute `is_sidebar_position_end`).\n\nTo place the sidebar at the right:\n\n```\n<.layout is_sidebar_position_end>\n  <:main>\n    Main content\n  </:main>\n  <:sidebar>\n    Sidebar content\n  </:sidebar>\n</.layout>\n```\n\nTo place the sidebar slot below the main slot on small screens, use attribute `is_sidebar_position_flow_row_end`:\n\n```\n<.layout is_sidebar_position_flow_row_end>\n  <:main>\n    Main content\n  </:main>\n  <:sidebar>\n    Sidebar content\n  </:sidebar>\n</.layout>\n```\n\nWhen using a divider, use attribute `is_divided` to make the divider element visible.\n\nExtra divider modifiers for vertical layout (on small screens):\n\n- `is_divided` creates a 1px border between main and sidebar\n- `is_divided` with `is_flow_row_hidden` hides the divider\n- `is_divided` with `is_flow_row_shallow` shows a filled 8px divider\n\n```\n<.layout is_divided>\n  <:main>\n    Main content\n  </:main>\n  <:divider></:divider>\n  <:sidebar>\n    Sidebar content\n  </:sidebar>\n</.layout>\n```\n\nThe modifiers `is_centered_xx` create a wrapper around `main` to center its content up to a maximum width.\nUse with `.container-xx` classes to restrict the size of the content:\n\n```\n<.layout is_centered_md>\n  <:main>\n     \n      Centered md\n     \n  </:main>\n  <:sidebar>\n    Sidebar content\n  </:sidebar>\n</.layout>\n```\n\nLayouts can be nested.\n\nNested layout, example 1:\n\n```\n<.layout>\n  <:main>\n    <.layout is_sidebar_position_end is_narrow_sidebar>\n      <:main>\n        Main content\n      </:main>\n      <:sidebar>\n        Metadata sidebar\n      </:sidebar>\n    </.layout>\n  </:main>\n  <:sidebar>\n    Default sidebar\n  </:sidebar>\n</.layout>\n```\n\nNested layout, example 2:\n\n```\n<.layout>\n  <:main>\n    <.layout is_sidebar_position_end is_flow_row_until_lg is_narrow_sidebar>\n      <:main>\n        Main content\n      </:main>\n      <:sidebar>\n        Metadata sidebar\n      </:sidebar>\n    </.layout>\n  </:main>\n  <:sidebar>\n    Default sidebar\n  </:sidebar>\n</.layout>\n```","ref":"PrimerLive.Component.html#layout/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.layout/1","doc":"* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for layout elements.\n\n    Any provided value will be appended to the default classname.\n\n    Default map:\n    ```\n    %{\n      layout: \"\",               # Layout wrapper\n      main: \"\",                 # Main element\n      main_center_wrapper: \"\",  # Wrapper for displaying content centered\n      sidebar: \"\",              # Sidebar element\n      divider: \"\",              # Divider element\n    }\n    ```\n\n  Defaults to `%{main: nil, layout: nil, main_center_wrapper: nil, sidebar: nil, divider: nil}`.\n* `is_divided` (`:boolean`) - Use `is_divided` in conjunction with the `layout_item/1` element with attribute `divider` to show a divider between the main content and the sidebar. Generates a 1px line between main and sidebar. Defaults to `false`.\n* `is_narrow_sidebar` (`:boolean`) - Smaller sidebar size. Widths: md: 240px, lg: 256px. Defaults to `false`.\n* `is_wide_sidebar` (`:boolean`) - Wider sidebar size. Widths: md: 296px, lg: 320px, xl: 344px. Defaults to `false`.\n* `is_gutter_none` (`:boolean`) - Changes the gutter size to 0px. Defaults to `false`.\n* `is_gutter_condensed` (`:boolean`) - Changes the gutter size to 16px. Defaults to `false`.\n* `is_gutter_spacious` (`:boolean`) - Changes the gutter sizes to: md: 16px, lg: 32px, xl: 40px. Defaults to `false`.\n* `is_sidebar_position_start` (`:boolean`) - Places the sidebar at the start (commonly at the left) (default). Defaults to `false`.\n* `is_sidebar_position_end` (`:boolean`) - Places the sidebar at the end (commonly at the right) on desktop. Defaults to `false`.\n* `is_sidebar_position_flow_row_start` (`:boolean`) - When stacked, render the sidebar first (default). Defaults to `false`.\n* `is_sidebar_position_flow_row_end` (`:boolean`) - When stacked, render the sidebar last. Defaults to `false`.\n* `is_sidebar_position_flow_row_none` (`:boolean`) - When stacked, hide the sidebar. Defaults to `false`.\n* `is_flow_row_until_md` (`:boolean`) - Stacks when container is md. Defaults to `false`.\n* `is_flow_row_until_lg` (`:boolean`) - Stacks when container is lg. Defaults to `false`.\n* `is_centered_lg` (`:boolean`) - Generates a wrapper around `main` to keep its content centered up to max width \"lg\". Defaults to `false`.\n* `is_centered_md` (`:boolean`) - Generates a wrapper around `main` to keep its content centered up to max width \"md\". Defaults to `false`.\n* `is_centered_xl` (`:boolean`) - Generates a wrapper around `main` to keep its content centered up to max width \"xl\". Defaults to `false`.\n* `is_flow_row_hidden` (`:boolean`) - On a small screen (up to 544px). Hides the horizontal divider. Defaults to `false`.\n* `is_flow_row_shallow` (`:boolean`) - On a small screen (up to 544px). Generates a filled 8px horizontal divider. Defaults to `false`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#layout/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.layout/1","doc":"* `main` - Generates a main element. Default gutter sizes: md: 16px, lg: 24px (change with `is_gutter_none`, `is_gutter_condensed` and `is_gutter_spacious`). Stacks when container is `sm` (change with `is_flow_row_until_md` and `is_flow_row_until_lg`). Accepts attributes:\n\n  * `order` (`:any`) - Markup order, defines in what order the slot is rendered in HTML. Keyboard navigation follows the markup order. Decide carefully how the focus order should be be by deciding whether main or sidebar comes first in code. The markup order won't affect the visual position. Default value: 2.Must be one of `1`, `2`, `\"1\"`, or `\"2\"`.\n* `divider` - Generates a divider element. The divider will only be shown with option `is_divided`. Generates a line between the main and sidebar elements - horizontal when the elements are stacked and vertical when they are shown side by side.\n* `sidebar` - Generates a sidebar element. Widths: md: 256px, lg: 296px (change with `is_narrow_sidebar` and `is_wide_sidebar`). Accepts attributes:\n\n  * `order` (`:any`) - See `main` slot. Default value: 1.Must be one of `1`, `2`, `\"1\"`, or `\"2\"`.","ref":"PrimerLive.Component.html#layout/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.layout/1","doc":"[Primer Layout](https://primer.style/design/components/layout)","ref":"PrimerLive.Component.html#layout/1-reference"},{"type":"function","title":"PrimerLive.Component.menu/1","doc":"Generates a vertical list of navigational links.\n\nMenu items are rendered as link element.\n\n```\n<.menu aria_label=\"Site navigation\">\n  <:item href=\"#url\" is_selected>\n    Account\n  </:item>\n  <:item href=\"#url\">\n    Emails\n  </:item>\n</.menu>\n```","ref":"PrimerLive.Component.html#menu/1"},{"type":"function","title":"Examples - PrimerLive.Component.menu/1","doc":"Menu links are created with `Phoenix.Component.link/1`, passing all other slot attributes to the link. Link examples:\n\n```\n<:item href=\"#url\">href link</:item>\n<:item navigate={Routes.page_path(@socket, :index)}>navigate link</:item>\n<:item patch={Routes.page_path(@socket, :index)}>patch link</:item>\n```\n\nAdd other types of content, such as icons and counters:\n\n```\n<.menu>\n  <:item href=\"#url\" is_selected>\n    <.octicon name=\"comment-discussion-16\" />\n     Conversation \n    <.counter>2</.counter>\n  </:item>\n  <:item href=\"#url\">\n    <.octicon name=\"check-circle-16\" />\n     Done \n    <.counter>99</.counter>\n  </:item>\n</.menu>\n```\n\nAdd a heading:\n\n```\n<.menu aria_label=\"Site navigation\">\n  <:heading>Menu heading</:heading>\n  <:item href=\"#url\" is_selected>\n    Account\n  </:item>\n  <:item href=\"#url\">\n    Emails\n  </:item>\n</.menu>\n```","ref":"PrimerLive.Component.html#menu/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.menu/1","doc":"* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for underline nav elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    menu: \"\",    # Outer container (nav element)\n    item: \"\",    # Menu item element\n    heading: \"\", # Heading element\n  }\n  ```\n\n  Defaults to `%{item: nil, menu: nil, heading: nil}`.\n* `aria_label` (`:string`) - Adds attribute `aria-label` to the outer element. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#menu/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.menu/1","doc":"* `item` (required) - Menu content. To create a link element, pass attribute `href`, `navigate` or `patch`. Accepts attributes:\n\n  * `is_selected` (`:boolean`) - Shows the selected state.\n  * `href` (`:any`) - Link attribute. The link is created with `Phoenix.Component.link/1`, passing all other slot attributes to the link.\n  * `patch` (`:string`) - Link attribute - see `href`.\n  * `navigate` (`:string`) - Link attribute - see `href`.\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `heading` - Menu heading.","ref":"PrimerLive.Component.html#menu/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.menu/1","doc":"No longer mentioned on https://primer.style/design/components","ref":"PrimerLive.Component.html#menu/1-reference"},{"type":"function","title":"PrimerLive.Component.octicon/1","doc":"Renders an icon from the set of GitHub icons, 512 including all size variations.\n\nSee `PrimerLive.Octicons` for the complete list.\n\n```\n<.octicon name=\"comment-16\" />\n```","ref":"PrimerLive.Component.html#octicon/1"},{"type":"function","title":"Examples - PrimerLive.Component.octicon/1","doc":"Pass the icon name with the size: icon \"alert-fill\" with size \"12\" becomes \"alert-fill-12\":\n\n```\n<.octicon name=\"alert-fill-12\" />\n```\n\nIcon \"pencil\" with size 24:\n\n```\n<.octicon name=\"pencil-24\" />\n```\n\nCustom class:\n\n```\n<.octicon name=\"pencil-24\" class=\"app-icon\" />\n```","ref":"PrimerLive.Component.html#octicon/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.octicon/1","doc":"* `name` (`:string`) (required) - Icon name, e.g. \"arrow-left-24\". See [available icons](https://primer.style/octicons/).\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#octicon/1-attributes"},{"type":"function","title":"Reference - PrimerLive.Component.octicon/1","doc":"- [Primer Icon](https://primer.style/design/components/icon)\n- [List of Primer icons](https://primer.style/octicons/)\n- [Primer/Octicons Usage](https://primer.style/octicons/guidelines/usage)","ref":"PrimerLive.Component.html#octicon/1-reference"},{"type":"function","title":"PrimerLive.Component.pagination/1","doc":"Pagination is a horizontal set of links to navigate paginated content.\n\n```\n<.pagination\n  page_count={@page_count}\n  current_page={@current_page}\n  link_path={fn page_num -> \"/page/#{page_num}\" end}\n/>\n```","ref":"PrimerLive.Component.html#pagination/1"},{"type":"function","title":"Features - PrimerLive.Component.pagination/1","doc":"- Configure the page number ranges for siblings and sides\n- Optionally disable page number display (minimal UI)\n- Custom labels\n- Custom classnames for all elements\n\nIf pages in the center (controlled by `sibling_count`) collide with pages near the sides (controlled by `side_count`), the center section will be pushed away from the side.","ref":"PrimerLive.Component.html#pagination/1-features"},{"type":"function","title":"Examples - PrimerLive.Component.pagination/1","doc":"Simplified paginations, showing Next / Previous buttons:\n\n```\n<.pagination\n  ...\n  is_numbered=\"false\"\n/>\n```\n\nConfigure the number of sibling and boundary page numbers to show:\n\n```\n<.pagination\n  ...\n  sibling_count=\"1\"  # default: 2\n  side_count=\"2\"     # default 1\n/>\n```\n\nProvide custom labels:\n\n```\n<.pagination\n  ...\n  labels={\n    %{\n      next_page: \"Nächste Seite\",\n      previous_page: \"Vorherige Seite\"\n    }\n  }\n/>\n```","ref":"PrimerLive.Component.html#pagination/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.pagination/1","doc":"* `page_count` (`:integer`) (required) - Result page count.\n* `current_page` (`:integer`) (required) - Current page number.\n* `link_path` (`:any`) (required) - Function that returns a path for the given page number. The link builder uses `Phoenix.Component.link/1` with attribute `navigate`. Extra options can be passed with `link_options`.\n\n  Function signature: `(page_number) -> path`\n\n* `side_count` (`:integer`) - Number of page links at both ends. Defaults to `1`.\n* `sibling_count` (`:integer`) - Number of page links at each side of the current page number element. Defaults to `2`.\n* `is_numbered` (`:any`) - Boolean atom or string. Showing page numbers. Defaults to `true`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for pagination elements. Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    gap: \"\",\n    pagination_container: \"\",\n    pagination: \"\",\n    previous_page: \"\",\n    next_page: \"\",\n    current_page: \"\",\n    page: \"\"\n  }\n  ```\n\n  Defaults to `%{pagination: nil, current_page: nil, gap: nil, pagination_container: nil, previous_page: nil, next_page: nil, page: nil}`.\n* `labels` (`:map`) - Textual labels. Any provided value will override the default text. Defaults to `%{gap: \"…\", previous_page: \"Previous\", next_page: \"Next\", aria_label_container: \"Pagination navigation\", aria_label_next_page: \"Go to next page\", aria_label_current_page: \"Current page, page {page_number}\", aria_label_page: \"Go to page {page_number}\", aria_label_previous_page: \"Go to previous page\"}`.\n* `link_options` (`:map`) - Link options. Defaults to `%{replace: false}`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#pagination/1-attributes"},{"type":"function","title":"Reference - PrimerLive.Component.pagination/1","doc":"[Primer Pagination](https://primer.style/design/components/pagination)","ref":"PrimerLive.Component.html#pagination/1-reference"},{"type":"function","title":"PrimerLive.Component.parent_child_avatar/1","doc":"","ref":"PrimerLive.Component.html#parent_child_avatar/1"},{"type":"function","title":"PrimerLive.Component.progress/1","doc":"Generates a progress bar to visualise task completion.\n\nThe item slot creates the colored bar. Its width is a percentage value (0 - 100).\n\n```\n<.progress aria_label=\"Tasks: 8 of 10 complete\">\n  <:item width=\"50\"></:item>\n</.progress>\n```","ref":"PrimerLive.Component.html#progress/1"},{"type":"function","title":"Examples - PrimerLive.Component.progress/1","doc":"The default bar state is \"success\" (green). Possible states:\n\n- \"info\" - blue\n- \"success\" - green\n- \"warning\" - ocher\n- \"error\" - red\n\n```\n<.progress>\n  <:item width=\"50\" state=\"error\"></:item>\n</.progress>\n```\n\nUse multiple items to show a multicolored bar:\n\n```\n<.progress>\n  <:item width=\"50\" state=\"success\"></:item>\n  <:item width=\"30\" state=\"warning\"></:item>\n  <:item width=\"10\" state=\"error\"></:item>\n  <:item width=\"5\" state=\"info\"></:item>\n</.progress>\n```\n\nCreate a large progress bar:\n\n```\n<.progress is_large>\n  <:item width=\"50\"></:item>\n</.progress>\n```\n\nCreate a small progress bar:\n\n```\n<.progress is_small>\n  <:item width=\"50\"></:item>\n</.progress>\n```\n\nCreate an inline progress bar:\n\n```\n 4 of 16 \n<.progress is_inline style=\"width: 160px;\">\n  <:item width=\"25\"></:item>\n</.progress>\n```","ref":"PrimerLive.Component.html#progress/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.progress/1","doc":"* `aria_label` (`:string`) - Adds attribute `aria-label` to the outer element. Defaults to `nil`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for progress elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    progress: \"\",      # Outer container\n    item: \"\",          # Colored bar element\n    state_success: \"\", # Color bar modifier\n    state_info: \"\",    # Color bar modifier\n    state_warning: \"\", # Color bar modifier\n    state_error: \"\",   # Color bar modifier\n  }\n  ```\n\n  Defaults to `%{progress: nil, item: nil, state_info: nil, state_success: nil, state_warning: nil, state_error: nil}`.\n* `is_large` (`:boolean`) - Creates a large progress bar. Defaults to `false`.\n* `is_small` (`:boolean`) - Creates a small progress bar. Defaults to `false`.\n* `is_inline` (`:boolean`) - Creates an inline progress bar, to be used next to other elements.\n\n  The \"progress\" element must have a width, for example:\n\n  ```\n  <.progress is_inline style=\"width: 160px;\">\n    <:item width=\"25\"></:item>\n  </.progress>\n  ```\n\n  Defaults to `false`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#progress/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.progress/1","doc":"* `item` (required) - Colored bar. Accepts attributes:\n\n  * `width` (`:any`) - String or integer. Percentage value (0 - 100).\n  * `state` (`:string`) - Color mapping:\n\n    - \"info\" - blue\n    - \"success\" - green\n    - \"warning\" - ocher\n    - \"error\" - red\nMust be one of `\"info\"`, `\"success\"`, `\"warning\"`, or `\"error\"`.","ref":"PrimerLive.Component.html#progress/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.progress/1","doc":"[Primer Progress bar](https://primer.style/design/components/progress-bar)","ref":"PrimerLive.Component.html#progress/1-reference"},{"type":"function","title":"PrimerLive.Component.radio_button/1","doc":"Generates a radio button.\n\nWrapper around `PhoenixHTMLHelpers.Form.radio_button/4`.\n\n```\n<.radio_button name=\"role\" value=\"admin\" />\n<.radio_button name=\"role\" value=\"editor\" />\n```\n\nTo create a group of radio buttons, see `radio_group/1`.","ref":"PrimerLive.Component.html#radio_button/1"},{"type":"function","title":"Examples - PrimerLive.Component.radio_button/1","doc":"Set the checked state:\n\n```\n<.radio_button name=\"role\" value=\"admin\" />\n<.radio_button name=\"role\" value=\"editor\" checked />\n```\n\nUsing the radio button with form data. This will automatically create the radio button label:\n\n```\n<.form let={f} for={@changeset} phx-change=\"validate\" phx-submit=\"save\">\n  <.radio_button form={f} field={:role} value=\"admin\" />\n  <.radio_button form={f} field={:role} value=\"editor\" />\n</.form>\n```\n\nPass a custom radio button label with the `label` slot:\n\n```\n<.radio_button form={:user} field={:role}>\n  <:label>Some label</:label>\n</.radio_button>\n```\n\nAdd emphasis to the label:\n\n```\n<.radio_button name=\"role\" is_emphasised_label />\n```\n\nAdd a hint below the label:\n\n```\n<.radio_button name=\"role\">\n  <:label>Some label</:label>\n  <:hint>\n    Add your  resume  below\n  </:hint>\n</.radio_button>\n```\n\nReveal extra details when the radio button is checked:\n\n```\n<.radio_button name=\"role\">\n  <:label>Some label</:label>\n  <:disclosure>\n     Available hours per week \n    <.text_input is_contrast size=\"3\" />\n     hours per week \n  </:disclosure>\n</.radio_button>\n```","ref":"PrimerLive.Component.html#radio_button/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.radio_button/1","doc":"* `form` (`:any`) - Either a [Phoenix.HTML.Form](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html) or an atom. Defaults to `nil`.\n* `field` (`:any`) - Field name (atom or string). Defaults to `nil`.\n* `name` (`:string`) - Input name attribute (when not using `form` and `field`).\n* `input_id` (`:string`) - When using form/field. Custom input ID to be used in case the generated IDs cause \"Multiple IDs detected\" errors. Defaults to `nil`.\n* `checked` (`:boolean`) - The state of the radio button (when not using `form` and `field`).\n* `checked_value` (`:string`) - For internal use to ensure compatibility with \"single select\" radio buttons in `action_list/1`. Defaults to `nil`.\n* `value` (`:string`) - Radio button value attribute (overrides field value when using `form` and `field`).\n* `is_emphasised_label` (`:boolean`) - Adds emphasis to the label. Defaults to `false`.\n* `is_omit_label` (`:boolean`) - Omits the label. Defaults to `false`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for radio button elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    container: \"\",       # Radio button container\n    label_container: \"\", # Input label container\n    label: \"\",           # Input label\n    input: \"\",           # Radio button input element\n    caption: \"\",         # Hint message element\n    hint: \"\",            # Deprecation support: identical to \"caption\"\n    disclosure: \"\"       # Disclosure container (inline)\n  }\n  ```\n\n  Defaults to `%{input: nil, label: nil, hint: nil, caption: nil, container: nil, label_container: nil, disclosure: nil}`.\n* Global attributes are accepted. Supports all globals plus: `[\"disabled\"]`.","ref":"PrimerLive.Component.html#radio_button/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.radio_button/1","doc":"* `label` - Custom radio button label. Overides the derived label when using a `form` and `field`. Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `caption` - Adds text below radio button label. Enabled when a label is displayed. Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `hint` - Deprecated: use `caption`. As of 0.5.0. Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `disclosure` - Extra label content to be revealed when radio button is checked. Enabled when a label is displayed.\n\n  Note that the label element can only contain inline child elements.\n\n  Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)","ref":"PrimerLive.Component.html#radio_button/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.radio_button/1","doc":"- [Primer Radio](https://primer.style/design/components/radio)\n- [Primer Form control](https://primer.style/design/components/form-control)","ref":"PrimerLive.Component.html#radio_button/1-reference"},{"type":"function","title":"PrimerLive.Component.radio_group/1","doc":"Radio group renders a set of [`radio buttons`](`radio_button/1`).\n\n```\n<.radio_group>\n  <.radio_button name=\"role\" value=\"admin\" />\n  <.radio_button name=\"role\" value=\"editor\" />\n</.radio_group>\n```\n\nThis is equivalent to:\n\n```\n<.form_control is_input_group>\n  <.radio_button name=\"role\" value=\"admin\" />\n  <.radio_button name=\"role\" value=\"editor\" />\n</.form_control>\n```\n\n`is_input_group` (and hence `radio_group`) adds specific styling: a larger label font size, and layout for inputs, captions and validation.","ref":"PrimerLive.Component.html#radio_group/1"},{"type":"function","title":"Examples - PrimerLive.Component.radio_group/1","doc":"```\n<.form :let={f} for={@changeset}>\n  <.radio_group form={f} field={@field} caption=\"Select one\">\n    <.radio_button\n      :for={{label, value} <- @options}\n      form={f}\n      field={@field}\n      value={value}\n    >\n      <:label>\n        <%= label %>\n      </:label>\n    </.radio_button>\n  </.radio_group>\n</.form>\n```","ref":"PrimerLive.Component.html#radio_group/1-examples"},{"type":"function","title":"Reference - PrimerLive.Component.radio_group/1","doc":"[Primer Radio group](https://primer.style/design/components/radio-group)","ref":"PrimerLive.Component.html#radio_group/1-reference"},{"type":"function","title":"Attributes - PrimerLive.Component.radio_group/1","doc":"* `form` (`:any`) - Either a [Phoenix.HTML.Form](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html) or an atom. Defaults to `nil`.\n* `field` (`:any`) - Field name (atom or string). Defaults to `nil`.\n* `validation_message` (`:any`) - Function to write a custom validation message (in case of error or success).\n\n  The function receives a `PrimerLive.FieldState` struct and returns a validation message or nil.\n\n  A validation message is shown:\n  - If form is a `Phoenix.HTML.Form`, containing a `changeset`\n  - The `validation_message` function does not return nil\n\n  Function signatures:\n  - `fun () -> string | nil`\n  - `fun (field_state) -> string | nil`\n\n  Conditional error message:\n  ```\n  fn field_state ->\n    if !field_state.valid?, do: \"Please enter your first name\"\n  end\n  ```\n\n  Conditional success message, only shown when `changeset.action` is `:validate`:\n  ```\n  fn field_state ->\n    if field_state.valid? && field_state.changeset.action == :validate, do: \"Is available\"\n  end\n  ```\n\n  Defaults to `nil`.\n* `caption` (`:any`) - Hint message below the radio group label.\n\n  Pass a string, or a function that returns a string.\n\n  The function receives a `PrimerLive.FieldState` struct and returns a message or nil (which omits the caption element).\n\n  Function signatures:\n  - `fun () -> string | nil`\n  - `fun (field_state) -> string | nil`\n\n  To conditionally show a caption, use `field_state`. To show the caption when field state is valid:\n  ```\n  fn field_state ->\n    if !field_state.valid?, do: nil, else: \"Caption\"\n  end\n  ```\n\n  For additional markup, use the `H` sigil:\n  ```\n  fn ->\n    ~H'''\n    Caption with  link \n    '''\n  end\n  ```\n\n  Defaults to `nil`.\n* `label` (`:string`) - Custom label. Note that a label is automatically generated when using `field`. Defaults to `nil`.\n* `is_hide_label` (`:boolean`) - Omits the automatically generated label (when using `field`). Defaults to `false`.\n* `is_disabled` (`:boolean`) - Adjusts the styling to indicate disabled state. Defaults to `false`.\n* `required_marker` (`:string`) - Required field marking. This will be shown for all required fields (when using `Phoenix.HTML.Form`). Pass an empty string to remove the indicator. Defaults to `\"*\"`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for radio group elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    control: \"\",               # Radio group wrapper\n    group: \"\",                 # Deprecation support: identical to \"control\"\n    header: \"\",                # Header element containing the group label\n    label: \"\",                 # Radio group label\n    input_group_container: \"\", # Input group container (for checkbox_group and radio_group)\n    caption: \"\",               # Radio group caption\n  }\n  ```\n\n  Defaults to `%{control: nil, label: nil, header: nil, group: nil, caption: nil, input_group_container: nil}`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#radio_group/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.radio_group/1","doc":"* `inner_block` (required) - The radio group content.","ref":"PrimerLive.Component.html#radio_group/1-slots"},{"type":"function","title":"PrimerLive.Component.radio_tabs/1","doc":"Groups [`radio buttons`](`radio_button/1`) in a tab-like row.\n\nRadio buttons are generated from the `radio_button` slot:\n\n```\n<.radio_tabs>\n  <:radio_button name=\"role\" value=\"admin\"></:radio_button>\n  <:radio_button name=\"role\" value=\"editor\"></:radio_button>\n</.radio_tabs>\n```","ref":"PrimerLive.Component.html#radio_tabs/1"},{"type":"function","title":"Examples - PrimerLive.Component.radio_tabs/1","doc":"Using a `PhoenixHTMLHelpers.Form`, attributes `form` and `field` are passed from radio group to the radio buttons, and labels are generated automatically:\n\n```\n<.form let={f} for={@changeset}>\n  <.radio_tabs form={f} field={:role}>\n    <:radio_button value=\"admin\"></:radio_button>\n    <:radio_button value=\"editor\"></:radio_button>\n  </.radio_tabs>\n</.form>\n```\n\nGenerates:\n\n```\n \n   \n     \n     Admin \n     \n     Editor \n   \n \n```\n\nUse custom label with the `radio_button` slot attr `label`:\n\n```\n<.radio_tabs>\n  <:radio_button name=\"role\" value=\"admin\" label=\"My role is Admin\"></:radio_button>\n  <:radio_button name=\"role\" value=\"editor\" label=\"My role is Editor\"></:radio_button>\n</.radio_tabs>\n```","ref":"PrimerLive.Component.html#radio_tabs/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.radio_tabs/1","doc":"* `form` (`:any`) - Either a [Phoenix.HTML.Form](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html) or an atom. Defaults to `nil`.\n* `field` (`:any`) - Field name (atom or string). Defaults to `nil`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for radio group elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    radio_group: \"\", # Wrapper\n    label: \"\",       # Radio button label\n    radio_input: \"\", # Radio button input\n  }\n  ```\n\n  Defaults to `%{label: nil, radio_group: nil, radio_input: nil}`.\n* `id_prefix` (`:string`) - Attribute `id` prefix to create unique ids. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#radio_tabs/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.radio_tabs/1","doc":"* `radio_button` - Generates a radio button. Accepts attributes:\n\n  * `value` (`:string`) - See `radio_button/1`.\n  * `name` (`:string`) - See `radio_button/1`.\n  * `label` (`:string`) - Custom radio button label.\n  * `checked` (`:boolean`) - See `radio_button/1`.\n  * `class` (`:any`) - Additional classname.","ref":"PrimerLive.Component.html#radio_tabs/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.radio_tabs/1","doc":"This component was created based on Primer CSS documentation. It is not mentioned in the Primer Style specification.\n\n- [Primer Radio group](https://primer.style/design/components/radio-group)\n- [Primer Form control](https://primer.style/design/components/form-control)","ref":"PrimerLive.Component.html#radio_tabs/1-reference"},{"type":"function","title":"PrimerLive.Component.select/1","doc":"Generates a single or multiple select input.\n\nWrapper around `PhoenixHTMLHelpers.Form.select/4` and `PhoenixHTMLHelpers.Form.multiple_select/4`.\n\n```\n<.select name=\"age\" options={25..35} />\n```","ref":"PrimerLive.Component.html#select/1"},{"type":"function","title":"Examples - PrimerLive.Component.select/1","doc":"Options can contain:\n- A list:\n  - `25..35`\n  - `[\"male\", \"female\", \"won't say\"]`\n- A keyword list:\n  - `[\"Admin\": \"admin\", \"User\": \"user\"]`\n- A nested keyword list with option attributes:\n  - `[[key: \"Admin\", value: \"admin\", disabled: true], [key: \"User\", value: \"user\"]]`\n\nCreate a small select input:\n\n```\n<.select name=\"age\" options={25..35} is_small />\n```\n\nSet the selected item:\n\n```\n<.select name=\"age\" options={25..35} selected=\"30\" />\n```\n\nAdd a prompt:\n\n```\n<.select name=\"age\" options={25..35} prompt=\"Choose your age\" />\n```\n\nSet attributes to the prompt option:\n\n```\n<.select\n  name=\"age\"\n  options={25..35}\n  prompt={[key: \"Choose your age\", disabled: true, selected: true]}\n/>\n```\n\nCreate a multiple select with `is_multiple`.\n- Use `is_auto_height` to set the height of the select input to the number of options.\n- From the Phoenix documentation: Values are expected to be an Enumerable containing two-item tuples (like maps and keyword lists) or any Enumerable where the element will be used both as key and value for the generated select.\n- `selected` should contain a list of selected options.\n\n```\n<.form let={f} for={@changeset} phx-change=\"validate\" phx-submit=\"save\">\n  <.select\n    form={f}\n    field={:role}\n    options={[\"Admin\": \"admin\", \"User\": \"user\", \"Editor\": \"editor\"]}\n    is_multiple\n    is_auto_height\n    selected={[\"user\", \"tester\"]}\n  />\n</.form>\n```\n\nPlace the select inside a `form_control/1` with `is_form_control`. See `text_input/1` for examples.\n\nA validation error message is automatically added when using a changeset with an error state. See `text_input/1` how to customise the validation messages.","ref":"PrimerLive.Component.html#select/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.select/1","doc":"* `form` (`:any`) - Either a [Phoenix.HTML.Form](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html) or an atom. Defaults to `nil`.\n* `field` (`:any`) - Field name (atom or string). Defaults to `nil`.\n* `name` (`:string`) - Input name attribute (when not using `form` and `field`).\n* `input_id` (`:string`) - When using form/field. Custom input ID to be used in case the generated IDs cause \"Multiple IDs detected\" errors. Defaults to `nil`.\n* `validation_message` (`:any`) - Function to write a custom validation message (in case of error or success).\n\n  The function receives a `PrimerLive.FieldState` struct and returns a validation message or nil.\n\n  A validation message is shown:\n  - If form is a `Phoenix.HTML.Form`, containing a `changeset`\n  - The `validation_message` function does not return nil\n\n  Function signatures:\n  - `fun () -> string | nil`\n  - `fun (field_state) -> string | nil`\n\n  Conditional error message:\n  ```\n  fn field_state ->\n    if !field_state.valid?, do: \"Please enter your first name\"\n  end\n  ```\n\n  Conditional success message, only shown when `changeset.action` is `:validate`:\n  ```\n  fn field_state ->\n    if field_state.valid? && field_state.changeset.action == :validate, do: \"Is available\"\n  end\n  ```\n\n  Defaults to `nil`.\n* `validation_message_id` (`:any`) - Message ID that is usually passed from the form element component to `input_validation_message`. If not used, the ID will be generated.\n* `caption` (`:any`) - Hint message below the select input.\n\n  Pass a string, or a function that returns a string.\n\n  The function receives a `PrimerLive.FieldState` struct and returns a message or nil (which omits the caption element).\n\n  Function signatures:\n  - `fun () -> string | nil`\n  - `fun (field_state) -> string | nil`\n\n  To conditionally show a caption, use `field_state`. To show the caption when field state is valid:\n  ```\n  fn field_state ->\n    if !field_state.valid?, do: nil, else: \"Caption\"\n  end\n  ```\n\n  For additional markup, use the `H` sigil:\n  ```\n  fn ->\n    ~H'''\n    Caption with  link \n    '''\n  end\n  ```\n\n  Defaults to `nil`.\n* `options` (`:any`) (required) - Selectable options (list, map or keyword list).\n* `selected` (`:any`) - Selected option or options (string for single select, list when using `is_multiple`).\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for select elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    select_container: \"\",   # Select container element\n    select: \"\",             # Select element\n    validation_message: \"\", # Validation message,\n    caption: \"\",            # Hint message element\n  }\n  ```\n\n  Defaults to `%{select: nil, caption: nil, validation_message: nil, select_container: nil}`.\n* `prompt` (`:any`) - The default option that is displayed in the select options before the user makes a selection. See\n  `PhoenixHTMLHelpers.Form.multiple_select/4`.\n\n  Can't be used with a multiple select - this attribute will be ignored.\n\n  Pass a string or a keyword list.\n\n  Examples:\n\n  ```\n  <.select name=\"age\" options={25..35} prompt=\"Choose your age\" />\n  ```\n\n  Set attributes to the prompt option:\n\n  ```\n  <.select\n    name=\"age\"\n    options={25..35}\n    prompt={[key: \"Choose your age\", disabled: true, selected: true]}\n  />\n  ```\n\n* `is_multiple` (`:boolean`) - Creates a multiple select. Uses `PhoenixHTMLHelpers.Form.multiple_select/4`.\n\n  From the Phoenix documentation:\n\n  Values are expected to be an Enumerable containing two-item tuples (like maps and keyword lists) or any Enumerable where the element will be used both as key and value for the generated select.\n\n  Defaults to `false`.\n* `is_small` (`:boolean`) - Creates a small (less high) select. Defaults to `false`.\n* `is_large` (`:boolean`) - Creates a large (higher) select. Defaults to `false`.\n* `is_full_width` (`:boolean`) - Full width select. Defaults to `false`.\n* `is_auto_height` (`:boolean`) - When using `is_multiple`: sets the size to the number of options. Defaults to `false`.\n* `is_monospace` (`:boolean`) - Uses a monospace font. Defaults to `false`.\n* `form_control` (`:map`) - Form control attributes. Places the select input inside a `form_control/1` component with given attributes, alongside `form` and `field` to generate a form control label.\n\n  If only a automatically generated label is required, use convenience attr `is_form_control` instead.\n\n* `form_group` (`:map`) - Deprecated: use `form_control`. Since `0.5.0`.\n* `is_form_control` (`:boolean`) - Places the select input inside a `form_control/1` component. Attributes `form` and `field` are automatically passed to `form_control` to generate a form control label. If the field is required, its label will show a required marker.\n\n  To configure the form control and label, use attr `form_control`.\n\n  Defaults to `false`.\n* `is_form_group` (`:boolean`) - Deprecated: use `is_form_control`. Since `0.5.0`. Defaults to `false`.\n* Global attributes are accepted. Supports all globals plus: `[\"disabled\"]`.","ref":"PrimerLive.Component.html#select/1-attributes"},{"type":"function","title":"Reference - PrimerLive.Component.select/1","doc":"- [Primer Select](https://primer.style/design/components/select)\n- [Primer Form control](https://primer.style/design/components/form-control)","ref":"PrimerLive.Component.html#select/1-reference"},{"type":"function","title":"PrimerLive.Component.select_menu/1","doc":"Generates a select menu.\n\n```\n<.select_menu>\n  <:toggle>Menu</:toggle>\n  <:item>Item 1</:item>\n  <:item>Item 2</:item>\n  <:item>Item 3</:item>\n</.select_menu>\n```","ref":"PrimerLive.Component.html#select_menu/1"},{"type":"function","title":"Examples - PrimerLive.Component.select_menu/1","doc":"When a link attribute is supplied to the item slot, links are created with `Phoenix.Component.link/1`, passing all other slot attributes to the link. Link examples:\n\n```\n<:item href=\"#url\">href link</:item>\n<:item navigate={Routes.page_path(@socket, :index)}>navigate link</:item>\n<:item patch={Routes.page_path(@socket, :index)}>patch link</:item>\n```\n\nAdd a dropdown caret:\n\n```\n<.select_menu is_dropdown_caret>\n  ...\n</.select_menu>\n```\n\nAdd dividers, with or without content:\n\n```\n<.select_menu>\n  <:toggle>Menu</:toggle>\n  <:item>Item 1</:item>\n  <:item is_divider />\n  <:item>Item 2</:item>\n  <:item is_divider>Divider content</:item>\n  <:item>Item 3</:item>\n</.select_menu>\n```\n\nSelected state. When any item is selected, all other items will line up nicely:\n\n```\n<.select_menu>\n  <:toggle>Menu</:toggle>\n  <:item is_selected>Selected</:item>\n  <:item>Not selected</:item>\n</.select_menu>\n```\n\nAdd a menu title. The title is placed in a header row with a close button. The click target for the button is based on the `id` attribute (generated automatically if not supplied).\n\n```\n<.select_menu id=\"this-id-is-optional\">\n  <:toggle>Menu</:toggle>\n  <:menu title=\"Title\" />\n  ...\n</.select_menu>\n```\n\nAdd a message:\n\n```\n<.select_menu>\n  <:toggle>Menu</:toggle>\n  <:message class=\"color-bg-danger color-fg-danger\">Message</:message>\n  ...\n</.select_menu>\n```\n\nAdd a filter input:\n\n```\n <.select_menu>\n  <:toggle>Menu</:toggle>\n  <:filter>\n     \n      <.text_input class=\"SelectMenu-input\" type=\"search\" name=\"q\" placeholder=\"Filter\" />\n     \n  </:filter>\n  ...\n</.select_menu>\n```\n\nAdd a tab menu filter by using slot `tab`:\n\n```\n <.select_menu>\n  <:toggle>Menu</:toggle>\n  <:tab is_selected>\n    Selected\n  </:tab>\n  <:tab>\n    Other tab\n  </:tab>\n  ...\n</.select_menu>\n```\n\nAdd a footer:\n\n```\n<.select_menu>\n  <:toggle>Menu</:toggle>\n  ...\n  <:footer>Footer</:footer>\n</.select_menu>\n```","ref":"PrimerLive.Component.html#select_menu/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.select_menu/1","doc":"* `id` (`:string`) - Select menu element id. Use to toggle from the outside, and to get consistent IDs in tests.\n  If not set, an id is generated, either based on `form` and `field`, or otherwise randomly.\n\n* `form` (`:any`) - To maintain the open state when using the menu element inside a form, pass the form surrounding the menu element.\n  Either a [Phoenix.HTML.Form](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html) or an atom.\n\n* `field` (`:any`) - Field name (atom or string). Use an atom when used with a form.\n  To maintain the open state when using the menu inside a form, see: [Menus and dialogs](doc-extra/menus-and-dialogs.md).\n\n* `is_dropdown_caret` (`:boolean`) - Adds a dropdown caret to the prompt button. Defaults to `false`.\n* `is_backdrop` (`:boolean`) - Generates a backdrop background (default with medium darkness). Defaults to `false`.\n* `is_dark_backdrop` (`:boolean`) - Generates a darker backdrop background color. Defaults to `false`.\n* `is_medium_backdrop` (`:boolean`) - Generates a medium backdrop background color. Defaults to `false`.\n* `is_light_backdrop` (`:boolean`) - Generates a lighter backdrop background color. Default for menus. Defaults to `false`.\n* `is_fast` (`:boolean`) - Generates fast fade transitions for backdrop and content. Defaults to `true`.\n* `prompt_options` (`:string`) - JavaScript state callback functions as string. For example:\n\n  ```\n  \"{\n    willShow: function(elements) { console.log('willShow', elements) },\n    didShow: function(elements) { console.log('didShow', elements) },\n    willHide: function(elements) { console.log('willHide', elements) },\n    didHide: function(elements) { console.log('didHide', elements) }\n  }\"\n  ```\n\n* `phx_click_touch` (`:any`) - `phx-click` event binding to assign an event callback on clicking the touch layer.\n  Ignored if `is_modal` is true.\n\n* `is_aligned_end` (`:boolean`) - Aligns the menu to the end (at the right in left-to-right languages). Defaults to `false`.\n* `is_right_aligned` (`:boolean`) - Deprecated: use `is_aligned_end`. Since 0.5.1.\n* `is_borderless` (`:boolean`) - Removes the borders between list items. Defaults to `false`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for select menu elements.\n\n  Any provided value will be appended to the default classname, except for `toggle` that will override the default class \"btn\".\n\n  Default map:\n  ```\n  %{\n    blankslate: \"\",          # Blankslate content element.\n    caret: \"\",               # Dropdown caret element.\n    divider: \"\",             # Divider item element.\n    filter: \"\",              # Filter content element\n    footer: \"\",              # Footer element.\n    header_close_button: \"\", # Close button in the header.\n    header: \"\",              # Header element.\n    item: \"\",                # Item element.\n    loading: \"\",             # Loading content element.\n    menu_container: \"\",      # Menu container (called \"modal\" at PrimerCSS).\n    menu_list: \"\",           # Menu list container.\n    menu_title: \"\",          # Menu title.\n    menu: \"\",                # Menu element\n    message: \"\",             # Message element.\n    select_menu: \"\",         # Select menu container (details element).\n    tabs: \"\",                # Tab container.\n    tab: \"\",                 # Tab button.\n    toggle: \"\",              # Toggle element. Any value will override the\n                             # default class \"btn\".\n  }\n  ```\n\n  Defaults to `%{message: nil, header: nil, loading: nil, filter: nil, tabs: nil, item: nil, blankslate: nil, tab: nil, menu: nil, divider: nil, footer: nil, caret: nil, toggle: nil, menu_title: nil, header_close_button: nil, menu_container: nil, menu_list: nil, select_menu: nil}`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#select_menu/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.select_menu/1","doc":"* `toggle` (required) - Generates a toggle element (default with button appearance) using the slot content as label.\n\n  Any custom class will override the default class \"btn\".\n\n  Accepts attributes:\n\n  * `options` (`:string`) - Deprecated: pass the attrs to the select menu component as `prompt_options`.\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`) - Additional HTML attributes added to the item element.\n* `menu` - Generates a menu element. Accepts attributes:\n\n  * `title` (`:string`) - Generates a menu header with specified title.\n* `filter` - Filter slot to insert a `text_input/1` component that will drive a custom filter function.\n* `tab` - Tab item element. If a tab slot is used, a tab navigation will be generated containing button elements. Accepts attributes:\n\n  * `is_selected` (`:boolean`) - The currently selected tab.\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `footer` - Footer content.\n* `message` - Message container. Use utility classes to further style the message.\n\n  Example:\n  ```\n  <:message class=\"color-bg-danger color-fg-danger\">Message</:message>\n  ```\n\n  Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n* `loading` - Slot to show a loading animation.\n\n  Example:\n  ```\n  <:loading><.octicon name=\"copilot-48\" class=\"anim-pulse\" /></:loading>\n  ```\n\n* `blankslate` - Slot to show blankslate content.\n* `item` - Menu item content. To create a link element, pass attribute `href`, `navigate` or `patch`. Accepts attributes:\n\n  * `is_selected` (`:boolean`) - Shows the selected state with a checkmark.\n  * `is_disabled` (`:boolean`) - Generates a disabled state.\n  * `is_divider` (`:boolean`) - Generates a divider. The divider may have content, for example a label \"More options\".\n  * `selected_octicon_name` (`:boolean`) - The icon name for the selected state, for example \"check-circle-fill-16\".\n\n    Default \"check-16\".\n\n  * `name` (`:string`)\n  * `type` (`:string`)\n  * `href` (`:any`) - Link attribute. The link is created with `Phoenix.Component.link/1`, passing all other slot attributes to the link.\n  * `patch` (`:string`) - Link attribute - see `href`.\n  * `navigate` (`:string`) - Link attribute - see `href`.\n  * `phx-click` (`:string`)\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)","ref":"PrimerLive.Component.html#select_menu/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.select_menu/1","doc":"[Primer Select menu](https://primer.style/design/components/select-menu)","ref":"PrimerLive.Component.html#select_menu/1-reference"},{"type":"function","title":"PrimerLive.Component.side_nav/1","doc":"Generates a vertical list of navigational links.\n\nMenu items are rendered as link element.\n\n```\n<.side_nav aria_label=\"Site navigation\">\n  <:item href=\"#url\" is_selected>\n    Account\n  </:item>\n  <:item href=\"#url\">\n    Emails\n  </:item>\n</.side_nav>\n```","ref":"PrimerLive.Component.html#side_nav/1"},{"type":"function","title":"Examples - PrimerLive.Component.side_nav/1","doc":"Menu links are created with `Phoenix.Component.link/1`, passing all other slot attributes to the link. Link examples:\n\n```\n<:item href=\"#url\">href link</:item>\n<:item navigate={Routes.page_path(@socket, :index)}>navigate link</:item>\n<:item patch={Routes.page_path(@socket, :index)}>patch link</:item>\n```\n\nAdd other types of content, such as icons and counters:\n\n```\n<.side_nav>\n  <:item href=\"#url\" is_selected>\n    <.octicon name=\"comment-discussion-16\" />\n     Conversation \n    <.counter>2</.counter>\n  </:item>\n  <:item href=\"#url\">\n    <.octicon name=\"check-circle-16\" />\n     Done \n    <.counter>99</.counter>\n  </:item>\n  <:item href=\"#url\">\n     With a heading \n     and some longer description \n  </:item>\n</.side_nav>\n```\n\nAdd a border (not for sub navigation):\n\n```\n<.side_nav is_border>\n  ...\n</.side_nav>\n```\n\nCreate a sub navigation: a lightweight version without borders and more condensed.\n\n```\n<.side_nav is_sub_nav>\n  ...\n</.side_nav>\n```\n\nA sub navigation can be placed inside a side navigation, using an `item` slot without attributes:\n\n```\n<.side_nav is_border>\n  <:item href=\"#url\">\n    Item 1\n  </:item>\n  <:item navigate=\"#url\" is_selected>\n    Item 2\n  </:item>\n  <:item>\n    <.side_nav is_sub_nav class=\"border-top py-3\" style=\"padding-left: 16px\">\n      <:item href=\"#url\" is_selected>\n        Sub item 1\n      </:item>\n      <:item navigate=\"#url\">\n        Sub item 2\n      </:item>\n    </.side_nav>\n  </:item>\n  <:item navigate=\"#url\">\n    Item 3\n  </:item>\n</.side_nav>\n```","ref":"PrimerLive.Component.html#side_nav/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.side_nav/1","doc":"* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for underline nav elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    side_nav: \"\", # Outer container (nav element)\n    item: \"\",     # Menu item element\n    sub_item: \"\", # Menu sub item element\n  }\n  ```\n\n  Defaults to `%{item: nil, side_nav: nil, sub_item: nil}`.\n* `aria_label` (`:string`) - Adds attribute `aria-label` to the outer element. Defaults to `nil`.\n* `is_border` (`:boolean`) - Adds a border. Not applied when using `is_sub_nav`. Defaults to `false`.\n* `is_sub_nav` (`:boolean`) - Sets the menu style to \"sub navigation\": a lightweight version without borders and more condensed. Defaults to `false`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#side_nav/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.side_nav/1","doc":"* `item` (required) - Menu content. To create a link element, pass attribute `href`, `navigate` or `patch`. Accepts attributes:\n\n  * `is_selected` (`:boolean`) - Shows the selected state.\n  * `href` (`:any`) - Link attribute. The link is created with `Phoenix.Component.link/1`, passing all other slot attributes to the link.\n  * `patch` (`:string`) - Link attribute - see `href`.\n  * `navigate` (`:string`) - Link attribute - see `href`.\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)","ref":"PrimerLive.Component.html#side_nav/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.side_nav/1","doc":"No longer mentioned on https://primer.style/design/components","ref":"PrimerLive.Component.html#side_nav/1-reference"},{"type":"function","title":"PrimerLive.Component.spinner/1","doc":"Indicator to show that content is being loaded.\n\n```\n<.spinner />\n```","ref":"PrimerLive.Component.html#spinner/1"},{"type":"function","title":"Examples - PrimerLive.Component.spinner/1","doc":"Set the size (default: `32`):\n\n```\n<.spinner size=\"40\" />\n```\n\nSet the circle color (defaults to the current text color):\n\n```\n<.spinner color=\"red\" />\n<.spinner color=\"#ff0000\" />\n<.spinner color=\"rgba(250, 50, 150, 0.5)\" />\n```\n\nSet the highlight color (defaults to the `color` value):\n\n```\n<.spinner highlight_color=\"black\" />\n<.spinner highlight_color=\"#000000\" />\n```\n\nAlternatively, use `octicon/1` with class \"anim-rotate\", using any circular icon:\n\n```\n<.octicon name=\"skip-16\" class=\"anim-rotate\" />\n```","ref":"PrimerLive.Component.html#spinner/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.spinner/1","doc":"* `size` (`:any`) - Spinner size (number or number as string). Defaults to `32`.\n* `color` (`:string`) - Spinner color. Defaults to `\"currentColor\"`.\n* `highlight_color` (`:string`) - Spinner highlight segment color. Defaults to the `color` value.\n* `gap_color` (`:string`) - Deprecated: use `highlight_color`. Since `0.5.1`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#spinner/1-attributes"},{"type":"function","title":"Reference - PrimerLive.Component.spinner/1","doc":"[Primer Spinner](https://primer.style/design/components/spinner)","ref":"PrimerLive.Component.html#spinner/1-reference"},{"type":"function","title":"PrimerLive.Component.state_label/1","doc":"Shows an item's status.\n\nState labels are larger and styled with bolded text. Attribute settings allows to apply colors.\n\n```\n<.state_label>Label</.state_label>\n```","ref":"PrimerLive.Component.html#state_label/1"},{"type":"function","title":"Examples - PrimerLive.Component.state_label/1","doc":"Set a state (applying a background color):\n\n```\n<.state_label is_open>Label</.state_label>\n```\n\nSmaller label:\n\n```\n<.state_label is_small>Label</.state_label>\n```\n\nWith an icon:\n\n```\n<.state_label is_open><.octicon name=\"git-pull-request-16\" />Label</.state_label>\n```","ref":"PrimerLive.Component.html#state_label/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.state_label/1","doc":"* `is_draft` (`:boolean`) - Draft state color. Defaults to `false`.\n* `is_open` (`:boolean`) - Open state color. Defaults to `false`.\n* `is_merged` (`:boolean`) - Merged state color. Defaults to `false`.\n* `is_closed` (`:boolean`) - Closed state color. Defaults to `false`.\n* `is_small` (`:boolean`) - Smaller state label. Defaults to `false`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#state_label/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.state_label/1","doc":"* `inner_block` (required) - Label content.","ref":"PrimerLive.Component.html#state_label/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.state_label/1","doc":"[Primer State label](https://primer.style/design/components/state-label)","ref":"PrimerLive.Component.html#state_label/1-reference"},{"type":"function","title":"PrimerLive.Component.styled_html/1","doc":"Adds styling to HTML. This can be used to format HTML generated by a Markdown library, or to create consistent layout of HTML content.\n\n```\n<.styled_html>\n  Content\n</.styled_html>\n```","ref":"PrimerLive.Component.html#styled_html/1"},{"type":"function","title":"Attributes - PrimerLive.Component.styled_html/1","doc":"* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#styled_html/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.styled_html/1","doc":"* `inner_block` (required) - Content to be formatted.","ref":"PrimerLive.Component.html#styled_html/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.styled_html/1","doc":"[Primer Markdown](https://primer.style/design/components/markdown)","ref":"PrimerLive.Component.html#styled_html/1-reference"},{"type":"function","title":"PrimerLive.Component.subhead/1","doc":"Configurable and styled h2 heading.\n\n```\n</.subhead>Plain subhead</.subhead>\n```","ref":"PrimerLive.Component.html#subhead/1"},{"type":"function","title":"Examples - PrimerLive.Component.subhead/1","doc":"Add a top margin when separating sections on a settings page:\n\n```\n</.subhead is_spacious>Subhead</.subhead>\n```\n\nCreate a danger zone heading:\n\n```\n</.subhead is_danger>Plain subhead</.subhead>\n```\n\nAdd a description:\n\n```\n<.subhead>\n  Heading\n  <:description>\n    Description\n  </:description>\n</.subhead>\n```\n\nAdd an action (button or link):\n\n```\n<.subhead>\n  Heading\n  <:actions>\n    <.button is_primary>Action</.button>\n  </:actions>\n</.subhead>\n```","ref":"PrimerLive.Component.html#subhead/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.subhead/1","doc":"* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for subhead elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    subhead: \"\",     # Subhead container\n    heading: \"\",     # h2 heading\n    description: \"\", # Description element\n    actions: \"\",     # Actions section element\n  }\n  ```\n\n  Defaults to `%{description: nil, subhead: nil, heading: nil, actions: nil}`.\n* `is_spacious` (`:boolean`) - Add a top margin. Defaults to `false`.\n* `is_danger` (`:boolean`) - Makes the text bold and red. This is useful for warning users. Defaults to `false`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#subhead/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.subhead/1","doc":"* `inner_block` (required) - Heading content.\n* `description` - Description content.\n* `actions` - Actions content.","ref":"PrimerLive.Component.html#subhead/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.subhead/1","doc":"[Primer Pagehead](https://primer.style/design/components/pagehead)","ref":"PrimerLive.Component.html#subhead/1-reference"},{"type":"function","title":"PrimerLive.Component.subnav/1","doc":"Use the sub nav component for navigation on a dashboard-type interface with another set of navigation components above it.\n\nSubnav is composed of one or more child components:\n- `subnav_links/1` - a link row\n- `subnav_search/1` - a search field\n- `subnav_search_context/1` - a search filter menu adjacent to the search field\n\nMinimal version, showing the link row:\n\n```\n<.subnav>\n  <.subnav_links>\n    <:item href=\"#url\" is_selected>Item 1</:item>\n    <:item href=\"#url\">Item 2</:item>\n    <:item href=\"#url\">Item 3</:item>\n  </.subnav_links>\n</.subnav>\n```","ref":"PrimerLive.Component.html#subnav/1"},{"type":"function","title":"Examples - PrimerLive.Component.subnav/1","doc":"","ref":"PrimerLive.Component.html#subnav/1-examples"},{"type":"function","title":"subnav_links - PrimerLive.Component.subnav/1","doc":"To show a link row, use child component `subnav_links/1`.\n\nNavigation links are created with `Phoenix.Component.link/1`, passing all other slot attributes to the link. Link examples:\n\n```\n<:item href=\"#url\">href link</:item>\n<:item navigate={Routes.page_path(@socket, :index)}>navigate link</:item>\n<:item patch={Routes.page_path(@socket, :index)}>patch link</:item>\n```","ref":"PrimerLive.Component.html#subnav/1-subnav_links"},{"type":"function","title":"subnav_search - PrimerLive.Component.subnav/1","doc":"To add a search field, use child component `subnav_search/1` with a `text_input/1` component. Use `type=\"search\"` to display a search icon inside the search field.\n\n```\n<.subnav>\n  <.subnav_search>\n    <.text_input type=\"search\" />\n  </.subnav_search>\n</.subnav>\n```","ref":"PrimerLive.Component.html#subnav/1-subnav_search"},{"type":"function","title":"subnav_search_context - PrimerLive.Component.subnav/1","doc":"To place a filter menu adjacent to the search field, use child component `subnav_search_context/1` with a `select_menu/1` component:\n\n```\n<.subnav>\n  <.subnav_search_context>\n    <.select_menu is_dropdown_caret>\n      <:toggle>Menu</:toggle>\n      <:item>Item 1</:item>\n      <:item>Item 2</:item>\n      <:item>Item 3</:item>\n    </.select_menu>\n  </.subnav_search_context>\n  <.subnav_search>\n    <.text_input type=\"search\" />\n  </.subnav_search>\n</.subnav>\n```","ref":"PrimerLive.Component.html#subnav/1-subnav_search_context"},{"type":"function","title":"Attributes - PrimerLive.Component.subnav/1","doc":"* `is_wrap` (`:boolean`) - Allows child elements to wrap, for example a link row followed by a search field. Defaults to `false`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#subnav/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.subnav/1","doc":"* `inner_block` (required) - Subnav components.","ref":"PrimerLive.Component.html#subnav/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.subnav/1","doc":"[Primer Sub nav](https://primer.style/design/components/sub-nav)","ref":"PrimerLive.Component.html#subnav/1-reference"},{"type":"function","title":"PrimerLive.Component.subnav_links/1","doc":"Subnav link row. See `subnav/1`.","ref":"PrimerLive.Component.html#subnav_links/1"},{"type":"function","title":"Attributes - PrimerLive.Component.subnav_links/1","doc":"* `aria_label` (`:string`) - Adds attribute `aria-label` to the subnav links element. Defaults to `nil`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for subnav links elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    subnav_links: \"\", # Outer container (nav element)\n    item: \"\",         # Link item element\n  }\n  ```\n\n  Defaults to `%{item: nil, subnav_links: nil}`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#subnav_links/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.subnav_links/1","doc":"* `item` (required) - Subnav buttons item. To create a link element, pass attribute `href`, `navigate` or `patch`. Accepts attributes:\n\n  * `is_selected` (`:boolean`) - Shows the selected state.\n  * `href` (`:any`) - Link attribute. The link is created with `Phoenix.Component.link/1`, passing all other slot attributes to the link.\n  * `patch` (`:string`) - Link attribute - see `href`.\n  * `navigate` (`:string`) - Link attribute - see `href`.\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)","ref":"PrimerLive.Component.html#subnav_links/1-slots"},{"type":"function","title":"PrimerLive.Component.subnav_search/1","doc":"Subnav search field. See `subnav/1`.","ref":"PrimerLive.Component.html#subnav_search/1"},{"type":"function","title":"Attributes - PrimerLive.Component.subnav_search/1","doc":"* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#subnav_search/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.subnav_search/1","doc":"* `inner_block` (required) - Contents.","ref":"PrimerLive.Component.html#subnav_search/1-slots"},{"type":"function","title":"PrimerLive.Component.subnav_search_context/1","doc":"Subnav search filter adjacent to the search field. See `subnav/1`.","ref":"PrimerLive.Component.html#subnav_search_context/1"},{"type":"function","title":"Attributes - PrimerLive.Component.subnav_search_context/1","doc":"* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#subnav_search_context/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.subnav_search_context/1","doc":"* `inner_block` (required) - Contents.","ref":"PrimerLive.Component.html#subnav_search_context/1-slots"},{"type":"function","title":"PrimerLive.Component.tabnav/1","doc":"Tab nav contains a set of links that let users navigate between different views in the same context.\n\nTabs are by default rendered as buttons. To create link elements, pass attribute `href`, `navigate` or `patch`.\n\n```\n<.tabnav aria_label=\"Topics navigation\">\n  <:item href=\"#url\" is_selected>\n    Link tab\n  </:item>\n  <:item>\n    Button tab\n  </:item>\n</.tabnav>\n```","ref":"PrimerLive.Component.html#tabnav/1"},{"type":"function","title":"Examples - PrimerLive.Component.tabnav/1","doc":"When a link attribute is supplied to the item slot, links are created with `Phoenix.Component.link/1`, passing all other slot attributes to the link. Link examples:\n\n```\n<:item href=\"#url\">href link</:item>\n<:item navigate={Routes.page_path(@socket, :index)}>navigate link</:item>\n<:item patch={Routes.page_path(@socket, :index)}>patch link</:item>\n```\n\nAdd other types of content, such as icons and counters:\n\n```\n<.tabnav>\n  <:item href=\"#url\" is_selected>\n    <.octicon name=\"comment-discussion-16\" />\n     Conversation \n    <.counter>2</.counter>\n  </:item>\n  <:item href=\"#url\">\n    <.octicon name=\"check-circle-16\" />\n     Done \n    <.counter>99</.counter>\n  </:item>\n</.tabnav>\n```\n\nPosition additional content to the far end of the tabs.\n\nA button placed at the far end:\n\n```\n<.tabnav>\n  <:item href=\"#url\" is_selected>\n    One\n  </:item>\n  <:item href=\"#url\">\n    Two\n  </:item>\n  <:position_end>\n     Button \n  </:position_end>\n</.tabnav>\n```\n\nExtra content (not a button) is styled using attribute `is_extra`:\n\n```\n<.tabnav>\n  <:item href=\"#url\" is_selected>\n    One\n  </:item>\n  <:item href=\"#url\">\n    Two\n  </:item>\n  <:position_end is_extra>\n    Tabnav widget text here.\n  </:position_end>\n</.tabnav>\n```\n\nCreate small tabs (similar to tabs inside a `select_menu/1`) with `is_small`:\n\n```\n<.tabnav>\n  <:item is_small is_selected>\n    One\n  </:item>\n  <:item is_small>\n    Two\n  </:item>\n</.tabnav>\n```","ref":"PrimerLive.Component.html#tabnav/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.tabnav/1","doc":"* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for tabnav elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    tabnav: \"\",       # Outer container\n    nav: \"\",          # Nav element\n    tab: \"\",          # Tab link element\n    position_end: \"\", # Container for elements positions at the far end\n  }\n  ```\n\n  Defaults to `%{tabnav: nil, nav: nil, tab: nil, position_end: nil}`.\n* `aria_label` (`:string`) - Adds attribute `aria-label` to the outer element. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#tabnav/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.tabnav/1","doc":"* `item` (required) - Tab item content. Tabs are by default rendered as buttons. To create a link element, pass attribute `href`, `navigate` or `patch`. Accepts attributes:\n\n  * `is_selected` (`:boolean`) - Shows the selected state.\n  * `is_small` (`:boolean`) - Creates a small tab, similar to tabs inside a `select_menu/1`.\n  * `type` (`:string`) - For example: type=\"button\".\n  * `href` (`:any`) - Link attribute. The link is created with `Phoenix.Component.link/1`, passing all other slot attributes to the link.\n  * `patch` (`:string`) - Link attribute - see `href`.\n  * `navigate` (`:string`) - Link attribute - see `href`.\n  * `class` (`:any`) - Additional classname.\n  * `phx-click` (`:string`)\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `position_end` - Container for elements positions at the far end. Accepts attributes:\n\n  * `is_extra` (`:boolean`) - Adds styles to optimise additional bits of text and links.\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)","ref":"PrimerLive.Component.html#tabnav/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.tabnav/1","doc":"[Primer Tab nav](https://primer.style/design/components/tab-nav)","ref":"PrimerLive.Component.html#tabnav/1-reference"},{"type":"function","title":"PrimerLive.Component.text_input/1","doc":"Generates a text input field.\n\nWrapper around `PhoenixHTMLHelpers.Form.text_input/3`, optionally wrapped itself inside a \"form control\" to add a field label.\n\n```\n<.text_input field=\"first_name\" />\n```","ref":"PrimerLive.Component.html#text_input/1"},{"type":"function","title":"Examples - PrimerLive.Component.text_input/1","doc":"Set the input type:\n\n```\n<.text_input type=\"password\" />\n<.text_input type=\"hidden\" />\n<.text_input type=\"email\" />\n```\n\nSet the placeholder. By default, the value of the placeholder attribute is used to fill in the aria-label attribute:\n\n```\n<.text_input placeholder=\"Enter your first name\" />\n```\n\nUsing the input with form data:\n\n```\n<.form let={f} for={@changeset} phx-change=\"validate\" phx-submit=\"save\">\n  <.text_input form={f} field={:first_name} />\n  <.text_input form={f} field={:last_name} />\n</.form>\n```\n\nAttach a button to the input with slot `group_button`:\n\n```\n<.text_input>\n  <:group_button>\n    <.button>Send</.button>\n  </:group_button>\n</.text_input>\n```\n\nor use an icon button:\n\n```\n<.text_input>\n  <:group_button>\n    <.button aria-label=\"Copy\">\n      <.octicon name=\"paste-16\" />\n    </.button>\n  </:group_button>\n</.text_input>\n```\n\nAdd a button to the text input with slot `trailing_action`:\n\n```\n<.text_input>\n  <:trailing_action>\n    <.button is_icon_only aria-label=\"Clear\">\n      <.octicon name=\"x-16\" />\n    </.button>\n  </:trailing_action>\n</.text_input>\n```\n\nOnly show the trailing action when the input has a value:\n\n```\n<.text_input>\n  <:trailing_action is_visible_with_value>\n    <.button is_icon_only aria-label=\"Clear\">\n      <.octicon name=\"x-16\" />\n    </.button>\n  </:trailing_action>\n</.text_input>\n```\n\nAdd a leading visual with slot `leading_visual`:\n\n```\n<.text_input>\n  <:leading_visual>\n    <.octicon name=\"mail-16\" />\n  </:leading_visual>\n</.text_input>\n```\n\nPlace the input inside a `form_control/1` with `is_form_control`. Attributes `form` and `field` are passed to the form control to generate a control label. If the field is required, its label will show a required marker.\n\n```\n<.form let={f} for={@changeset} phx-change=\"validate\" phx-submit=\"save\">\n  <.text_input form={f} field={:first_name} is_form_control />\n</.form>\n```\n\nTo configure the form control and label, use attr `form_control`. See `form_control/1` for supported attributes.\n\nA validation error message is automatically added when using a changeset with an error state. The message text is taken from the changeset errors.\nTo show a custom validation error message, supply function `validation_message`:\n\n```\n<.form let={f} for={@changeset} phx-change=\"validate\" phx-submit=\"save\">\n  <.text_input\n    form={f}\n    field={:first_name}\n    form_control={%{\n      label: \"Custom label\",\n      validation_message:\n        fn field_state ->\n          if !field_state.valid?, do: \"Please enter your first name\"\n        end\n    }}\n  />\n</.form>\n```\n\nSimilarly, to show a custom validation success message:\n\n```\n<.form let={f} for={@changeset} phx-change=\"validate\" phx-submit=\"save\">\n  <.text_input\n    form={f}\n    field={:first_name}\n    validation_message={\n      fn field_state ->\n        if field_state.valid?, do: \"Available!\"\n      end\n    }\n  />\n</.form>\n```","ref":"PrimerLive.Component.html#text_input/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.text_input/1","doc":"* `form` (`:any`) - Either a [Phoenix.HTML.Form](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html) or an atom. Defaults to `nil`.\n* `field` (`:any`) - Field name (atom or string). Defaults to `nil`.\n* `input_id` (`:string`) - When using form/field. Custom input ID to be used in case the generated IDs cause \"Multiple IDs detected\" errors. Defaults to `nil`.\n* `caption` (`:any`) - Hint message below the input element.\n\n  Pass a string, or a function that returns a string.\n\n  The function receives a `PrimerLive.FieldState` struct and returns a message or nil (which omits the caption element).\n\n  Function signatures:\n  - `fun () -> string | nil`\n  - `fun (field_state) -> string | nil`\n\n  To conditionally show a caption, use `field_state`. To show the caption when field state is valid:\n  ```\n  fn field_state ->\n    if !field_state.valid?, do: nil, else: \"Caption\"\n  end\n  ```\n\n  For additional markup, use the `H` sigil:\n  ```\n  fn ->\n    ~H'''\n    Caption with  link \n    '''\n  end\n  ```\n\n  Defaults to `nil`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for input elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    input: \"\",              # Input element\n    caption: \"\",            # Caption element\n    input_group: \"\",        # Wrapper around the grouped input and group button\n    input_group_button: \"\", # Wrapper around slot group_button\n    validation_message: \"\", # Validation message\n    input_wrap: \"\",         # Input wrapper when leading or trailing visual is used\n  }\n  ```\n\n  Defaults to `%{input: nil, caption: nil, validation_message: nil, input_group: nil, input_group_button: nil, input_wrap: nil}`.\n* `name` (`:string`) - Input name attribute (when not using `form` and `field`).\n* `value` (`:string`) - Text input value attribute (overrides field value when using `form` and `field`).\n* `type` (`:string`) - Text input type. Defaults to `\"text\"`.\n* `size` (`:any`) - Defines the width of the input (number or number as string).\n* `is_contrast` (`:boolean`) - Changes the background color to light gray. Defaults to `false`.\n* `is_full_width` (`:boolean`) - Full width input. Defaults to `false`.\n* `is_hide_webkit_autofill` (`:boolean`) - Hide WebKit's contact info autofill icon. Defaults to `false`.\n* `is_large` (`:boolean`) - Additional padding creates a higher input box. If no width is specified, the input box is slightly wider. Defaults to `false`.\n* `is_small` (`:boolean`) - Smaller (less high) input with smaller text size. Defaults to `false`.\n* `is_monospace` (`:boolean`) - Uses a monospace font. Defaults to `false`.\n* `form_control` (`:map`) - Form control attributes. Places the input inside a `form_control/1` component with given attributes, alongside `form` and `field` to generate a form control label.\n\n  If only a automatically generated label is required, use convenience attr `is_form_control` instead.\n\n* `form_group` (`:map`) - Deprecated: use `form_control`. Since `0.5.0`.\n* `is_form_control` (`:boolean`) - Places the input inside a `form_control/1` component. Attributes `form` and `field` are automatically passed to `form_control` to generate a form control label. If the field is required, its label will show a required marker.\n\n  To configure the form control and label, use attr `form_control`.\n\n  Defaults to `false`.\n* `is_form_group` (`:boolean`) - Deprecated: use `is_form_control`. Since `0.5.0`. Defaults to `false`.\n* `validation_message` (`:any`) - Function to write a custom validation message (in case of error or success).\n\n  The function receives a `PrimerLive.FieldState` struct and returns a validation message or nil.\n\n  A validation message is shown:\n  - If form is a `Phoenix.HTML.Form`, containing a `changeset`\n  - The `validation_message` function does not return nil\n\n  Function signatures:\n  - `fun () -> string | nil`\n  - `fun (field_state) -> string | nil`\n\n  Conditional error message:\n  ```\n  fn field_state ->\n    if !field_state.valid?, do: \"Please enter your first name\"\n  end\n  ```\n\n  Conditional success message, only shown when `changeset.action` is `:validate`:\n  ```\n  fn field_state ->\n    if field_state.valid? && field_state.changeset.action == :validate, do: \"Is available\"\n  end\n  ```\n\n  Defaults to `nil`.\n* `validation_message_id` (`:any`) - Message ID that is usually passed from the form element component to `input_validation_message`. If not used, the ID will be generated.\n* Global attributes are accepted. Supports all globals plus: `[\"disabled\", \"max\", \"maxlength\", \"min\", \"minlength\", \"autocomplete\", \"pattern\", \"placeholder\", \"readonly\", \"required\"]`.","ref":"PrimerLive.Component.html#text_input/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.text_input/1","doc":"* `group_button` - Primer CSS \"Input group\". Attaches a button at the end of the input.\n\n  Example:\n  ```\n  <.text_input>\n    <:group_button>\n      <.button aria-label=\"Copy\">\n        <.octicon name=\"paste-16\" />\n      </.button>\n    </:group_button>\n  </.text_input>\n  ```\n\n* `leading_visual` - Container for a leading visual. Commonly a `octicon/1` component is used.\n* `trailing_action` - Container for a trailing action. Commonly a `octicon/1` component, or a `button/1` component with an icon (no label) is used. Accepts attributes:\n\n  * `is_divider` (`:boolean`) - Adds a separator line.\n  * `is_visible_with_value` (`:boolean`) - Only show the trailing action when the input has a value.\n  * `class` (`:any`) - Additional classname.","ref":"PrimerLive.Component.html#text_input/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.text_input/1","doc":"- [Primer Text input](https://primer.style/design/components/text-input)\n- [Primer Form control](https://primer.style/design/components/form-control)","ref":"PrimerLive.Component.html#text_input/1-reference"},{"type":"function","title":"PrimerLive.Component.textarea/1","doc":"Generates a textarea.\n\n```\n<.textarea name=\"comments\" />\n```","ref":"PrimerLive.Component.html#textarea/1"},{"type":"function","title":"Attributes - PrimerLive.Component.textarea/1","doc":"Use `text_input/1` attributes.","ref":"PrimerLive.Component.html#textarea/1-attributes"},{"type":"function","title":"Reference - PrimerLive.Component.textarea/1","doc":"- [Primer Textarea](https://primer.style/design/components/textarea)\n- [Primer Form control](https://primer.style/design/components/form-control)","ref":"PrimerLive.Component.html#textarea/1-reference"},{"type":"function","title":"PrimerLive.Component.theme/1","doc":"Creates a wrapper that sets the light/dark color mode and theme, with support for color blindness.\n\nSee also `PrimerLive.Theme`.","ref":"PrimerLive.Component.html#theme/1"},{"type":"function","title":"Alternative method - PrimerLive.Component.theme/1","doc":"Instead of using a wrapper, consider using `Theme.html_attributes` to set a theme on a component or element directly:\n\n```\n<.button\n  {PrimerLive.Theme.html_attributes([color_mode: \"dark\", dark_theme: \"dark_high_contrast\"])}\n>Button</.button>\n\n<.octicon name=\"sun-24\"\n  {PrimerLive.Theme.html_attributes(%{color_mode: \"dark\", dark_theme: \"dark_dimmed\"})}\n/>\n```","ref":"PrimerLive.Component.html#theme/1-alternative-method"},{"type":"function","title":"Theme wrapper examples - PrimerLive.Component.theme/1","doc":"Use default settings:\n\n```\n<.theme>\n  Content\n</.theme>\n```\n\nSet the color mode to dark and specify the dark theme:\n\n```\n<.theme color_mode=\"dark\" dark_theme=\"dark_dimmed\">\n  Content\n</.theme>\n```\n\nSpecify light and dark themes:\n\n```\n<.theme color_mode=\"dark\" light_theme=\"light_high_contrast\" dark_theme=\"dark_high_contrast\">\n  Content\n</.theme>\n```\n\nUse a `theme_state` struct for easier passing around state:\n\n```\nassigns = assign\n  |> assign(:theme_state, %{\n    color_mode: \"light\",\n    light_theme: \"light_high_contrast\",\n    dark_theme: \"dark_high_contrast\"\n  })\n\n<.theme theme_state={@theme_state}>\n  Content\n</.theme>\n```","ref":"PrimerLive.Component.html#theme/1-theme-wrapper-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.theme/1","doc":"* `theme_state` (`:map`) - Sets all theme values at once. Defaults to `nil`.\n* `color_mode` (`:string`) - Color mode. Defaults to `\"auto\"`.\n* `light_theme` (`:string`) - Light theme.\n\n  Possible values:\n  - \"light\"\n  - \"light_high_contrast\"\n  - \"light_colorblind\"\n  - \"light_tritanopia\"\n\n  Defaults to `\"light\"`.\n* `dark_theme` (`:string`) - Dark theme.\n\n  Possible values:\n  - \"dark\"\n  - \"dark_dimmed\"\n  - \"dark_high_contrast\"\n  - \"dark_colorblind\"\n  - \"dark_tritanopia\"\n\n  Defaults to `\"dark\"`.\n* `is_inline` (`:boolean`) - Renders the wrapper as a `span`. Useful for setting the color on an inline element. Defaults to `false`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#theme/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.theme/1","doc":"* `inner_block` (required) - Content.","ref":"PrimerLive.Component.html#theme/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.theme/1","doc":"No longer mentioned on https://primer.style/design/components","ref":"PrimerLive.Component.html#theme/1-reference"},{"type":"function","title":"PrimerLive.Component.theme_menu_options/1","doc":"Generates theme menu options as an `action_list/1`, to be used inside an `action_menu/1`.\n\nSee also `PrimerLive.Theme`.","ref":"PrimerLive.Component.html#theme_menu_options/1"},{"type":"function","title":"Menu options - PrimerLive.Component.theme_menu_options/1","doc":"To create a default menu - showing all possible options, using default labels:\n\n```\n<.theme_menu_options\n  theme_state={@theme_state}\n  default_theme_state={@default_theme_state}\n/>\n```\n\n- `theme_state` contains the current theme state\n- `default_theme_state` contains the initial (default) state","ref":"PrimerLive.Component.html#theme_menu_options/1-menu-options"},{"type":"function","title":"Menu - PrimerLive.Component.theme_menu_options/1","doc":"Place the menu options inside an expanding menu:\n\n```\n<.action_menu>\n  <:toggle class=\"btn btn-invisible\">\n    <.octicon name=\"sun-16\" />\n  </:toggle>\n  <.theme_menu_options\n    theme_state={@theme_state}\n  />\n</.action_menu>\n```\n\nTo make the selected theme persist, follow the instructions in `PrimerLive.Theme`.","ref":"PrimerLive.Component.html#theme_menu_options/1-menu"},{"type":"function","title":"Attributes - PrimerLive.Component.theme_menu_options/1","doc":"* `default_theme_state` (`:map`) - Defines the default (and initial) theme state.\n\n  Pass a map with all theme state keys.\n\n  Change the values to meet specific use cases, for example to set a light color mode instead of \"auto\":\n  ```\n  %{\n    color_mode: \"light\",\n    light_theme: \"light\",\n    dark_theme: \"dark_dimmed\"\n  }\n  ```\n\n  Defaults to `%{color_mode: \"auto\", light_theme: \"light\", dark_theme: \"dark\"}`.\n* `theme_state` (`:map`) (required) - Defines the current theme state. When using persistent data, this will be passed from the session.\n\n  Pass a map with all theme state keys. For example:\n  ```\n  %{\n    color_mode: \"light\",\n    light_theme: \"light_high_contrast\",\n    dark_theme: \"dark_high_contrast\"\n  }\n  ```\n\n* `update_theme_event` (`:string`) - Event name for the `handle_event` update callback.\n  The callback will be called with arguments:\n  - `key`: \"color_mode\", \"light_theme\", \"dark_theme\" or \"reset\"\n  - `data`: any value from `color_mode`, `light_theme` or `dark_theme`; or \"\" (when `key` is \"reset\")\n\n  If `update_theme_event` has value `store_theme`, the update theme event handler would be set up like this:\n  ```\n  def handle_event(\n    \"store_theme\",\n    %{\"data\" => data, \"key\" => key, \"value\" => _},\n    socket\n  ) do\n    # Persist new theme state ...\n\n    {:noreply, socket}\n  end\n  ```\n\n  Defaults to `\"update_theme\"`.\n* `options` (`:map`) - Selectable options (keys).\n\n  To show a limited set of theme options:\n  ```\n  %{\n    color_mode: ~w(light dark),\n    light_theme: ~w(light light_high_contrast),\n    dark_theme: ~w(dark dark_dimmed)\n  }\n  ```\n  or even:\n  ```\n  %{\n    color_mode: ~w(light dark)\n  }\n  ```\n\n  Defaults to `%{color_mode: [\"light\", \"dark\", \"auto\"], light_theme: [\"light\", \"light_high_contrast\", \"light_colorblind\", \"light_tritanopia\"], dark_theme: [\"dark\", \"dark_dimmed\", \"dark_high_contrast\", \"dark_colorblind\", \"dark_tritanopia\"]}`.\n* `labels` (`:map`) - Custom labels for menu items. For example:\n  ```\n  %{\n    color_mode: %{\n      light: \"Light theme\"\n    },\n    reset: \"Reset\"\n  }\n  ```\n\n  Defaults to `%{reset: \"Reset to default\", color_mode: %{auto: \"System\", title: \"Theme\", dark: \"Dark\", light: \"Light\"}, light_theme: %{title: \"Light tone\", light: \"Light\", light_colorblind: \"Light colorblind\", light_high_contrast: \"Light high contrast\", light_tritanopia: \"Light Tritanopia\"}, dark_theme: %{title: \"Dark tone\", dark: \"Dark\", dark_colorblind: \"Dark colorblind\", dark_dimmed: \"Dark dimmed\", dark_high_contrast: \"Dark high contrast\", dark_tritanopia: \"Dark Tritanopia\"}}`.\n* `is_show_group_labels` (`:boolean`) - Set to `false` to remove the labels above the menu groups. Defaults to `true`.\n* `is_show_reset_link` (`:boolean`) - Set to `false` to remove the reset link. Defaults to `true`.\n* `is_click_disabled` (`:boolean`) - For demo purposes. Set to `true` to prevent clicks on options. Defaults to `false`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#theme_menu_options/1-attributes"},{"type":"function","title":"PrimerLive.Component.timeline_item/1","doc":"Generates a timeline item to display items on a vertical timeline.\n\n```\n<.timeline_item>\n  <:badge>\n    <.octicon name=\"flame-16\" />\n  </:badge>\n  Everything is fine\n</.timeline_item>\n```","ref":"PrimerLive.Component.html#timeline_item/1"},{"type":"function","title":"Examples - PrimerLive.Component.timeline_item/1","doc":"Add color to the badge by using attribute `state`. Possible states:\n\n- \"default\" - light gray\n- \"info\" - blue\n- \"success\" - green\n- \"warning\" - ocher\n- \"error\" - red\n\n```\n<.timeline_item state=\"error\">\n  <:badge>\n    <.octicon name=\"flame-16\" />\n  </:badge>\n  Everything will be fine\n</.timeline_item>\n```\n\nAlternatively, use Primer CSS modifier classes on the badge slot to assign colors:\n\n```\n<.timeline_item>\n  <:badge class=\"color-bg-done-emphasis color-fg-on-emphasis\">\n    <.octicon name=\"flame-16\" />\n  </:badge>\n  Everything will be fine\n</.timeline_item>\n```\n\nWhen a link attribute is supplied to the badge slot, links are created with `Phoenix.Component.link/1`, passing all other slot attributes to the link. Link examples:\n\n```\n<:badge href=\"#url\">href link</:item>\n<:badge navigate={Routes.page_path(@socket, :index)}>navigate link</:item>\n<:badge patch={Routes.page_path(@socket, :index)}>patch link</:item>\n```\n\nCreate a condensed item, reducing the vertical padding and removing the background from the badge item:\n\n```\n<.timeline_item is_condensed>\n  <:badge>\n    <.octicon name=\"git-commit-16\" />\n  </:badge>\n  My commit\n</.timeline_item>\n```\n\nDisplay an avatar of the author:\n\n```\n<.timeline_item>\n  <:badge>\n    <.octicon name=\"git-commit-16\" />\n  </:badge>\n  <:avatar>\n    <.avatar size=\"6\" src=\"user.jpg\" />\n  </:avatar>\n  Someone's commit\n</.timeline_item>\n```\n\nCreate a visual break in the timeline with attribute `is_break`. This adds a horizontal bar across the timeline to show that something has disrupted it.\n\n```\n<.timeline_item state=\"error\">\n  <:badge><.octicon name=\"flame-16\" /></:badge>\n  Everything will be fine\n</.timeline_item>\n<.timeline_item is_break />\n<.timeline_item state=\"success\">\n  <:badge><.octicon name=\"smiley-16\" /></:badge>\n  Everything is fine\n</.timeline_item>\n```","ref":"PrimerLive.Component.html#timeline_item/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.timeline_item/1","doc":"* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for timeline elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    timeline_item: \"\", # Outer container\n    badge: \"\",         # Badge element\n    avatar: \"\",        # Avatar container\n    body: \"\",          # Body element\n    state_default: \"\", # Badge color modifier\n    state_info: \"\",    # Badge color modifier\n    state_success: \"\", # Badge color modifier\n    state_warning: \"\", # Badge color modifier\n    state_error: \"\",   # Badge color modifier\n  }\n  ```\n\n  Defaults to `%{body: nil, state_default: nil, state_info: nil, state_success: nil, state_warning: nil, state_error: nil, avatar: nil, timeline_item: nil, badge: nil}`.\n* `state` (`:string`) - Create a badge color variant by setting the state. Color mapping:\n\n  - \"default\" - light gray\n  - \"info\" - blue\n  - \"success\" - green\n  - \"warning\" - ocher\n  - \"error\" - red\nMust be one of `\"default\"`, `\"info\"`, `\"success\"`, `\"warning\"`, or `\"error\"`.\n* `is_condensed` (`:boolean`) - Creates a condensed item, reducing the vertical padding and removing the background from the badge item. Defaults to `false`.\n* `is_break` (`:boolean`) - Creates a visual break in the timeline. This adds a horizontal bar across the timeline to show that something has disrupted it. Ignores any slots. Defaults to `false`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#timeline_item/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.timeline_item/1","doc":"* `badge` - Badge content. Pass an `octicon/1` to display an icon. To create a link element, pass attribute `href`, `navigate` or `patch`. Accepts attributes:\n\n  * `href` (`:any`) - Link attribute. The link is created with `Phoenix.Component.link/1`, passing all other slot attributes to the link.\n  * `patch` (`:string`) - Link attribute - see `href`.\n  * `navigate` (`:string`) - Link attribute - see `href`.\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `avatar` - Avatar container.\n* `inner_block` - Item body.","ref":"PrimerLive.Component.html#timeline_item/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.timeline_item/1","doc":"[Primer Timeline](https://primer.style/design/components/timeline)","ref":"PrimerLive.Component.html#timeline_item/1-reference"},{"type":"function","title":"PrimerLive.Component.toggle_switch/1","doc":"Toggle switch is used to immediately toggle a setting on or off.\n\n```\n<.toggle_switch />\n```","ref":"PrimerLive.Component.html#toggle_switch/1"},{"type":"function","title":"Examples - PrimerLive.Component.toggle_switch/1","doc":"Add an On/Off label:\n\n```\n<.toggle_switch status_on_label=\"On\" status_off_label=\"Off\" />\n```\n\nWhen using a `PhoenixHTMLHelpers.Form`, the label can be derived from the field:\n\n```\n<.toggle_switch form={f} field={:terms_accepted} is_derived_label />\n```\n\nCreate a small toggle switch:\n```\n<.toggle_switch status_on_label=\"On\" status_off_label=\"Off\" is_small />\n```\n\nAdd a loading spinner:\n```\n<.toggle_switch status_on_label=\"On\" status_off_label=\"Off\" is_loading />\n```","ref":"PrimerLive.Component.html#toggle_switch/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.toggle_switch/1","doc":"* `form` (`:any`) - Either a [Phoenix.HTML.Form](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html) or an atom. Defaults to `nil`.\n* `field` (`:any`) - Field name (atom or string). Defaults to `nil`.\n* `name` (`:string`) - Input name attribute (when not using `form` and `field`).\n* `input_id` (`:string`) - When using form/field. Custom input ID to be used in case the generated IDs cause \"Multiple IDs detected\" errors. Defaults to `nil`.\n* `checked` (`:boolean`) - The state of the toggle switch (when not using `form` and `field`).\n* `checked_value` (`:string`) - The value to be sent when the toggle switch is checked. If `checked_value` equals `value`, the toggle switch is marked checked. Defaults to \"true\". Defaults to `nil`.\n* `hidden_input` (`:string`) - Controls if the component will generate a hidden input to submit the unchecked checkbox value or not. Defaults to \"true\". Defaults to `\"true\"`.\n* `value` (`:string`) - Toggle switch value attribute (overrides field value when using `form` and `field`).\n* `status_on_label` (`:string`) - Status label for on state.\n* `status_off_label` (`:string`) - Status label for off state.\n* `is_small` (`:boolean`) - Creates a small toggle switch. Defaults to `false`.\n* `is_loading` (`:boolean`) - Adds a loading spinner. Defaults to `false`.\n* `is_derived_label` (`:boolean`) - Uses a single a label (for both on and off state) derived from the field name (when using `field`). Defaults to `false`.\n* `is_label_position_end` (`:boolean`) - Places the label after the switch control. Defaults to `false`.\n* `classes` (`:map`) - Additional classnames for toggle switch elements. Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    container: \"\",\n    status_icon: \"\",\n    status_labels_container: \"\",\n    status_label: \"\",\n    status_on_label: \"\",\n    status_off_label: \"\",\n    track: \"\",\n    icons_container: \"\",\n    circle_icon: \"\",\n    line_icon: \"\",\n    loading_icon: \"\",\n    toggle_knob: \"\",\n  }\n  ```\n\n  Defaults to `%{container: nil, status_on_label: nil, status_off_label: nil, status_icon: nil, status_labels_container: nil, status_label: nil, track: nil, icons_container: nil, circle_icon: nil, line_icon: nil, loading_icon: nil, toggle_knob: nil}`.\n* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* Global attributes are accepted. Supports all globals plus: `[\"disabled\"]`.","ref":"PrimerLive.Component.html#toggle_switch/1-attributes"},{"type":"function","title":"Reference - PrimerLive.Component.toggle_switch/1","doc":"[Primer Toggle switch](https://primer.style/design/components/toggle-switch)","ref":"PrimerLive.Component.html#toggle_switch/1-reference"},{"type":"function","title":"PrimerLive.Component.truncate/1","doc":"Shortens text with ellipsis.\n\n```\n<.truncate>\n  <:item>really-long-text</:item>\n</.truncate>\n```","ref":"PrimerLive.Component.html#truncate/1"},{"type":"function","title":"Examples - PrimerLive.Component.truncate/1","doc":"Change the default generated HTML tags (default \"span\"). Note that the outer element is by default styled as `inline-flex`, regardless of the provided tag.\n\n```\n<.truncate tag=\"ol\">\n  <:item tag=\"li\">really-long-text</:item>\n  <:item tag=\"li\">really-long-text</:item>\n</.truncate>\n```\n\nTabs are by default rendered as `span` elements. To create link elements, pass attribute `href`, `navigate` or `patch`. Link examples:\n\n```\n<:item href=\"#url\">href link</:item>\n<:item navigate={Routes.page_path(@socket, :index)}>navigate link</:item>\n<:item patch={Routes.page_path(@socket, :index)}>patch link</:item>\n```\n\nMultiple item texts will truncate evenly.\n\n```\n<.truncate>\n  <:item>really-long-text</:item>\n  <:item>really-long-text</:item>\n</.truncate>\n```\n\nDelay the truncating of specific items:\n\n```\n<.truncate>\n  <:item>really-long-user-nametext</:item>\n  <:item is_primary>really-long-project-name</:item>\n</.truncate>\n```\n\nExpand the items on `hover` and `focus`:\n\n```\n<.truncate>\n  <:item expandable>really-long-text</:item>\n  <:item expandable>really-long-text</:item>\n</.truncate>\n```\n\nLimit the maximum width by adding `max-width` style:\n\n```\n<.truncate>\n  <:item is_expandable style=\"max-width: 300px;\">\n    really-long-text\n  </:item>\n</.truncate>\n```","ref":"PrimerLive.Component.html#truncate/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.truncate/1","doc":"* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for truncate elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    truncate: \"\", # Truncate wrapper element\n    item: \"\",     # Text wrapper element\n  }\n  ```\n\n  Defaults to `%{truncate: nil, item: nil}`.\n* `tag` (`:string`) - HTML tag used for the truncate wrapper. Defaults to `\"span\"`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#truncate/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.truncate/1","doc":"* `item` (required) - Wrapper around text to be truncated. Accepts attributes:\n\n  * `tag` (`:string`) - HTML tag used for the text wrapper.\n\n    Default: \"span\".\n\n  * `href` (`:any`) - Link attribute. The link is created with `Phoenix.Component.link/1`, passing all other slot attributes to the link.\n  * `patch` (`:string`) - Link attribute - see `href`.\n  * `navigate` (`:string`) - Link attribute - see `href`.\n  * `is_primary` (`:boolean`) - When using multiple items. Delays the truncating of the item.\n  * `is_expandable` (`:boolean`) - When using multiple items. Will expand the text on `hover` and `focus`.\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)","ref":"PrimerLive.Component.html#truncate/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.truncate/1","doc":"[Primer Truncate](https://primer.style/design/components/truncate)","ref":"PrimerLive.Component.html#truncate/1-reference"},{"type":"function","title":"PrimerLive.Component.ui_icon/1","doc":"Renders an interface icon.\n\nThese icons, while not part of the `octicon/1` icons, are used in interface elements.\n\n```\n<.ui_icon name=\"single-select-16\" />\n<.ui_icon name=\"multiple-select-16\" />\n<.ui_icon name=\"collapse-16\" />\n```","ref":"PrimerLive.Component.html#ui_icon/1"},{"type":"function","title":"Attributes - PrimerLive.Component.ui_icon/1","doc":"* `name` (`:string`) (required) - Icon name, e.g. \"single-select-16\".\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#ui_icon/1-attributes"},{"type":"function","title":"PrimerLive.Component.underline_nav/1","doc":"Generates a tab navigation with minimal underlined selected state, typically used for navigation placed at the top of the page.\n\nTabs are by default rendered as buttons. To create link elements, pass attribute `href`, `navigate` or `patch`.\n\n```\n<.underline_nav aria_label=\"Site navigation\">\n  <:item href=\"#url\" is_selected>\n    Link tab\n  </:item>\n  <:item>\n    Button tab\n  </:item>\n</.underline_nav>\n```","ref":"PrimerLive.Component.html#underline_nav/1"},{"type":"function","title":"Examples - PrimerLive.Component.underline_nav/1","doc":"When a link attribute is supplied to the item slot, links are created with `Phoenix.Component.link/1`, passing all other slot attributes to the link. Link examples:\n\n```\n<:item href=\"#url\">href link</:item>\n<:item navigate={Routes.page_path(@socket, :index)}>navigate link</:item>\n<:item patch={Routes.page_path(@socket, :index)}>patch link</:item>\n```\n\nAdd other types of content, such as icons and counters:\n\n```\n<.underline_nav>\n  <:item href=\"#url\" is_selected>\n    <.octicon name=\"comment-discussion-16\" />\n     Conversation \n    <.counter>2</.counter>\n  </:item>\n  <:item href=\"#url\">\n    <.octicon name=\"check-circle-16\" />\n     Done \n    <.counter>99</.counter>\n  </:item>\n</.underline_nav>\n```\n\nPosition additional content to the far end of the tabs.\n\nA button placed at the far end:\n\n```\n<.underline_nav>\n  <:item href=\"#url\" is_selected>\n    One\n  </:item>\n  <:item href=\"#url\">\n    Two\n  </:item>\n  <:position_end>\n     Button \n  </:position_end>\n</.underline_nav>\n```\n\nUse `is_container_width` in combination with container styles to make navigation fill the width of the container:\n\n```\n<.underline_nav is_container_width classes={%{\n    container: \"container-sm\"\n  }}>\n  <:item href=\"#url\" is_selected>\n    One\n  </:item>\n  <:item href=\"#url\">\n    Two\n  </:item>\n  <:position_end>\n     Button \n  </:position_end>\n</.underline_nav>\n```","ref":"PrimerLive.Component.html#underline_nav/1-examples"},{"type":"function","title":"Attributes - PrimerLive.Component.underline_nav/1","doc":"* `class` (`:any`) - Additional classname. Defaults to `nil`.\n* `classes` (`:map`) - Additional classnames for underline nav elements.\n\n  Any provided value will be appended to the default classname.\n\n  Default map:\n  ```\n  %{\n    underline_nav: \"\", # Outer container (nav element)\n    container: \"\",     # Extra container wrapper when using attr is_container_width\n    body: \"\",          # Tabs wrapper\n    tab: \"\",           # Tab link element\n    position_end: \"\",  # Container for elements positions at the far end\n  }\n  ```\n\n  Defaults to `%{body: nil, tab: nil, position_end: nil, underline_nav: nil, container: nil}`.\n* `is_container_width` (`:boolean`) - Use in combination with container styles to make navigation fill the width of the container.\n\n  For example:\n  ```\n  <.underline_nav is_container_width classes={%{\n    container: \"container-sm\"\n  }}>\n    ...\n  </.underline_nav>\n  ```\n\n  Defaults to `false`.\n* `is_reversed` (`:boolean`) - In left-to-right views the navigation will be positioned at the right. Defaults to `false`.\n* `aria_label` (`:string`) - Adds attribute `aria-label` to the outer element. Defaults to `nil`.\n* Global attributes are accepted.","ref":"PrimerLive.Component.html#underline_nav/1-attributes"},{"type":"function","title":"Slots - PrimerLive.Component.underline_nav/1","doc":"* `item` (required) - Tab item content: either a link or a button.\n\n  Tab item content. Tabs are by default rendered as buttons. To create a link element, pass attribute `href`, `navigate` or `patch`.\n\n  Accepts attributes:\n\n  * `is_selected` (`:boolean`) - Shows the selected state.\n  * `href` (`:any`) - Link attribute. The link is created with `Phoenix.Component.link/1`, passing all other slot attributes to the link.\n  * `patch` (`:string`) - Link attribute - see `href`.\n  * `navigate` (`:string`) - Link attribute - see `href`.\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)\n* `position_end` - Container for elements positions at the far end. Accepts attributes:\n\n  * `class` (`:any`) - Additional classname.\n  * `style` (`:string`) - Additional CSS styles.\n  * `rest` (`:any`)","ref":"PrimerLive.Component.html#underline_nav/1-slots"},{"type":"function","title":"Reference - PrimerLive.Component.underline_nav/1","doc":"[Primer Underline nav](https://primer.style/design/components/underline-nav)","ref":"PrimerLive.Component.html#underline_nav/1-reference"},{"type":"module","title":"PrimerLive.FieldState","doc":"State object with validation data for a particular form field.\n\nStruct fields:\n- `caption` - Field hint message that may be rendered dependent on the field state.\n- `changeset` - `Ecto.Changeset` struct.\n- `field_errors` - Changeset `errors`, filtered for the field.\n- `ignore_errors?` - Changeset has errors but should not be displayed (currently when `changeset.action` is `nil`)\n- `message_id` - Generated id that is used for `aria_describedby`.\n- `message` - Default message derived from changeset `errors`, unless overridden by `validation_message` attribute.\n- `required?` - True if the field is marked as required in the changeset (the `changeset.errors` contains value `[validation: :required]`).\n- `valid?` - True if changeset's `field_errors` is empty for the field.","ref":"PrimerLive.FieldState.html"},{"type":"module","title":"PrimerLive.Octicons","doc":"Components for SVG icons.\n\nRender an icon with [octicon/1](`PrimerLive.Component.octicon/1`):\n```\n<.octicon name=\"icon-name\" />\n```","ref":"PrimerLive.Octicons.html"},{"type":"module","title":"All octicons - PrimerLive.Octicons","doc":"```\n<.octicon name=\"accessibility-16\" />\n<.octicon name=\"accessibility-inset-16\" />\n<.octicon name=\"alert-16\" />\n<.octicon name=\"alert-24\" />\n<.octicon name=\"alert-fill-12\" />\n<.octicon name=\"alert-fill-16\" />\n<.octicon name=\"alert-fill-24\" />\n<.octicon name=\"apps-16\" />\n<.octicon name=\"archive-16\" />\n<.octicon name=\"archive-24\" />\n<.octicon name=\"arrow-both-16\" />\n<.octicon name=\"arrow-both-24\" />\n<.octicon name=\"arrow-down-16\" />\n<.octicon name=\"arrow-down-24\" />\n<.octicon name=\"arrow-down-left-16\" />\n<.octicon name=\"arrow-down-left-24\" />\n<.octicon name=\"arrow-down-right-16\" />\n<.octicon name=\"arrow-down-right-24\" />\n<.octicon name=\"arrow-left-16\" />\n<.octicon name=\"arrow-left-24\" />\n<.octicon name=\"arrow-right-16\" />\n<.octicon name=\"arrow-right-24\" />\n<.octicon name=\"arrow-switch-16\" />\n<.octicon name=\"arrow-switch-24\" />\n<.octicon name=\"arrow-up-16\" />\n<.octicon name=\"arrow-up-24\" />\n<.octicon name=\"arrow-up-left-16\" />\n<.octicon name=\"arrow-up-left-24\" />\n<.octicon name=\"arrow-up-right-16\" />\n<.octicon name=\"arrow-up-right-24\" />\n<.octicon name=\"beaker-16\" />\n<.octicon name=\"beaker-24\" />\n<.octicon name=\"bell-16\" />\n<.octicon name=\"bell-24\" />\n<.octicon name=\"bell-fill-16\" />\n<.octicon name=\"bell-fill-24\" />\n<.octicon name=\"bell-slash-16\" />\n<.octicon name=\"bell-slash-24\" />\n<.octicon name=\"blocked-16\" />\n<.octicon name=\"blocked-24\" />\n<.octicon name=\"bold-16\" />\n<.octicon name=\"bold-24\" />\n<.octicon name=\"book-16\" />\n<.octicon name=\"book-24\" />\n<.octicon name=\"bookmark-16\" />\n<.octicon name=\"bookmark-24\" />\n<.octicon name=\"bookmark-fill-24\" />\n<.octicon name=\"bookmark-slash-16\" />\n<.octicon name=\"bookmark-slash-24\" />\n<.octicon name=\"bookmark-slash-fill-24\" />\n<.octicon name=\"briefcase-16\" />\n<.octicon name=\"briefcase-24\" />\n<.octicon name=\"broadcast-16\" />\n<.octicon name=\"broadcast-24\" />\n<.octicon name=\"browser-16\" />\n<.octicon name=\"browser-24\" />\n<.octicon name=\"bug-16\" />\n<.octicon name=\"bug-24\" />\n<.octicon name=\"cache-16\" />\n<.octicon name=\"calendar-16\" />\n<.octicon name=\"calendar-24\" />\n<.octicon name=\"check-16\" />\n<.octicon name=\"check-24\" />\n<.octicon name=\"check-circle-16\" />\n<.octicon name=\"check-circle-24\" />\n<.octicon name=\"check-circle-fill-12\" />\n<.octicon name=\"check-circle-fill-16\" />\n<.octicon name=\"check-circle-fill-24\" />\n<.octicon name=\"checkbox-16\" />\n<.octicon name=\"checkbox-24\" />\n<.octicon name=\"checklist-16\" />\n<.octicon name=\"checklist-24\" />\n<.octicon name=\"chevron-down-12\" />\n<.octicon name=\"chevron-down-16\" />\n<.octicon name=\"chevron-down-24\" />\n<.octicon name=\"chevron-left-16\" />\n<.octicon name=\"chevron-left-24\" />\n<.octicon name=\"chevron-right-12\" />\n<.octicon name=\"chevron-right-16\" />\n<.octicon name=\"chevron-right-24\" />\n<.octicon name=\"chevron-up-12\" />\n<.octicon name=\"chevron-up-16\" />\n<.octicon name=\"chevron-up-24\" />\n<.octicon name=\"circle-16\" />\n<.octicon name=\"circle-24\" />\n<.octicon name=\"circle-slash-16\" />\n<.octicon name=\"circle-slash-24\" />\n<.octicon name=\"clock-16\" />\n<.octicon name=\"clock-24\" />\n<.octicon name=\"clock-fill-16\" />\n<.octicon name=\"clock-fill-24\" />\n<.octicon name=\"cloud-16\" />\n<.octicon name=\"cloud-24\" />\n<.octicon name=\"cloud-offline-16\" />\n<.octicon name=\"cloud-offline-24\" />\n<.octicon name=\"code-16\" />\n<.octicon name=\"code-24\" />\n<.octicon name=\"code-of-conduct-16\" />\n<.octicon name=\"code-of-conduct-24\" />\n<.octicon name=\"code-review-16\" />\n<.octicon name=\"code-review-24\" />\n<.octicon name=\"code-square-16\" />\n<.octicon name=\"code-square-24\" />\n<.octicon name=\"codescan-16\" />\n<.octicon name=\"codescan-24\" />\n<.octicon name=\"codescan-checkmark-16\" />\n<.octicon name=\"codescan-checkmark-24\" />\n<.octicon name=\"codespaces-16\" />\n<.octicon name=\"codespaces-24\" />\n<.octicon name=\"columns-16\" />\n<.octicon name=\"columns-24\" />\n<.octicon name=\"command-palette-16\" />\n<.octicon name=\"command-palette-24\" />\n<.octicon name=\"comment-16\" />\n<.octicon name=\"comment-24\" />\n<.octicon name=\"comment-discussion-16\" />\n<.octicon name=\"comment-discussion-24\" />\n<.octicon name=\"commit-24\" />\n<.octicon name=\"container-16\" />\n<.octicon name=\"container-24\" />\n<.octicon name=\"copilot-16\" />\n<.octicon name=\"copilot-24\" />\n<.octicon name=\"copilot-48\" />\n<.octicon name=\"copilot-96\" />\n<.octicon name=\"copilot-error-16\" />\n<.octicon name=\"copilot-warning-16\" />\n<.octicon name=\"copy-16\" />\n<.octicon name=\"copy-24\" />\n<.octicon name=\"cpu-16\" />\n<.octicon name=\"cpu-24\" />\n<.octicon name=\"credit-card-16\" />\n<.octicon name=\"credit-card-24\" />\n<.octicon name=\"cross-reference-16\" />\n<.octicon name=\"cross-reference-24\" />\n<.octicon name=\"dash-16\" />\n<.octicon name=\"dash-24\" />\n<.octicon name=\"database-16\" />\n<.octicon name=\"database-24\" />\n<.octicon name=\"dependabot-16\" />\n<.octicon name=\"dependabot-24\" />\n<.octicon name=\"desktop-download-16\" />\n<.octicon name=\"desktop-download-24\" />\n<.octicon name=\"device-camera-16\" />\n<.octicon name=\"device-camera-video-16\" />\n<.octicon name=\"device-camera-video-24\" />\n<.octicon name=\"device-desktop-16\" />\n<.octicon name=\"device-desktop-24\" />\n<.octicon name=\"device-mobile-16\" />\n<.octicon name=\"device-mobile-24\" />\n<.octicon name=\"devices-16\" />\n<.octicon name=\"devices-24\" />\n<.octicon name=\"diamond-16\" />\n<.octicon name=\"diamond-24\" />\n<.octicon name=\"diff-16\" />\n<.octicon name=\"diff-24\" />\n<.octicon name=\"diff-added-16\" />\n<.octicon name=\"diff-ignored-16\" />\n<.octicon name=\"diff-modified-16\" />\n<.octicon name=\"diff-removed-16\" />\n<.octicon name=\"diff-renamed-16\" />\n<.octicon name=\"discussion-closed-16\" />\n<.octicon name=\"discussion-closed-24\" />\n<.octicon name=\"discussion-duplicate-16\" />\n<.octicon name=\"discussion-duplicate-24\" />\n<.octicon name=\"discussion-outdated-16\" />\n<.octicon name=\"discussion-outdated-24\" />\n<.octicon name=\"dot-16\" />\n<.octicon name=\"dot-24\" />\n<.octicon name=\"dot-fill-16\" />\n<.octicon name=\"dot-fill-24\" />\n<.octicon name=\"download-16\" />\n<.octicon name=\"download-24\" />\n<.octicon name=\"duplicate-16\" />\n<.octicon name=\"duplicate-24\" />\n<.octicon name=\"ellipsis-16\" />\n<.octicon name=\"eye-16\" />\n<.octicon name=\"eye-24\" />\n<.octicon name=\"eye-closed-16\" />\n<.octicon name=\"eye-closed-24\" />\n<.octicon name=\"feed-discussion-16\" />\n<.octicon name=\"feed-forked-16\" />\n<.octicon name=\"feed-heart-16\" />\n<.octicon name=\"feed-merged-16\" />\n<.octicon name=\"feed-person-16\" />\n<.octicon name=\"feed-repo-16\" />\n<.octicon name=\"feed-rocket-16\" />\n<.octicon name=\"feed-star-16\" />\n<.octicon name=\"feed-tag-16\" />\n<.octicon name=\"feed-trophy-16\" />\n<.octicon name=\"file-16\" />\n<.octicon name=\"file-24\" />\n<.octicon name=\"file-added-16\" />\n<.octicon name=\"file-badge-16\" />\n<.octicon name=\"file-binary-16\" />\n<.octicon name=\"file-binary-24\" />\n<.octicon name=\"file-code-16\" />\n<.octicon name=\"file-code-24\" />\n<.octicon name=\"file-diff-16\" />\n<.octicon name=\"file-diff-24\" />\n<.octicon name=\"file-directory-16\" />\n<.octicon name=\"file-directory-24\" />\n<.octicon name=\"file-directory-fill-16\" />\n<.octicon name=\"file-directory-fill-24\" />\n<.octicon name=\"file-directory-open-fill-16\" />\n<.octicon name=\"file-directory-symlink-16\" />\n<.octicon name=\"file-directory-symlink-24\" />\n<.octicon name=\"file-media-24\" />\n<.octicon name=\"file-moved-16\" />\n<.octicon name=\"file-removed-16\" />\n<.octicon name=\"file-submodule-16\" />\n<.octicon name=\"file-submodule-24\" />\n<.octicon name=\"file-symlink-file-16\" />\n<.octicon name=\"file-symlink-file-24\" />\n<.octicon name=\"file-zip-16\" />\n<.octicon name=\"file-zip-24\" />\n<.octicon name=\"filter-16\" />\n<.octicon name=\"filter-24\" />\n<.octicon name=\"fiscal-host-16\" />\n<.octicon name=\"flame-16\" />\n<.octicon name=\"flame-24\" />\n<.octicon name=\"fold-16\" />\n<.octicon name=\"fold-24\" />\n<.octicon name=\"fold-down-16\" />\n<.octicon name=\"fold-down-24\" />\n<.octicon name=\"fold-up-16\" />\n<.octicon name=\"fold-up-24\" />\n<.octicon name=\"gear-16\" />\n<.octicon name=\"gear-24\" />\n<.octicon name=\"gift-16\" />\n<.octicon name=\"gift-24\" />\n<.octicon name=\"git-branch-16\" />\n<.octicon name=\"git-branch-24\" />\n<.octicon name=\"git-commit-16\" />\n<.octicon name=\"git-commit-24\" />\n<.octicon name=\"git-compare-16\" />\n<.octicon name=\"git-compare-24\" />\n<.octicon name=\"git-merge-16\" />\n<.octicon name=\"git-merge-24\" />\n<.octicon name=\"git-merge-queue-16\" />\n<.octicon name=\"git-merge-queue-24\" />\n<.octicon name=\"git-pull-request-16\" />\n<.octicon name=\"git-pull-request-24\" />\n<.octicon name=\"git-pull-request-closed-16\" />\n<.octicon name=\"git-pull-request-closed-24\" />\n<.octicon name=\"git-pull-request-draft-16\" />\n<.octicon name=\"git-pull-request-draft-24\" />\n<.octicon name=\"globe-16\" />\n<.octicon name=\"globe-24\" />\n<.octicon name=\"goal-16\" />\n<.octicon name=\"goal-24\" />\n<.octicon name=\"grabber-16\" />\n<.octicon name=\"grabber-24\" />\n<.octicon name=\"graph-16\" />\n<.octicon name=\"graph-24\" />\n<.octicon name=\"hash-16\" />\n<.octicon name=\"hash-24\" />\n<.octicon name=\"heading-16\" />\n<.octicon name=\"heading-24\" />\n<.octicon name=\"heart-16\" />\n<.octicon name=\"heart-24\" />\n<.octicon name=\"heart-fill-16\" />\n<.octicon name=\"heart-fill-24\" />\n<.octicon name=\"history-16\" />\n<.octicon name=\"history-24\" />\n<.octicon name=\"home-16\" />\n<.octicon name=\"home-24\" />\n<.octicon name=\"home-fill-24\" />\n<.octicon name=\"horizontal-rule-16\" />\n<.octicon name=\"horizontal-rule-24\" />\n<.octicon name=\"hourglass-16\" />\n<.octicon name=\"hourglass-24\" />\n<.octicon name=\"hubot-16\" />\n<.octicon name=\"hubot-24\" />\n<.octicon name=\"id-badge-16\" />\n<.octicon name=\"image-16\" />\n<.octicon name=\"image-24\" />\n<.octicon name=\"inbox-16\" />\n<.octicon name=\"inbox-24\" />\n<.octicon name=\"infinity-16\" />\n<.octicon name=\"infinity-24\" />\n<.octicon name=\"info-16\" />\n<.octicon name=\"info-24\" />\n<.octicon name=\"issue-closed-16\" />\n<.octicon name=\"issue-closed-24\" />\n<.octicon name=\"issue-draft-16\" />\n<.octicon name=\"issue-draft-24\" />\n<.octicon name=\"issue-opened-16\" />\n<.octicon name=\"issue-opened-24\" />\n<.octicon name=\"issue-reopened-16\" />\n<.octicon name=\"issue-reopened-24\" />\n<.octicon name=\"issue-tracked-by-16\" />\n<.octicon name=\"issue-tracked-by-24\" />\n<.octicon name=\"issue-tracks-16\" />\n<.octicon name=\"issue-tracks-24\" />\n<.octicon name=\"italic-16\" />\n<.octicon name=\"italic-24\" />\n<.octicon name=\"iterations-16\" />\n<.octicon name=\"iterations-24\" />\n<.octicon name=\"kebab-horizontal-16\" />\n<.octicon name=\"kebab-horizontal-24\" />\n<.octicon name=\"key-16\" />\n<.octicon name=\"key-24\" />\n<.octicon name=\"key-asterisk-16\" />\n<.octicon name=\"law-16\" />\n<.octicon name=\"law-24\" />\n<.octicon name=\"light-bulb-16\" />\n<.octicon name=\"light-bulb-24\" />\n<.octicon name=\"link-16\" />\n<.octicon name=\"link-24\" />\n<.octicon name=\"link-external-16\" />\n<.octicon name=\"link-external-24\" />\n<.octicon name=\"list-ordered-16\" />\n<.octicon name=\"list-ordered-24\" />\n<.octicon name=\"list-unordered-16\" />\n<.octicon name=\"list-unordered-24\" />\n<.octicon name=\"location-16\" />\n<.octicon name=\"location-24\" />\n<.octicon name=\"lock-16\" />\n<.octicon name=\"lock-24\" />\n<.octicon name=\"log-16\" />\n<.octicon name=\"log-24\" />\n<.octicon name=\"logo-gist-16\" />\n<.octicon name=\"logo-github-16\" />\n<.octicon name=\"mail-16\" />\n<.octicon name=\"mail-24\" />\n<.octicon name=\"mark-github-16\" />\n<.octicon name=\"markdown-16\" />\n<.octicon name=\"megaphone-16\" />\n<.octicon name=\"megaphone-24\" />\n<.octicon name=\"mention-16\" />\n<.octicon name=\"mention-24\" />\n<.octicon name=\"meter-16\" />\n<.octicon name=\"milestone-16\" />\n<.octicon name=\"milestone-24\" />\n<.octicon name=\"mirror-16\" />\n<.octicon name=\"mirror-24\" />\n<.octicon name=\"moon-16\" />\n<.octicon name=\"moon-24\" />\n<.octicon name=\"mortar-board-16\" />\n<.octicon name=\"mortar-board-24\" />\n<.octicon name=\"move-to-bottom-16\" />\n<.octicon name=\"move-to-bottom-24\" />\n<.octicon name=\"move-to-end-16\" />\n<.octicon name=\"move-to-end-24\" />\n<.octicon name=\"move-to-start-16\" />\n<.octicon name=\"move-to-start-24\" />\n<.octicon name=\"move-to-top-16\" />\n<.octicon name=\"move-to-top-24\" />\n<.octicon name=\"multi-select-16\" />\n<.octicon name=\"multi-select-24\" />\n<.octicon name=\"mute-16\" />\n<.octicon name=\"mute-24\" />\n<.octicon name=\"no-entry-16\" />\n<.octicon name=\"no-entry-24\" />\n<.octicon name=\"no-entry-fill-12\" />\n<.octicon name=\"north-star-16\" />\n<.octicon name=\"north-star-24\" />\n<.octicon name=\"note-16\" />\n<.octicon name=\"note-24\" />\n<.octicon name=\"number-16\" />\n<.octicon name=\"number-24\" />\n<.octicon name=\"organization-16\" />\n<.octicon name=\"organization-24\" />\n<.octicon name=\"package-16\" />\n<.octicon name=\"package-24\" />\n<.octicon name=\"package-dependencies-16\" />\n<.octicon name=\"package-dependencies-24\" />\n<.octicon name=\"package-dependents-16\" />\n<.octicon name=\"package-dependents-24\" />\n<.octicon name=\"paintbrush-16\" />\n<.octicon name=\"paper-airplane-16\" />\n<.octicon name=\"paper-airplane-24\" />\n<.octicon name=\"paperclip-16\" />\n<.octicon name=\"paperclip-24\" />\n<.octicon name=\"passkey-fill-16\" />\n<.octicon name=\"passkey-fill-24\" />\n<.octicon name=\"paste-16\" />\n<.octicon name=\"paste-24\" />\n<.octicon name=\"pencil-16\" />\n<.octicon name=\"pencil-24\" />\n<.octicon name=\"people-16\" />\n<.octicon name=\"people-24\" />\n<.octicon name=\"person-16\" />\n<.octicon name=\"person-24\" />\n<.octicon name=\"person-add-16\" />\n<.octicon name=\"person-add-24\" />\n<.octicon name=\"person-fill-16\" />\n<.octicon name=\"person-fill-24\" />\n<.octicon name=\"pin-16\" />\n<.octicon name=\"pin-24\" />\n<.octicon name=\"pin-slash-16\" />\n<.octicon name=\"pin-slash-24\" />\n<.octicon name=\"pivot-column-16\" />\n<.octicon name=\"pivot-column-24\" />\n<.octicon name=\"play-16\" />\n<.octicon name=\"play-24\" />\n<.octicon name=\"plug-16\" />\n<.octicon name=\"plug-24\" />\n<.octicon name=\"plus-16\" />\n<.octicon name=\"plus-24\" />\n<.octicon name=\"plus-circle-16\" />\n<.octicon name=\"plus-circle-24\" />\n<.octicon name=\"project-16\" />\n<.octicon name=\"project-24\" />\n<.octicon name=\"project-roadmap-16\" />\n<.octicon name=\"project-roadmap-24\" />\n<.octicon name=\"project-symlink-16\" />\n<.octicon name=\"project-symlink-24\" />\n<.octicon name=\"project-template-16\" />\n<.octicon name=\"project-template-24\" />\n<.octicon name=\"pulse-16\" />\n<.octicon name=\"pulse-24\" />\n<.octicon name=\"question-16\" />\n<.octicon name=\"question-24\" />\n<.octicon name=\"quote-16\" />\n<.octicon name=\"quote-24\" />\n<.octicon name=\"read-16\" />\n<.octicon name=\"read-24\" />\n<.octicon name=\"redo-16\" />\n<.octicon name=\"rel-file-path-16\" />\n<.octicon name=\"rel-file-path-24\" />\n<.octicon name=\"reply-16\" />\n<.octicon name=\"reply-24\" />\n<.octicon name=\"repo-16\" />\n<.octicon name=\"repo-24\" />\n<.octicon name=\"repo-clone-16\" />\n<.octicon name=\"repo-clone-24\" />\n<.octicon name=\"repo-deleted-16\" />\n<.octicon name=\"repo-forked-16\" />\n<.octicon name=\"repo-forked-24\" />\n<.octicon name=\"repo-locked-16\" />\n<.octicon name=\"repo-locked-24\" />\n<.octicon name=\"repo-pull-16\" />\n<.octicon name=\"repo-pull-24\" />\n<.octicon name=\"repo-push-16\" />\n<.octicon name=\"repo-push-24\" />\n<.octicon name=\"repo-template-16\" />\n<.octicon name=\"repo-template-24\" />\n<.octicon name=\"report-16\" />\n<.octicon name=\"report-24\" />\n<.octicon name=\"rocket-16\" />\n<.octicon name=\"rocket-24\" />\n<.octicon name=\"rows-16\" />\n<.octicon name=\"rows-24\" />\n<.octicon name=\"rss-16\" />\n<.octicon name=\"rss-24\" />\n<.octicon name=\"ruby-16\" />\n<.octicon name=\"ruby-24\" />\n<.octicon name=\"screen-full-16\" />\n<.octicon name=\"screen-full-24\" />\n<.octicon name=\"screen-normal-16\" />\n<.octicon name=\"screen-normal-24\" />\n<.octicon name=\"search-16\" />\n<.octicon name=\"search-24\" />\n<.octicon name=\"server-16\" />\n<.octicon name=\"server-24\" />\n<.octicon name=\"share-16\" />\n<.octicon name=\"share-24\" />\n<.octicon name=\"share-android-16\" />\n<.octicon name=\"share-android-24\" />\n<.octicon name=\"shield-16\" />\n<.octicon name=\"shield-24\" />\n<.octicon name=\"shield-check-16\" />\n<.octicon name=\"shield-check-24\" />\n<.octicon name=\"shield-lock-16\" />\n<.octicon name=\"shield-lock-24\" />\n<.octicon name=\"shield-slash-16\" />\n<.octicon name=\"shield-slash-24\" />\n<.octicon name=\"shield-x-16\" />\n<.octicon name=\"shield-x-24\" />\n<.octicon name=\"sidebar-collapse-16\" />\n<.octicon name=\"sidebar-collapse-24\" />\n<.octicon name=\"sidebar-expand-16\" />\n<.octicon name=\"sidebar-expand-24\" />\n<.octicon name=\"sign-in-16\" />\n<.octicon name=\"sign-in-24\" />\n<.octicon name=\"sign-out-16\" />\n<.octicon name=\"sign-out-24\" />\n<.octicon name=\"single-select-16\" />\n<.octicon name=\"single-select-24\" />\n<.octicon name=\"skip-16\" />\n<.octicon name=\"skip-24\" />\n<.octicon name=\"skip-fill-16\" />\n<.octicon name=\"skip-fill-24\" />\n<.octicon name=\"sliders-16\" />\n<.octicon name=\"smiley-16\" />\n<.octicon name=\"smiley-24\" />\n<.octicon name=\"sort-asc-16\" />\n<.octicon name=\"sort-asc-24\" />\n<.octicon name=\"sort-desc-16\" />\n<.octicon name=\"sort-desc-24\" />\n<.octicon name=\"sparkle-fill-16\" />\n<.octicon name=\"sponsor-tiers-16\" />\n<.octicon name=\"sponsor-tiers-24\" />\n<.octicon name=\"square-16\" />\n<.octicon name=\"square-24\" />\n<.octicon name=\"square-fill-16\" />\n<.octicon name=\"square-fill-24\" />\n<.octicon name=\"squirrel-16\" />\n<.octicon name=\"squirrel-24\" />\n<.octicon name=\"stack-16\" />\n<.octicon name=\"stack-24\" />\n<.octicon name=\"star-16\" />\n<.octicon name=\"star-24\" />\n<.octicon name=\"star-fill-16\" />\n<.octicon name=\"star-fill-24\" />\n<.octicon name=\"stop-16\" />\n<.octicon name=\"stop-24\" />\n<.octicon name=\"stopwatch-16\" />\n<.octicon name=\"stopwatch-24\" />\n<.octicon name=\"strikethrough-16\" />\n<.octicon name=\"strikethrough-24\" />\n<.octicon name=\"sun-16\" />\n<.octicon name=\"sun-24\" />\n<.octicon name=\"sync-16\" />\n<.octicon name=\"sync-24\" />\n<.octicon name=\"tab-24\" />\n<.octicon name=\"tab-external-16\" />\n<.octicon name=\"table-16\" />\n<.octicon name=\"table-24\" />\n<.octicon name=\"tag-16\" />\n<.octicon name=\"tag-24\" />\n<.octicon name=\"tasklist-16\" />\n<.octicon name=\"tasklist-24\" />\n<.octicon name=\"telescope-16\" />\n<.octicon name=\"telescope-24\" />\n<.octicon name=\"telescope-fill-16\" />\n<.octicon name=\"telescope-fill-24\" />\n<.octicon name=\"terminal-16\" />\n<.octicon name=\"terminal-24\" />\n<.octicon name=\"three-bars-16\" />\n<.octicon name=\"thumbsdown-16\" />\n<.octicon name=\"thumbsdown-24\" />\n<.octicon name=\"thumbsup-16\" />\n<.octicon name=\"thumbsup-24\" />\n<.octicon name=\"tools-16\" />\n<.octicon name=\"tools-24\" />\n<.octicon name=\"tracked-by-closed-completed-16\" />\n<.octicon name=\"tracked-by-closed-completed-24\" />\n<.octicon name=\"tracked-by-closed-not-planned-16\" />\n<.octicon name=\"tracked-by-closed-not-planned-24\" />\n<.octicon name=\"trash-16\" />\n<.octicon name=\"trash-24\" />\n<.octicon name=\"triangle-down-16\" />\n<.octicon name=\"triangle-down-24\" />\n<.octicon name=\"triangle-left-16\" />\n<.octicon name=\"triangle-left-24\" />\n<.octicon name=\"triangle-right-16\" />\n<.octicon name=\"triangle-right-24\" />\n<.octicon name=\"triangle-up-16\" />\n<.octicon name=\"triangle-up-24\" />\n<.octicon name=\"trophy-16\" />\n<.octicon name=\"trophy-24\" />\n<.octicon name=\"typography-16\" />\n<.octicon name=\"typography-24\" />\n<.octicon name=\"undo-16\" />\n<.octicon name=\"unfold-16\" />\n<.octicon name=\"unfold-24\" />\n<.octicon name=\"unlink-16\" />\n<.octicon name=\"unlink-24\" />\n<.octicon name=\"unlock-16\" />\n<.octicon name=\"unlock-24\" />\n<.octicon name=\"unmute-16\" />\n<.octicon name=\"unmute-24\" />\n<.octicon name=\"unread-16\" />\n<.octicon name=\"unread-24\" />\n<.octicon name=\"unverified-16\" />\n<.octicon name=\"unverified-24\" />\n<.octicon name=\"upload-16\" />\n<.octicon name=\"upload-24\" />\n<.octicon name=\"verified-16\" />\n<.octicon name=\"verified-24\" />\n<.octicon name=\"versions-16\" />\n<.octicon name=\"versions-24\" />\n<.octicon name=\"video-16\" />\n<.octicon name=\"video-24\" />\n<.octicon name=\"webhook-16\" />\n<.octicon name=\"workflow-16\" />\n<.octicon name=\"workflow-24\" />\n<.octicon name=\"x-12\" />\n<.octicon name=\"x-16\" />\n<.octicon name=\"x-24\" />\n<.octicon name=\"x-circle-16\" />\n<.octicon name=\"x-circle-24\" />\n<.octicon name=\"x-circle-fill-12\" />\n<.octicon name=\"x-circle-fill-16\" />\n<.octicon name=\"x-circle-fill-24\" />\n<.octicon name=\"zap-16\" />\n<.octicon name=\"zap-24\" />\n<.octicon name=\"zoom-in-16\" />\n<.octicon name=\"zoom-in-24\" />\n<.octicon name=\"zoom-out-16\" />\n<.octicon name=\"zoom-out-24\" />\n```","ref":"PrimerLive.Octicons.html#module-all-octicons"},{"type":"module","title":"PrimerLive.Theme","doc":"Primer CSS contains styles for light/dark color modes and themes, with support for color blindness.\n\nPrimerLive provides components and functions to work with themes:\n- [`theme/1`](`PrimerLive.Component.theme/1`) - wrapper to set the theme on child elements\n- [`theme_menu_options/1`](`PrimerLive.Component.theme_menu_options/1`) - contents for a theme menu\n- `html_attributes/2` - HTML attributes to set a theme on a component or element directly","ref":"PrimerLive.Theme.html"},{"type":"module","title":"Persistency - PrimerLive.Theme","doc":"There is no easy way to save persistent session data in LiveView because LiveView's state is stored in a process that ends when the page is left.","ref":"PrimerLive.Theme.html#module-persistency"},{"type":"module","title":"Session for theme state has been removed - PrimerLive.Theme","doc":"Using the session to store the theme state (for example [using a AJAX call roundtrip](https://thepugautomatic.com/2020/05/persistent-session-data-in-phoenix-liveview/)) does not work as expected: when navigating to another LiveView page, the updated session data is not refetched and only becomes available after a page refresh. This means that the previous offered solution with `PrimerLive.ThemeSessionController` is no longer recommended and in fact removed.","ref":"PrimerLive.Theme.html#module-session-for-theme-state-has-been-removed"},{"type":"module","title":"Alternatives: database or cache - PrimerLive.Theme","doc":"If you already have a database set up for storing data by session ID, it's a small step to integrate the theme state with it.\n\n- [Database Session Store with Elixir and Plug (2021)](https://kimlindholm.medium.com/database-session-store-with-elixir-and-plug-4354740e2f58)\n\nOn the other hand, for a lightweight solution you may find caching simpler to start with. For example [Cachex](https://github.com/whitfin/cachex) (which I've selected for [primer-live.org](https://primer-live.org)).\n\n- [Cachex with Phoenix (2020)](https://www.alenm.com/code/phoenix-cachex)\n- [Use caching to speed up data loading in Phoenix LiveView](https://fullstackphoenix.com/quick_tips/liveview-caching)","ref":"PrimerLive.Theme.html#module-alternatives-database-or-cache"},{"type":"module","title":"Handling user selection - PrimerLive.Theme","doc":"Assuming you are providing a [theme menu](`PrimerLive.Component.theme_menu_options/1`) on the website, the option the user selects must be stored in persistent storage.\n\nHere we're setting event callback \"store_theme\" in the theme menu:\n\n```\n# Some app component\n\n<.action_menu>\n  <:toggle class=\"btn btn-invisible\">\n    <.octicon name=\"sun-16\" />\n  </:toggle>\n  <.theme_menu_options\n    theme_state={@theme_state}\n    update_theme_event=\"store_theme\"\n  />\n</.action_menu>\n```\n\nThe callback is invoked whenever a theme menu option is clicked. See attr [`update_theme_event`](`PrimerLive.Component.theme_menu_options/1`) for documentation of the arguments.\n\n```\n# App LiveView\n\ndef handle_event(\n  \"store_theme\",\n  %{\"data\" => data, \"key\" => key, \"value\" => _},\n  socket\n) do\n  # Persist new theme state ...\n\n  {:noreply, socket}\nend\n```","ref":"PrimerLive.Theme.html#module-handling-user-selection"},{"type":"function","title":"PrimerLive.Theme.create_menu_items/3","doc":"Configures menu options from supplied params:\n- theme: the current theme state (used to define the selected menu items)\n- menu_options: which menu options will be displayed\n- menu_labels: overrides of default text labels\n\nReturns a list with 3 menu elements:\n- color_mode\n- dark_theme\n- light_theme\n\nEach list item is a map that contains display attributes:\n- group label\n- option labels\n- the selected item","ref":"PrimerLive.Theme.html#create_menu_items/3"},{"type":"function","title":"Tests - PrimerLive.Theme.create_menu_items/3","doc":"iex> PrimerLive.Theme.create_menu_items(\n    ...> %{\n    ...>   color_mode: \"light\",\n    ...>   light_theme: \"light_high_contrast\",\n    ...>   dark_theme: \"dark_high_contrast\"\n    ...> },\n    ...> PrimerLive.Theme.default_menu_options(),\n    ...> PrimerLive.Theme.default_menu_labels()\n    ...> )\n    [{:color_mode, %{labeled_options: [{\"light\", \"Light\"}, {\"dark\", \"Dark\"}, {\"auto\", \"System\"}], options: [\"light\", \"dark\", \"auto\"], selected: \"light\", title: \"Theme\"}},{:light_theme, %{options: [\"light\", \"light_high_contrast\", \"light_colorblind\", \"light_tritanopia\"], selected: \"light_high_contrast\", title: \"Light tone\", labeled_options: [{\"light\", \"Light\"}, {\"light_high_contrast\", \"Light high contrast\"}, {\"light_colorblind\", \"Light colorblind\"}, {\"light_tritanopia\", \"Light Tritanopia\"}]}},{ :dark_theme, %{ labeled_options: [{\"dark\", \"Dark\"}, {\"dark_dimmed\", \"Dark dimmed\"}, {\"dark_high_contrast\", \"Dark high contrast\"}, {\"dark_colorblind\", \"Dark colorblind\"}, {\"dark_tritanopia\", \"Dark Tritanopia\"}], options: [\"dark\", \"dark_dimmed\", \"dark_high_contrast\", \"dark_colorblind\", \"dark_tritanopia\"], selected: \"dark_high_contrast\", title: \"Dark tone\" }}]\n\n    iex> PrimerLive.Theme.create_menu_items(\n    ...> %{\n    ...>   color_mode: \"light\",\n    ...>   light_theme: \"light_high_contrast\",\n    ...>   dark_theme: \"dark_high_contrast\"\n    ...> },\n    ...> %{\n    ...>   color_mode: ~w(light dark)\n    ...> },\n    ...> %{\n    ...>   color_mode: %{\n    ...>     light: \"Light theme\"\n    ...>   },\n    ...>   reset: \"Reset\"\n    ...> })\n    [color_mode: %{labeled_options: [{\"light\", \"Light theme\"}, {\"dark\", \"Dark\"}], options: [\"light\", \"dark\"], selected: \"light\", title: \"Theme\"}]","ref":"PrimerLive.Theme.html#create_menu_items/3-tests"},{"type":"function","title":"PrimerLive.Theme.default_menu_labels/0","doc":"Default label for a theme menu.","ref":"PrimerLive.Theme.html#default_menu_labels/0"},{"type":"function","title":"PrimerLive.Theme.default_menu_options/0","doc":"Default options for a theme menu.","ref":"PrimerLive.Theme.html#default_menu_options/0"},{"type":"function","title":"PrimerLive.Theme.default_theme?/2","doc":"Compares the supplied state with the supplied default state.","ref":"PrimerLive.Theme.html#default_theme?/2"},{"type":"function","title":"Tests - PrimerLive.Theme.default_theme?/2","doc":"iex> PrimerLive.Theme.default_theme?(\n    ...> %{\n    ...>   color_mode: \"auto\",\n    ...>   light_theme: \"light\",\n    ...>   dark_theme: \"dark\"\n    ...> },\n    ...> PrimerLive.Theme.default_theme_state()\n    ...> )\n    true\n\n    iex> PrimerLive.Theme.default_theme?(\n    ...> %{\n    ...>   color_mode: \"light\",\n    ...>   light_theme: \"light_high_contrast\",\n    ...>   dark_theme: \"dark_high_contrast\"\n    ...> },\n    ...> PrimerLive.Theme.default_theme_state()\n    ...> )\n    false","ref":"PrimerLive.Theme.html#default_theme?/2-tests"},{"type":"function","title":"PrimerLive.Theme.default_theme_state/0","doc":"Initial theme state.","ref":"PrimerLive.Theme.html#default_theme_state/0"},{"type":"function","title":"PrimerLive.Theme.html_attributes/1","doc":"See `html_attributes/2`.","ref":"PrimerLive.Theme.html#html_attributes/1"},{"type":"function","title":"PrimerLive.Theme.html_attributes/2","doc":"Creates HTML (data) attributes from the supplied theme state to set a theme on a component or element directly. This is useful to \"theme\" specific page parts regardless of the user selected theme, for example a dark page header.\n\n```\n<.button\n  {PrimerLive.Theme.html_attributes([color_mode: \"dark\", dark_theme: \"dark_high_contrast\"])}\n>Button</.button>\n\n<.octicon name=\"sun-24\"\n  {PrimerLive.Theme.html_attributes(%{color_mode: \"dark\", dark_theme: \"dark_dimmed\"})}\n/>\n```","ref":"PrimerLive.Theme.html#html_attributes/2"},{"type":"function","title":"Tests - PrimerLive.Theme.html_attributes/2","doc":"iex> PrimerLive.Theme.html_attributes(\n    ...> %{\n    ...>   color_mode: \"light\",\n    ...>   light_theme: \"light_high_contrast\",\n    ...>   dark_theme: \"dark_high_contrast\"\n    ...> }\n    ...> )\n    [{:\"data-color-mode\", \"light\"}, {:\"data-dark-theme\", \"dark_high_contrast\"}, {:\"data-light-theme\", \"light_high_contrast\"}]\n\n    iex> PrimerLive.Theme.html_attributes(\n    ...> %{\n    ...> },\n    ...> %{\n    ...>   color_mode: \"auto\",\n    ...>   light_theme: \"light\",\n    ...>   dark_theme: \"dark\"\n    ...> }\n    ...> )\n    [{:\"data-color-mode\", \"auto\"}, {:\"data-dark-theme\", \"dark\"}, {:\"data-light-theme\", \"light\"}]\n\n    iex> PrimerLive.Theme.html_attributes(\n    ...> %{\n    ...>   light_theme: \"light_high_contrast\",\n    ...> },\n    ...> %{\n    ...>   color_mode: \"auto\",\n    ...>   light_theme: \"light\",\n    ...>   dark_theme: \"dark\"\n    ...> }\n    ...> )\n    [{:\"data-color-mode\", \"auto\"}, {:\"data-dark-theme\", \"dark\"}, {:\"data-light-theme\", \"light_high_contrast\"}]\n\n    iex> PrimerLive.Theme.html_attributes(\n    ...> %{\n    ...> },\n    ...> %{\n    ...>   color_mode: \"auto\",\n    ...> }\n    ...> )\n    [\"data-color-mode\": \"auto\"]","ref":"PrimerLive.Theme.html#html_attributes/2-tests"},{"type":"function","title":"PrimerLive.Theme.reset_key/0","doc":"Default reset link identifier for the `handle_event` update callback.","ref":"PrimerLive.Theme.html#reset_key/0"},{"type":"function","title":"PrimerLive.Theme.update_theme_event_key/0","doc":"Default event name for the `handle_event` update callback.\n\nThis value can be overridden in `theme_menu_options` with `update_theme_event`:\n```\n<.theme_menu_options\n  theme_state={@theme_state}\n  update_theme_event=\"store_theme\"\n/>\n```","ref":"PrimerLive.Theme.html#update_theme_event_key/0"},{"type":"module","title":"PrimerLive.UIIcons","doc":"Interface icons that are not part of the Octicons set.","ref":"PrimerLive.UIIcons.html"},{"type":"function","title":"PrimerLive.UIIcons.common_svg_attrs/0","doc":"","ref":"PrimerLive.UIIcons.html#common_svg_attrs/0"},{"type":"function","title":"PrimerLive.UIIcons.ui_icons/1","doc":"Internal use: generates a map of SVG's.\n\nTo use the `PrimerLive.Component.ui_icon/1` component, write:\n```\n<.ui_icon name=\"icon-name\" />\n```","ref":"PrimerLive.UIIcons.html#ui_icons/1"},{"type":"function","title":"All UI icons - PrimerLive.UIIcons.ui_icons/1","doc":"```\n<.ui_icon name=\"single-select-16\" />\n<.ui_icon name=\"multiple-select-16\" />\n<.ui_icon name=\"collapse-16\" />\n```","ref":"PrimerLive.UIIcons.html#ui_icons/1-all-ui-icons"},{"type":"function","title":"Attributes - PrimerLive.UIIcons.ui_icons/1","doc":"* Global attributes are accepted. Additional HTML attributes added to the svg element.","ref":"PrimerLive.UIIcons.html#ui_icons/1-attributes"},{"type":"extras","title":"Overview","doc":"# Overview\n\n \nAn implementation of GitHub's  Primer Design System  for Phoenix LiveView.\n \n\n \nPrimer Design provides a strong base for creating data driven applications such as rich CRUD applications with interactive forms.\n \n\n \nAll PrimerLive components accept the  class  attribute for customisations (and often the  classes  struct to address inner elements).  Primer's utility classes  allow a wide range of customisations without having to write custom styles.\n \n\n \nPrimerLive components can be used in  Phoenix LiveView pages  and regular (non-LiveView) views in Phoenix applications.","ref":"overview.html"},{"type":"extras","title":"Documentation - Overview","doc":"- [Component documentation](`PrimerLive.Component`)\n- [Installation](doc-extra/installation.md)\n- [Usage](doc-extra/usage.md)","ref":"overview.html#documentation"},{"type":"extras","title":"Resources - Overview","doc":"- [PrimerLive Storybook and Demo](https://primer-live.org)\n- [Source code](https://github.com/ArthurClemens/primer_live)","ref":"overview.html#resources"},{"type":"extras","title":"Installation","doc":"# Installation","ref":"installation.html"},{"type":"extras","title":"Install primer_live - Installation","doc":"Add PrimerLive as a dependency in your Phoenix application's `mix.exs`\n\n```\n{:primer_live, \"~> 0.7\"}\n```\n\nRun `mix.deps get`","ref":"installation.html#install-primer_live"},{"type":"extras","title":"CSS and JavaScript - Installation","doc":"You can either serve the dependencies as static resources, or use  npm  to bundle all assets. \n \n  If you plan to use menus, dialogs, or drawers in your project, you will need to include JavaScript dependencies. If not, you may skip the JavaScript imports and hooks.\n \n\n \n  Option A: Serve the dependencies as static resources\n \n\n Create a new static plug entry to  endpoint.ex : \n\n```\n# PrimerLive resources\nplug(Plug.Static,\n  at: \"/primer_live\",\n  from: {:primer_live, \"priv/static\"}\n)\n```\n\nAdd the `primer_live` directory to the `Phoenix.VerifiedRoutes` configuration in ` _web.ex`:\n\n```\ndef static_paths, do: ~w(assets fonts images favicon.png robots.txt primer_live)\n```\n\n CSS only \n\n Add the import link to  root.html.heex . \n If you are using verified routes: \n\n```\n \n```\n\nOtherwise:\n\n```\n \n```\n\n CSS and JavaScript \n\n Add both import links to  root.html.heex . \n If you are using verified routes: \n\n```\n \n  \n```\n\nAdvanced usage: to only include core Prompt functionality (to enable menus, dialogs and drawers, but without included styling), replace the import filenames with `primer-live-prompt.min.css` and `primer-live-prompt.min.js`.\n\nOtherwise:\n\n```\n \n  \n```\n\n \n  In  assets/js/app.js , add global  Prompt  to the hooks:\n \n\n```\nlet liveSocket = new LiveSocket(\"/live\", Socket, {\n  params: { _csrf_token: csrfToken },\n  hooks: {\n    Prompt: window.Prompt,\n    // existing hooks ...\n  },\n});\n```\n\n \n  Option B: Adding dependencies using npm\n \n\n This process will bundle all of the app's dependencies together with PrimerLive assets into  app.js  and  app.css  inside  priv/static/assets . \n\n Add npm library  primer-live  to your  assets/package.json . For a regular project, do: \n```\n{\n  \"dependencies\": {\n    \"primer-live\": \"file:../deps/primer_live\"\n  }\n}\n```\n\n If you're adding  primer-live  to an umbrella project, change the paths accordingly: \n\n```\n{\n  \"dependencies\": {\n    \"primer-live\": \"file:../../../deps/primer_live\"\n  }\n}\n```\n\nNow run the next command from your web app root:\n\n```\nnpm install --prefix assets\n```\n\n If you had previously installed  primer-live  and want to get the latest JavaScript, then force an install with: \n\n```\nnpm install --force primer-live --prefix assets\n```\n\n \n  To ensure that the assets are installed before your application has started, and before it has been deployed, add &quot;npm install&quot; to the setup and deploy scripts in  mix.exs .\n \n\n For example: \n\n```\ndefp aliases do\n[\n  setup: [\"deps.get\", \"cmd npm --prefix assets install\"],\n  \"assets.deploy\": [\n    \"cmd npm --prefix assets install\",\n    \"esbuild default --minify\",\n    \"phx.digest\"\n  ]\n]\nend\n```\n\n Run  mix setup  to install the npm dependencies. \n\n Add to  assets/js/app.js : \n\n```\nimport \"primer-live/primer-live.min.css\";\nimport { Prompt } from \"primer-live\";\n```\n\nAdvanced usage: to only include core Prompt functionality (to enable menus, dialogs and drawers, but without included styling), replace the CSS filename to `primer-live-prompt.min.js`.\n\n Also in  assets/js/app.js , add  Prompt  to the hooks: \n\n```\nlet liveSocket = new LiveSocket(\"/live\", Socket, {\n  params: { _csrf_token: csrfToken },\n  hooks: {\n    Prompt,\n    // existing hooks ...\n  },\n});\n```","ref":"installation.html#css-and-javascript"},{"type":"extras","title":"Usage","doc":"# Usage","ref":"usage.html"},{"type":"extras","title":"Usage in LiveView pages - Usage","doc":"```\ndefmodule MyAppWeb.MyLiveView do\n  use MyAppWeb, :live_view\n  alias PrimerLive.Component, as: Primer\n\n  def render(assigns) do\n    ~H\"\"\"\n     Click me \n    \"\"\"\n  end\n\nend\n```\n\nOr import with `use`:\n\n```\ndefmodule MyAppWeb.MyLiveView do\n  use MyAppWeb, :live_view\n  use PrimerLive\n\n  def render(assigns) do\n    ~H\"\"\"\n    <.button>Click me</.button>\n    \"\"\"\n  end\n\nend\n```","ref":"usage.html#usage-in-liveview-pages"},{"type":"extras","title":"Usage in regular views - Usage","doc":"In view files, for example in `page_view.ex`:\n\n```\ndefmodule MyAppWeb.PageView do\n  use MyAppWeb, :view\n  alias PrimerLive.Component, as: P\nend\n```\n\nThen call the component on a page, for example in `templates/page/index.html.heex`:\n\n```\n Click me \n```\n\nOr import with `use`:\n\n```\ndefmodule MyAppWeb.PageView do\n  use MyAppWeb, :view\n  use PrimerLive\nend\n```\n\nCall the component on a page:\n\n```\n<.button>Click me</.button>\n```","ref":"usage.html#usage-in-regular-views"},{"type":"extras","title":"Menus and dialogs","doc":"# Menus and dialogs\n\nMenu and dialog components - [`action_menu`](`PrimerLive.Component.action_menu/1`), [`dropdown`](`PrimerLive.Component.dropdown/1`), [`select_menu`](`PrimerLive.Component.select_menu/1`), [`drawer`](`PrimerLive.Component.drawer/1`) and [`dialog`](`PrimerLive.Component.dialog/1`) - share common interaction and appearance.\n\nTo use these components, CSS and JavaScript hook must be installed - see [Installation](installation.md).","ref":"menus-and-dialogs.html"},{"type":"extras","title":"Usage - Menus and dialogs","doc":"Menus are created with 3 elements: the component wrapper, a toggle button and the menu contents. For example for a dropdown menu:\n\n```\n<.dropdown>\n  <:toggle>Menu</:toggle>\n  <:item href=\"#url\">Item 1</:item>\n  <:item href=\"#url\">Item 2</:item>\n</.dropdown>\n```\n\nWith dialogs and drawers, the toggle element is omitted - they are usually opened from the outside.\n\n```\n<.dialog>\n  <:header_title>Title</:header_title>\n  <:body>\n    Content\n  </:body>\n</.dialog>\n```","ref":"menus-and-dialogs.html#usage"},{"type":"extras","title":"Attrs - Menus and dialogs","doc":"The following (optional) attributes are common for all menus and dialogs.\n\n- `form` - The surrounding form, if any.\n- `field` - See below at [Maintaining state in forms](#maintaining-state-in-forms).\n- `id` - Element id. Use to toggle from the outside, and to get consistent IDs in tests.\n- `is_backdrop` - Generates a backdrop background (default with medium darkness).\n- `is_dark_backdrop` - Generates a dark backdrop background color.\n- `is_dropdown_caret` - Adds a dropdown caret to the prompt button.\n- `is_fast` - Generates fast fade transitions for backdrop and content.\n- `is_light_backdrop` - Generates a light backdrop background color.\n- `is_medium_backdrop` - Generates a medium backdrop background color.\n- `phx_click_touch` - `phx-click` event binding to assign an event callback on clicking the touch layer.\n- `prompt_options` - JavaScript state callback functions.\n\nDialog and drawer specific:\n\n- `is_modal` - Generates a modal dialog/drawer; clicking the backdrop (if used) or outside of the dialog/drawer will not close it.\n- `is_escapable` - Closes the content when pressing the Escape key.\n- `focus_first` - Focus the first element after opening dialog/drawer. Pass a selector to match the element.","ref":"menus-and-dialogs.html#attrs"},{"type":"extras","title":"Slots - Menus and dialogs","doc":"The toggle slot is required for menus.\n\n- `toggle` - Generates a toggle element (default with button appearance) using the slot content as label.","ref":"menus-and-dialogs.html#slots"},{"type":"extras","title":"Prompt - Menus and dialogs","doc":"The menu `toggle` is an HTML label element that is connected to the checkbox that holds the state; clicking will toggle the checkbox state.\n\nTo control the open state from the outside, use the `Prompt` hook with either of these functions:\n- `Prompt.show(selectorOrElement)`\n- `Prompt.hide(selectorOrElement)`\n- `Prompt.toggle(selectorOrElement)`\n\nwhere `selectorOrElement` is either an HTML element, `this` (when used within the component), or a selector string.\n\n```\n<.button is_primary onclick=\"Prompt.show('#my-menu')\">\n  Show menu from outside\n</.button>\n\n<.action_menu id=\"my-menu\">\n  <:toggle>Show menu</:toggle>\n  <.action_list>\n    <.action_list_item>\n      One\n    </.action_list_item>\n    <.action_list_item>\n      Two\n    </.action_list_item>\n    <.action_list_item onclick=\"Prompt.hide(this)\">\n      Hide from inside\n    </.action_list_item>\n  </.action_list>\n</.action_menu>\n```","ref":"menus-and-dialogs.html#prompt"},{"type":"extras","title":"Status callbacks - Menus and dialogs","doc":"Use attr `prompt_options` to pass JavaScript state callback functions.\n\n```\n<.action_menu prompt_options=\"{\n  willShow: function(elements) { console.log('willShow', elements) },\n  didShow: function(elements) { console.log('didShow', elements) },\n  willHide: function(elements) { console.log('willHide', elements) },\n  didHide: function(elements) { console.log('didHide', elements) }\n}\">\n  ...\n</.action_menu>\n```","ref":"menus-and-dialogs.html#status-callbacks"},{"type":"extras","title":"CSS - Menus and dialogs","doc":"Prompt CSS mainly defines behavior and can be modified by providing different values to the default CSS Variables:\n\n```\n[data-prompt] {\n  /* colors */\n  --prompt-background-color-backdrop: black;\n  --prompt-background-opacity-backdrop-dark: 0.5;\n\n  /* - default: */\n  --prompt-background-opacity-backdrop-medium: 0.2;\n  --prompt-background-opacity-backdrop-light: 0.07;\n\n  /* transitions */\n  --prompt-transition-timing-function-backdrop: ease-in-out;\n  --prompt-transition-timing-function-content: ease-in-out;\n  --prompt-transition-duration-content: 180ms;\n  --prompt-fast-transition-duration-content: 140ms;\n  --prompt-transition-duration-backdrop: var(--prompt-transition-duration-content);\n  --prompt-fast-transition-duration-backdrop: var(--prompt-fast-transition-duration-content);\n\n  /* drawer */\n  --drawer-width: 320px;\n\n  /* z-index */\n  --prompt-z-index-backdrop: 98;\n  --prompt-z-index-touch: 99;\n  --prompt-z-index-menu-content: 100;\n  --prompt-z-index-drawer-content: 200;\n  --prompt-z-index-dialog-content: 300;\n}\n```","ref":"menus-and-dialogs.html#css"},{"type":"extras","title":"App header - Menus and dialogs","doc":"Take note of the `z-index` values: if the application uses a fixed header, you may want to ensure that its z-index is below dialogs/drawers and above menus, so between `101` and `199`.","ref":"menus-and-dialogs.html#app-header"},{"type":"extras","title":"Maintaining state in forms - Menus and dialogs","doc":"Under the hood, menu behavior is implemented through the Prompt hook that retrieves the open state and other relevant attributes from a hidden toggle checkbox.\nBy using a checkbox, we are able to preserve the open state when they are used within a form and updated by user actions.\n\nNormally after an update to the LiveView state, the menu/dialog/drawer is redrawn, resulting in it being rendered closed.\n\nTo preserve the open state of the menu, you can pass the form along with a *fictitious and unique field name* (not used in the data model). To differentiate its name from regular fields, you may add a prefix like \"ui_\". We'll read this field value in event handlers.\n\nHere we are adding field `ui_prompt_user_job` to the form:\n\n```\n<.form :let={f} for={@changeset} phx-change=\"validate\" phx-submit=\"save\">\n  <.action_menu form={f} field={:ui_prompt_user_job}>\n    <:toggle>Menu</:toggle>\n    <.action_list is_multiple_select>\n      <%= for {label, value} <- @options do %>\n        <.action_list_item\n          form={f}\n          field={:jobs}\n          checked_value={value}\n          is_multiple_select\n          is_selected={value in @values}\n        >\n          <%= label %>\n        </.action_list_item>\n      <% end %>\n    </.action_list>\n  </.action_menu>\n</.form>\n```\n\nThe same method can be used for dialogs and drawers:\n\n```\n<.form :let={f} for={@changeset} phx-change=\"validate\" phx-submit=\"save\">\n  <.dialog form={f} field={:ui_prompt_user_job} id=\"user-job-dialog\">\n    <:body>\n      <.action_list is_multiple_select>\n        # See above\n      </.action_list>\n    </:body>\n  </.dialog>\n</.form>\n```","ref":"menus-and-dialogs.html#maintaining-state-in-forms"},{"type":"extras","title":"Menu behavior: when to update - Menus and dialogs","doc":"The implementation of menu behavior from a user's perspective is determined by the event handler, where you have two options for updating the model state:\n\n1. Update with each selection\n2. Update only after closing the menu.\n\n#### Approach 1: Update with each selection\n\nThis approach is usually preferred, because it allows for direct validation feedback.\n\nProcess the event as usual and re-insert the fictitious field value:\n\n```\n# user_live/show.ex\n\ndef handle_event(\"save\", %{\"user\" => params}, socket) do\n  case User.update(socket.assigns.user, params) do\n    {:ok, user} ->\n      # Re-insert ui_prompt_user_job value\n      ui_changeset =\n        User.changeset(\n          user,\n          params |> Map.take([\"ui_prompt_user_job\"])\n        )\n\n      socket =\n        socket\n        |> assign(:user, user)\n        |> assign(:changeset, ui_changeset)\n\n      {:noreply, socket}\n\n    {:error, %Ecto.Changeset{} = changeset} ->\n      # Re-insert ui_prompt_user_job value\n      ui_changeset =\n        User.changeset(\n          changeset.data,\n          params |> Map.take([\"ui_prompt_user_job\"])\n        )\n\n      socket =\n        socket\n        |> assign(:changeset, changeset |> Map.merge(ui_changeset))\n\n      {:noreply, socket}\n  end\nend\n```\n\n\n#### Approach 2: Update only after closing the menu\n\nIgnore the event while the the menu is open (the toggle checkbox value is \"true\"):\n\n```\ndef handle_event(\"save\", %{\"user\" => %{\"ui_prompt_user_job\" => \"true\"}}, socket) do\n  # Ignore\n  {:noreply, socket}\nend\n\ndef handle_event(\"save\", %{\"user\" => params}, socket) do\n  # ui_prompt_user_job is \"false\", so process normally\n  ...\nend\n```","ref":"menus-and-dialogs.html#menu-behavior-when-to-update"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.7.2 - Changelog","doc":"","ref":"changelog.html#0-7-2"},{"type":"extras","title":"Changes - Changelog","doc":"- Fixes support for Ash 3. Thanks @ademenev!\n- Internal improvements","ref":"changelog.html#changes"},{"type":"extras","title":"0.7.1 - Changelog","doc":"","ref":"changelog.html#0-7-1"},{"type":"extras","title":"Changes - Changelog","doc":"- Added dialog attr `is_show_on_mount`.\n- Downgraded dependency @primer/css to 21.0.7 due to regressions.","ref":"changelog.html#changes"},{"type":"extras","title":"0.7.0 - Changelog","doc":"Updated dependencies:\n\n- `phoenix_ecto` to `4.5`\n- `phoenix_html` to `4.1`\n  - Added `phoenix_html_helpers`\n- `phoenix_live_view` to `0.20`\n- `@primer/css` to `21.2.2`\n\nRemoved support for Ash Framework due to incompatible dependencies.","ref":"changelog.html#0-7-0"},{"type":"extras","title":"0.6.4 - Changelog","doc":"Reverted dependency `@primer/css` to `21.0.9` because of an excessively increased file size in later versions.","ref":"changelog.html#0-6-4"},{"type":"extras","title":"0.6.3 - Changelog","doc":"","ref":"changelog.html#0-6-3"},{"type":"extras","title":"Changes - Changelog","doc":"- Class attrs now support class notation from [Surface](https://github.com/surface-ui/surface). Thanks @tunchamroeun!\n- Component `pagination`: added class entry for \"current_page\" which now can receive a custom class.","ref":"changelog.html#changes"},{"type":"extras","title":"0.6.2 - Changelog","doc":"","ref":"changelog.html#0-6-2"},{"type":"extras","title":"Bug fixes - Changelog","doc":"- Pagination: fixes the calculation when a gap between page numbers should be shown.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Other changes - Changelog","doc":"- Pagination: added `role` and improved ARIA labels.","ref":"changelog.html#other-changes"},{"type":"extras","title":"0.6.1 - Changelog","doc":"Bug fixes:\n\n- Fixes reading the required state of input fields.","ref":"changelog.html#0-6-1"},{"type":"extras","title":"0.6.0 - Changelog","doc":"Added support for forms created with [Ash Framework](https://www.ash-hq.org/). See [test/frameworks/ash/form_test.exs](https://github.com/ArthurClemens/primer_live/tree/development/test/frameworks/ash/form_test.exs) for an example.","ref":"changelog.html#0-6-0"},{"type":"extras","title":"0.5.4 - Changelog","doc":"Fixed a bug where the required marker would always be displayed, regardless of the field's required state.","ref":"changelog.html#0-5-4"},{"type":"extras","title":"0.5.3 - Changelog","doc":"Downgraded `phoenix_live_view` version to `0.19`; both `0.19` and `0.20` should be compatible.","ref":"changelog.html#0-5-3"},{"type":"extras","title":"0.5.2 - Changelog","doc":"Added JS and CSS exports for Prompt functionality only. This is useful when you want to use menu/dialog/drawer behavior without Primer Design CSS. See the installation documentation for details.","ref":"changelog.html#0-5-2"},{"type":"extras","title":"0.5.1 - Changelog","doc":"","ref":"changelog.html#0-5-1"},{"type":"extras","title":"Deprecated - Changelog","doc":"- Component `avatar_pair`: renamed `parent_child_avatar` to `avatar_pair`.\n- Components `action_menu` and `select_menu`: renamed `is_right_aligned` to `is_aligned_end` (added RTL support).\n- Component `spinner`: renamed `gap_color` to `highlight_color`.","ref":"changelog.html#deprecated"},{"type":"extras","title":"New component - Changelog","doc":"- `toggle_switch`: Toggle switch is used to immediately toggle a setting on or off.","ref":"changelog.html#new-component"},{"type":"extras","title":"Updated components - Changelog","doc":"- `avatar`: Added attr `is_round`.\n- `avatar_pair`: Improved styling: support display inside flex container, add inner border to child avatar.\n- `button`\n  - Improved dimensions according to Primer Style specs, including placing a trailing icon.\n  - Added attr `is_aligned_start`. Aligns contents to the start (at the left in left-to-right languages), while the dropdown caret (if any) is placed at the far end.\n- `spinner`: Updated to latest Primer Style design.","ref":"changelog.html#updated-components"},{"type":"extras","title":"0.5.0 - Changelog","doc":"Form elements have been revamped and aligned with the most recent [form element documentation at Primer Style](https://primer.style/design/ui-patterns/forms/overview).","ref":"changelog.html#0-5-0"},{"type":"extras","title":"Deprecated - Changelog","doc":"For all listed deprecations below: existing syntax will keep working, but log warnings will inform about the deprecation.\n\n- `form_group` is replaced by `form_control` (and `is_form_group` is replaced by `is_form_control`). When updating your code:\n  - You may need to add styling to correct the missing whitespace at top and bottom, because class \"form-group\" (which is also added when using attrs `form_group` and `is_form_group`) contains a top and bottom margin.\n  - Without a form group, text inputs (as well as selects) [will be given a default width by the browser](https://primer.style/design/components/text-input#width) and will probably be displayed smaller than they currently are.\n- The horizontal \"tab-row\" layout of `radio_group` is not mentioned in the Primer Design specification, while \"Radio group\" is (with vertical layout).\n  - The current `radio_group` has been renamed to `radio_tabs`.\n  - The new component `radio_group` uses a vertical layout.\n- `checkbox` and `radio_button` slot `hint` has been renamed to `caption`.\n- `button_group` slot `button` is replaced by `button` components as children.\n- For consistency, attr `is_full` has been renamed to `is_full_width` (in `alert` and `header` slot: `item`).","ref":"changelog.html#deprecated"},{"type":"extras","title":"Improvements - Changelog","doc":"- Added component `checkbox_group`.\n- Added convenience component `checkbox_in_group` for checkboxes inside a `checkbox_group`.\n- Added component `radio_group` (with vertical layout).\n- Added attr `caption` to show **hint message** below the form fields.\n  - Implemented for `select`, `text_input` and `textarea`.\n  - Implemented for `checkbox_group` and `radio_group` to show a hint below the group label.\n- Added a **required marker** to `form_control`, `checkbox_group` and `radio_group`. The form control label will show a required marker if the field is required.\n  - Added `is_required?` to `FieldState`, so it can also be queried in `validation_message` and `caption` callbacks.\n- Added **disabled state** to `form_control`:\n  - With components `select`, `text_input` and `textarea`: the attribute `disabled` is automatically passed to `form_control`.\n  - When using component `form_control` on its own: set explicitly with attr `is_disabled`.","ref":"changelog.html#improvements"},{"type":"extras","title":"Removed - Changelog","doc":"- Form element width variation attrs `is_short` and `is_shorter`. These are no longer supported by Primer System.\n- `form_control` class `body`: this extra div is removed to simplify the styling of validation states.","ref":"changelog.html#removed"},{"type":"extras","title":"0.4.0 - Changelog","doc":"","ref":"changelog.html#0-4-0"},{"type":"extras","title":"Improvements - Changelog","doc":"- The open state of menus and dialogs can now be maintained when used inside forms - see [Menus and dialogs](doc-extra/menus-and-dialogs.md).\n- Improved validation message logic.\n- Updated components:\n  - `theme_menu_options`: added attr `update_theme_event`: the event name to be called for updating the theme.\n  - `radio_group`: added to slot `radio_button` the attr `label` to set a custom label.\n- Updated `@primer/css` to `21.0.7`.","ref":"changelog.html#improvements"},{"type":"extras","title":"Breaking changes - Changelog","doc":"- Removed functions related to using session for theme state - see `PrimerLive.Theme` for alternatives. Removed:\n  - `ThemeSessionController`\n  - `ThemeEvent`\n  - Theme hook\n- IDs of checkboxes and radio buttons have been updated to only include valid characters.","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Deprecated - Changelog","doc":"- For all menu components, including 'dialog' and 'drawer': passing prompt options to the `toggle` slot is replaced by passing `prompt_options` to the main component.\n- In the `drawer` component, replace the subcomponent `drawer_content` with the slot `body`.\n  - This allows the focus wrap ID to be derived from the drawer's 'id' attribute, similar to how it is done for 'dialog'.\n  - When using the previous syntax, a warning message will be shown in the shell.","ref":"changelog.html#deprecated"},{"type":"extras","title":"Other changes - Changelog","doc":"- The HTML structure and some of the CSS classes of `action_menu`, `dropdown_menu` and `select_menu` have changed. Instead of ` ` and ` ` elements, the open state is now controlled with ` ` and ` `.\n- HTML attributes are sorted alphabetically.","ref":"changelog.html#other-changes"},{"type":"extras","title":"0.3.1 - Changelog","doc":"Replaced underscores in HTML element attributes with dashes because Phoenix LiveView 0.19 no longer does automatic substitution.\n\nUpdated components:\n\n- `select`: attr `prompt` is ignored when `is_multiple` is also used. This prevents `Phoenix.HTML.Form.multiple_select` from raising an error.","ref":"changelog.html#0-3-1"},{"type":"extras","title":"0.3.0 - Changelog","doc":"Breaking change: `action_list_item` now always renders a checkbox group, also when `is_multiple_select` is set on the list items. This change makes handling form data in events more consistent: the data will always consist of a list of checkbox values.","ref":"changelog.html#0-3-0"},{"type":"extras","title":"0.2.7 - Changelog","doc":"Fixes a bug introduced in `0.2.6` where single select `action_list_item`s did not get unique ids.","ref":"changelog.html#0-2-7"},{"type":"extras","title":"0.2.6 - Changelog","doc":"- Fixes a bug where `FormHelpers.field_state` did not handle forms without a changeset.\n- Updated components:\n  - `text_input`: added attrs `name` and `value`\n  - `checkbox`: add attrs `checked`, `checked_value`, `hidden_input`\n- Update `@primer/css` to `21.0.0`.","ref":"changelog.html#0-2-6"},{"type":"extras","title":"0.2.5 - Changelog","doc":"Updated components:\n\n- `action_menu` and `select_menu`:\n  - Added `prompt` slot attr `options` to pass Prompt options. This enables (for example) to postpone submitting a form in the menu by calling `submit` event in the Prompt functions `willHide` or `didHide`.","ref":"changelog.html#0-2-5"},{"type":"extras","title":"0.2.4 - Changelog","doc":"- Fixes a bug where variables in error messages where not interpolated.\n- Update to `phoenix_html` `3.3.x`","ref":"changelog.html#0-2-4"},{"type":"extras","title":"0.2.3 - Changelog","doc":"- Clarified `layout` attributes to change the rendered order of slots.\n- Improve field name and id generation.\n- Use checkboxes and radio buttons in action lists.\n\nUpdated component:\n\n- `checkbox`:\n  - Added attr `is_multiple`: When creating a list of checkboxes. Appends `[]` to the input name so that a list of values is passed to the form events.\n  - Added attr `is_omit_label`: Omits any label.","ref":"changelog.html#0-2-3"},{"type":"extras","title":"0.2.2 - Changelog","doc":"Updated component:\n\n- `text_input`:\n  - Moved attr `is_trailing_action_divider` to slot `trailing_action` as `is_divider`\n  - Added attr `is_visible_with_value` to slot `trailing_action` to only show the trailing action when the input has a value. Use this cor example to show a clear button only when the input has a value to clear.","ref":"changelog.html#0-2-2"},{"type":"extras","title":"0.2.1 - Changelog","doc":"","ref":"changelog.html#0-2-1"},{"type":"extras","title":"Rework of form controls - Changelog","doc":"The rework includes styles from [Primer ViewComponents](https://primer.style/view-components/). The form styles from this flavor of Primer is more mature than the generally used Primer CSS.\n\nUpdated components:\n\n- `text_input`:\n  - Added attr `is_monospace`\n  - Added slots `leading_visual` and `trailing_action`\n  - Added attr `is_trailing_action_divider`\n  - Inputs inside a form group no longer have a background color by default; use `is_contrast` to set it explicitly\n  - Removed validation message for hidden inputs\n- `textarea`:\n  - Added attr `is_monospace`\n  - Use `is_contrast` to explicitly set a contrasting background color\n- `checkbox` and `radio_button`\n  - Have a clearer (more colorful) appearance\n  - Changed the HTML structure\n- `radio_group`\n  - For consistency, added input styling from Primer ViewComponents radio button (keeping the initial size)\n- `select`:\n  - Added wrapper HTML element\n  - Added attr `is_monospace`\n  - Added attr `is_large`\n  - Added attr `is_short`\n  - Added attr `is_shorter`\n  - Added attr `is_full_width`\n  - Improved styling for multiple select\n- `subnav` with search field:\n  - Added attr `is_wrap` to wrap child elements\n  - Improved CSS for small screens\n\nAdded component:\n\n- `input_validation_message` - can be used as standalone message component for inputs where the position of the validation feedback is not so obvious, for example lists of checkboxes or radio buttons\n\nAdditional:\n\n- Added styling for input elements inside a disabled fieldset","ref":"changelog.html#rework-of-form-controls"},{"type":"extras","title":"Integration of npm dependencies - Changelog","doc":"JavaScript and CSS dependencies (from npm library `primer-live`) are now incorporated in the Elixir package. The installation instructions are slightly simplified (see the documentation) and are recommended for a fresh setup. The previous installation method works just fine for existing projects.","ref":"changelog.html#integration-of-npm-dependencies"},{"type":"extras","title":"0.1.16 - Changelog","doc":"Added anchor link attributes to `button` to create a link that looks like a button.","ref":"changelog.html#0-1-16"},{"type":"extras","title":"0.1.15 - Changelog","doc":"Removed Octicon builder template files from distribution.","ref":"changelog.html#0-1-15"},{"type":"extras","title":"0.1.14 - Changelog","doc":"- Updated `octicons` dependency to `17.10.1`\n- Code quality refactoring\n- Documentation updates","ref":"changelog.html#0-1-14"},{"type":"extras","title":"0.1.13 - Changelog","doc":"Added:\n\n- `theme_menu_options` to create a theme menu\n- `Theme.html_attributes` to set theme attributes on elements\n- Theme functions for persistent theme data in the session","ref":"changelog.html#0-1-13"},{"type":"extras","title":"0.1.12 - Changelog","doc":"Fixes an issue where validation messages did not show.","ref":"changelog.html#0-1-12"},{"type":"extras","title":"0.1.11 - Changelog","doc":"Added:\n\n- `theme`","ref":"changelog.html#0-1-11"},{"type":"extras","title":"0.1.10 - Changelog","doc":"Updated:\n\n- Prevent attribute open on select menu","ref":"changelog.html#0-1-10"},{"type":"extras","title":"0.1.9 - Changelog","doc":"Added:\n\n- `styled_html`","ref":"changelog.html#0-1-9"},{"type":"extras","title":"0.1.8 - Changelog","doc":"Updated:\n\n- Removed requirement for Elixir version","ref":"changelog.html#0-1-8"},{"type":"extras","title":"0.1.7 - Changelog","doc":"Updated:\n\n- Added `is_small` for `tabnav` items","ref":"changelog.html#0-1-7"},{"type":"extras","title":"0.1.6 - Changelog","doc":"Updated:\n\n- `oticon` icons","ref":"changelog.html#0-1-6"},{"type":"extras","title":"0.1.5 - Changelog","doc":"Added:\n\n- `drawer`","ref":"changelog.html#0-1-5"},{"type":"extras","title":"0.1.4 - Changelog","doc":"Bug fix:\n\n- Improve `action_menu` on mobile","ref":"changelog.html#0-1-4"},{"type":"extras","title":"0.1.3 - Changelog","doc":"Added:\n\n- `action_menu`","ref":"changelog.html#0-1-3"},{"type":"extras","title":"0.1.2 - Changelog","doc":"Bug fix:\n\n- `action_link_item`: pass class to `link` slot.","ref":"changelog.html#0-1-2"},{"type":"extras","title":"0.1.1 - Changelog","doc":"First release.","ref":"changelog.html#0-1-1"},{"type":"extras","title":"LICENSE","doc":"Copyright Arthur Clemens\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the \"Software\"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}